@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident "@(#)Notice.c	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident "@(#)Notice.c	1.4 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -18,9 +20,10 @@
 #include <X11/Xos.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#include <olgx/olgx.h>
 
 #include "i18n.h"
+#include <olgx/olgx.h>
+
 #include "ollocale.h"
 #include "olwm.h"
 #include "win.h"
@@ -29,7 +32,6 @@
 #include "mem.h"
 #include "events.h"
 
-
 extern int		PointInRect();
 extern SemanticAction 	FindKeyboardAction();
 
@@ -338,7 +340,7 @@ noticeBoxDetails	*boxDetails;
 			/* need to move each line further down the screen */
 			MIN_BOX_TOP + GRV.TextFontInfo->ascent * ( ii + 1 )
 				+ ( MIN_STRING_VSPACE * ii ),
-			0, False, OLGX_NORMAL );
+			0, OLGX_NORMAL );
 
 	/* put buttons in - notice that it's a single row */
 	/* row of buttons should be centered within available space,
@@ -470,6 +472,7 @@ pointInButton(event,details,btn)
  * noticeInterposer - event handler for notices
  */
 static int
+/* ARGSUSED */
 noticeInterposer(dpy,event,win,details)
 Display			*dpy;
 XEvent			*event;
@@ -481,7 +484,7 @@ char			*win;
 noticeBoxDetails	*details;
 {
 	NoticeBox	*noticeBox = details->noticeBox;
-	int		ii,button,buttonState;
+	int		ii,button;
 
 	/*
 	 * Discard synthetic events
@@ -642,7 +645,7 @@ CreateNoticeBox(dpy,screen,noticeBox,callback)
 {
 	XSetWindowAttributes	attributes;
 	noticeBoxDetails	*boxDetails;
-	int			i,defaultButton;
+	int			i;
 
 	/* 
 	 * Create box details and button details
