@@ -7,7 +7,9 @@
 /* client.c - functions relating to clients as a whole 
  */
 
-#ident	"@(#)client.c	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident	"@(#)client.c	1.4 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -22,9 +24,10 @@
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
 #include <X11/keysym.h>
-#include <olgx/olgx.h>
 
 #include "i18n.h"
+#include <olgx/olgx.h>
+
 #include "ollocale.h"
 #include "events.h"
 #include "mem.h"
@@ -111,8 +114,6 @@ static	Client		*lastCurrentClient = NULL;
 * private functions
 ***************************************************************************/
 
-static void clientSetBusy();
-
 /*
  * setComposeLed - sets the compose led to the new mode iff different than
  *		   the current mode.
@@ -139,15 +140,15 @@ setComposeLed(dpy,mode)
 ***************************************************************************/
 
 /*
+
  * InitClientState - init kbd led state for client use
  */
 InitClientState(dpy)
 Display	*dpy;
 {
 	int	*ledMap;
-	int	i,numLeds,led;
+	int	i,numLeds;
 	unsigned int nitems,nremain;
-	XKeyboardControl  kbdvalue;
 
 	DoingWindowState = False;
 
@@ -303,7 +304,7 @@ ClientShowProps(cli)
 Client *cli;
 {
 	XEvent clientEvent;
-	
+
 	clientEvent.xclient.type = ClientMessage;
 	clientEvent.xclient.message_type = AtomShowProperties;
 	clientEvent.xclient.format = 32;
@@ -350,6 +351,7 @@ void *
 #else
 char *
 #endif
+/* ARGSUSED */
 ClientShutdown(cli,junk)
 Client	*cli;
 #ifndef COHERENT
@@ -399,6 +401,7 @@ char *junk;
 	{
 		IconHide(cli, cli->iconwin);
 	}
+	IconUnparent(cli, cli->iconwin);
 
 	frameInfo = cli->framewin;
 	paneInfo = (WinPane*)(frameInfo->fcore.panewin);
@@ -487,7 +490,7 @@ Client *cli;
 
 	    setfocus = !GRV.FocusFollowsMouse;
 	}
-	
+
 	removeClient(cli);
 
 	/*
@@ -504,6 +507,7 @@ Client *cli;
 	}
 
 	/* destroy the window resources associated with the client */
+	IconUnparent(cli, cli->iconwin);
 	WinCallDestroy(cli);
 
 	GroupRemove(cli->groupid, cli);
@@ -525,7 +529,7 @@ Client *cli;
 	/* REMIND  what's to be done with followers here? */
 
 #ifdef DEBUG
-	memset(cli, 0, sizeof(Client));
+	memset(cli, 0x55, sizeof(Client));
 #endif /* DEBUG */
 
 	MemFree(cli);
@@ -590,6 +594,7 @@ ClientSetWMState( cli )
 	if (cli->framewin->core.self ==
 		cli->scrInfo->vdm->client->framewin->core.self)
 	    return;
+
 	if (iconWinInfo) {
         	if ( iconWinInfo->fcore.panewin )
         		icon = iconWinInfo->fcore.panewin->core.self;
@@ -787,9 +792,9 @@ Client *cli;
 	WinPane *wp;
 
 	if ((wf = cli->framewin) == NULL)
-		return (Window)NULL;
+		return NULL;
 	if ((wp = (WinPane *)(wf->fcore.panewin)) == NULL)
-		return (Window)NULL;
+		return NULL;
 	return wp->core.self;
 }
 
@@ -1191,7 +1196,7 @@ ClientInBoxClosure *close;
 }
 
 /*
- * ClientSetBusy -- the busy state has (possibly) been changed for a client.
+ * ClientUpdateBusy -- the busy state has (possibly) been changed for a client.
  *	if the client is going from normal to busy:
  *          mark the client as busy
  *          put up a busy window
@@ -1262,7 +1267,6 @@ DestroyPinnedMenuClients()
 	List	*l = ActiveClientList;
 	Client	*cli;
 
-
 	for (cli = ListEnum(&l); cli != NULL; cli = ListEnum(&l)) {
 		if (cli->framewin && cli->framewin->fcore.panewin &&
 		    cli->framewin->fcore.panewin->core.kind == WIN_PINMENU) {
