@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)defaults.h	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident	"@(#)defaults.h	1.3 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
