@@ -4,6 +4,8 @@
  *      file for terms of the license.
  */
 
+#ifdef IDENT
 #ident	"@(#)environ.h	1.5	91/09/14 SMI"
+#endif
 
 extern	char	**MakeEnviron(/* ScreenInfo *scrInfo */);
