@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)evbind.c	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident	"@(#)evbind.c	1.4 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -34,10 +36,6 @@
 #include "resources.h"
 
 
-#ifdef COH42
-#include <misc.h>
-#endif
-
 /* ===== externs ========================================================== */
 
 extern List *ScreenInfoList;
@@ -91,8 +89,6 @@ establishModBindings(dpy, newDB)
     XrmValue value;
     ModDescriptor *d;
     unsigned int polyStringToModifier();
-    static XrmBinding bindings[] =
-	{ XrmBindTightly, XrmBindTightly, XrmBindTightly };
 
     classlist[0] = OpenWinQ;
     classlist[1] = modClassQ;
@@ -438,13 +434,13 @@ KeyDescriptor KeyDescriptorTable[] = {
 	ACTION_TOGGLE_PIN,	    KD_FULL
 }, {
 	"SuspendMouseless",	    "z+Alt",			keySuspend,
-	ACTION_NONE,		    KD_BASIC_FULL
+	ACTION_NONE,		    KD_FULL
 }, {
 	"ResumeMouseless",	    "Z+Alt",			keyResume,
-	ACTION_NONE,		    KD_IMMUNE | KD_BASIC_FULL
+	ACTION_NONE,		    KD_IMMUNE | KD_FULL
 }, {
 	"QuoteNextKey",		    "q+Alt",			keyQuoteNext,
-	ACTION_NONE,		    KD_BASIC_FULL
+	ACTION_NONE,		    KD_FULL
 }, {
 	"Refresh",		    "F8+Alt",			KeyRefresh,
 	ACTION_NONE,		    KD_FULL
@@ -484,6 +480,21 @@ KeyDescriptor KeyDescriptorTable[] = {
 }, {
 	"RaiseLower",		    "L5",		 KeyRaiseLowerPointer,
 	ACTION_NONE,		    KD_ALWAYS
+}, {
+	"ToggleFullSizeZoomX",	    "F3+Alt+Shift",    KeyToggleFullSizeZoomX,
+	ACTION_NONE,		    KD_FULL
+}, {
+	"ToggleDragWindow",	    "F6+Alt+Shift",    KeyToggleDragWindow,
+	ACTION_NONE,		    KD_FULL
+}, {
+	"ToggleMoveGroups",	    "g+Alt",           KeyToggleMoveGroups,
+	ACTION_NONE,		    KD_FULL
+}, {
+	"ToggleSticky",	            "s+Alt",           KeyToggleSticky,
+	ACTION_NONE,		    KD_FULL
+}, {
+	"SaveWorkspace",	    "F10+Meta+Alt+Shift", KeySaveWorkspace,
+	ACTION_NONE,		    KD_ALWAYS
 },
 
 /*
@@ -492,138 +503,140 @@ KeyDescriptor KeyDescriptorTable[] = {
  * modifier are grabbed and are always active, otherwise they fall through
  * to the no focus window which moves the vdm
  *
- * We don't have a nofocus action for R7 and R13 since they already have
- * an action above
  */
    {    "VirtualUp",		    "Up+Meta",		KeyMoveVDM,
-	ACTION_UP,		    KD_ALWAYS				},
+	ACTION_UP,		    KD_VIRTUAL				},
    {    "HalfUp",		    "Up+Shift",		NULLFUNC,
-	ACTION_HALF_UP,	    	    KD_ALWAYS				},
+	ACTION_HALF_UP,	    	    KD_VIRTUAL				},
    {    "VirtualHalfUp",	    "Up+Shift+Meta",	KeyMoveVDM,
-	ACTION_HALF_UP,		    KD_ALWAYS				},
+	ACTION_HALF_UP,		    KD_VIRTUAL				},
    {    "VirtualJumpUp",	    "Up+Ctrl+Meta",	KeyMoveVDM,
-	ACTION_JUMP_UP,		    KD_ALWAYS				},
+	ACTION_JUMP_UP,		    KD_VIRTUAL				},
 
    {    "VirtualDown",		    "Down+Meta",	KeyMoveVDM,
-	ACTION_DOWN,		    KD_ALWAYS				},
+	ACTION_DOWN,		    KD_VIRTUAL				},
    {    "HalfDown",		    "Down+Shift",	NULLFUNC,
-	ACTION_HALF_DOWN,    	    KD_ALWAYS				},
+	ACTION_HALF_DOWN,    	    KD_VIRTUAL				},
    {    "VirtualHalfDown",	    "Down+Shift+Meta",	KeyMoveVDM,
-	ACTION_HALF_DOWN,	    KD_ALWAYS				},
+	ACTION_HALF_DOWN,	    KD_VIRTUAL				},
    {    "VirtualJumpDown",	    "Down+Ctrl+Meta",	KeyMoveVDM,
-	ACTION_JUMP_DOWN,	    KD_ALWAYS				},
+	ACTION_JUMP_DOWN,	    KD_VIRTUAL				},
 
    {    "VirtualLeft",		    "Left+Meta",	KeyMoveVDM,
-	ACTION_LEFT,		    KD_ALWAYS				},
+	ACTION_LEFT,		    KD_VIRTUAL				},
    {    "HalfLeft",		    "Left+Shift",	NULLFUNC,
-	ACTION_HALF_LEFT,	    KD_ALWAYS				},
+	ACTION_HALF_LEFT,	    KD_VIRTUAL				},
    {    "VirtualHalfLeft",	    "Left+Shift+Meta",	KeyMoveVDM,
-	ACTION_HALF_LEFT,	    KD_ALWAYS				},
+	ACTION_HALF_LEFT,	    KD_VIRTUAL				},
    {    "VirtualJumpLeft",	    "Left+Ctrl+Meta",	KeyMoveVDM,
-	ACTION_JUMP_LEFT,	    KD_ALWAYS				},
+	ACTION_JUMP_LEFT,	    KD_VIRTUAL				},
 
    {    "VirtualRight",		    "Right+Meta",	KeyMoveVDM,
-	ACTION_RIGHT,		    KD_ALWAYS				},
+	ACTION_RIGHT,		    KD_VIRTUAL				},
    {    "HalfRight",		    "Right+Shift",	NULLFUNC,
-	ACTION_HALF_RIGHT,	    KD_ALWAYS				},
+	ACTION_HALF_RIGHT,	    KD_VIRTUAL				},
    {    "VirtualHalfRight",	    "Right+Shift+Meta",	KeyMoveVDM,
-	ACTION_HALF_RIGHT,	    KD_ALWAYS				},
+	ACTION_HALF_RIGHT,	    KD_VIRTUAL				},
    {    "VirtualJumpRight",	    "Right+Ctrl+Meta",	KeyMoveVDM,
-	ACTION_JUMP_RIGHT,	    KD_ALWAYS				},
+	ACTION_JUMP_RIGHT,	    KD_VIRTUAL				},
 
+   {    "UpLeft",		    "R7",		NULLFUNC,
+	ACTION_UPLEFT,		    KD_VIRTUAL				},
    {    "VirtualUpLeft",	    "R7+Meta",		KeyMoveVDM,
-	ACTION_UPLEFT,		    KD_ALWAYS				},
+	ACTION_UPLEFT,		    KD_VIRTUAL				},
    {    "JumpUpLeft",		    "R7+Ctrl",		NULLFUNC,
-	ACTION_JUMP_UPLEFT,	    KD_ALWAYS				},
+	ACTION_JUMP_UPLEFT,	    KD_VIRTUAL				},
    {	"VirtualJumpUpLeft",	    "R7+Ctrl+Meta",	KeyMoveVDM,
-	ACTION_JUMP_UPLEFT,	    KD_ALWAYS				},
+	ACTION_JUMP_UPLEFT,	    KD_VIRTUAL				},
    {    "HalfUpLeft",		    "R7+Shift",		NULLFUNC,
-	ACTION_HALF_UPLEFT,	    KD_ALWAYS				},
+	ACTION_HALF_UPLEFT,	    KD_VIRTUAL				},
    {	"VirtualHalfUpLeft",	    "R7+Shift+Meta",	KeyMoveVDM,
-	ACTION_HALF_UPLEFT,	    KD_ALWAYS				},
+	ACTION_HALF_UPLEFT,	    KD_VIRTUAL				},
 
    {    "VirtualUpRight",	    "R9+Meta",		KeyMoveVDM,
-	ACTION_UPRIGHT,		    KD_ALWAYS				},
+	ACTION_UPRIGHT,		    KD_VIRTUAL				},
    {    "UpRight",		    "R9",		NULLFUNC,
-	ACTION_UPRIGHT,		    KD_ALWAYS				},
+	ACTION_UPRIGHT,		    KD_VIRTUAL				},
    {    "JumpUpRight",		    "R9+Ctrl",		NULLFUNC,
-	ACTION_JUMP_UPRIGHT,	    KD_ALWAYS				},
+	ACTION_JUMP_UPRIGHT,	    KD_VIRTUAL				},
    {    "VirtualJumpUpRight",	    "R9+Ctrl+Meta",	KeyMoveVDM,
-	ACTION_JUMP_UPRIGHT,	    KD_ALWAYS				},
+	ACTION_JUMP_UPRIGHT,	    KD_VIRTUAL				},
    {    "HalfUpRight",		    "R9+Shift",		NULLFUNC,
-	ACTION_HALF_UPRIGHT,	    KD_ALWAYS				},
+	ACTION_HALF_UPRIGHT,	    KD_VIRTUAL				},
    {    "VirtualHalfUpRight",	    "R9+Shift+Meta",	KeyMoveVDM,
-	ACTION_HALF_UPRIGHT,	    KD_ALWAYS				},
+	ACTION_HALF_UPRIGHT,	    KD_VIRTUAL				},
 
+   {	"DownLeft",		    "R13",		NULLFUNC,
+	ACTION_DOWNLEFT,	    KD_VIRTUAL				},
    {    "VirtualDownLeft",	    "R13+Meta",		KeyMoveVDM,
-	ACTION_DOWNLEFT,	    KD_ALWAYS				},
+	ACTION_DOWNLEFT,	    KD_VIRTUAL				},
    {    "JumpDownLeft",		    "R13+Ctrl",		NULLFUNC,
-	ACTION_JUMP_DOWNLEFT,	    KD_ALWAYS				},
+	ACTION_JUMP_DOWNLEFT,	    KD_VIRTUAL				},
    {    "VirtualJumpDownLeft",	    "R13+Ctrl+Meta",	KeyMoveVDM,
-	ACTION_JUMP_DOWNLEFT,	    KD_ALWAYS				},
+	ACTION_JUMP_DOWNLEFT,	    KD_VIRTUAL				},
    {    "HalfDownLeft",		    "R13+Shift",	NULLFUNC,
-	ACTION_HALF_DOWNLEFT,	    KD_ALWAYS				},
+	ACTION_HALF_DOWNLEFT,	    KD_VIRTUAL				},
    {    "VirtualHalfDownLeft",	    "R13+Shift+Meta",	KeyMoveVDM,
-	ACTION_HALF_DOWNLEFT,	    KD_ALWAYS				},
+	ACTION_HALF_DOWNLEFT,	    KD_VIRTUAL				},
 
    {    "VirtualDownRight",	    "R15+Meta",		KeyMoveVDM,
-	ACTION_DOWNRIGHT,	    KD_ALWAYS				},
+	ACTION_DOWNRIGHT,	    KD_VIRTUAL				},
    {    "DownRight",		    "R15",		NULLFUNC,
-	ACTION_DOWNRIGHT,	    KD_ALWAYS				},
+	ACTION_DOWNRIGHT,	    KD_VIRTUAL				},
    {    "JumpDownRight",	    "R15+Ctrl",		NULLFUNC,
-	ACTION_JUMP_DOWNRIGHT,	    KD_ALWAYS				},
+	ACTION_JUMP_DOWNRIGHT,	    KD_VIRTUAL				},
    {    "VirtualJumpDownRight",	    "R15+Ctrl+Meta",	KeyMoveVDM,
-	ACTION_JUMP_DOWNRIGHT,	    KD_ALWAYS				},
+	ACTION_JUMP_DOWNRIGHT,	    KD_VIRTUAL				},
    {    "HalfDownRight",	    "R15+Shift",	NULLFUNC,
-	ACTION_HALF_DOWNRIGHT,	    KD_ALWAYS				},
+	ACTION_HALF_DOWNRIGHT,	    KD_VIRTUAL				},
    {    "VirtualHalfDownRight",	    "R15+Shift+Meta",	KeyMoveVDM,
-	ACTION_HALF_DOWNRIGHT,	    KD_ALWAYS				},
+	ACTION_HALF_DOWNRIGHT,	    KD_VIRTUAL				},
 
    {    "VirtualHome",	    	    "R11+Meta",		KeyMoveVDM,
-	ACTION_HOME,	    	    KD_ALWAYS				},
+	ACTION_HOME,	    	    KD_VIRTUAL				},
    {    "GoHome",		    "R11",		NULLFUNC,
-	ACTION_HOME,		    KD_ALWAYS				},
+	ACTION_HOME,		    KD_VIRTUAL				},
 
    {    "VirtualScreen1",	    "F1+Meta",		KeyMoveVDM,
-	ACTION_GOTO_1,		    KD_ALWAYS				},
+	ACTION_GOTO_1,		    KD_VIRTUAL				},
    {    "Screen1",	    	    "F1",		NULLFUNC,
-	ACTION_GOTO_1,		    KD_ALWAYS				},
+	ACTION_GOTO_1,		    KD_VIRTUAL				},
    {    "VirtualScreen2",	    "F2+Meta",		KeyMoveVDM,
-	ACTION_GOTO_2,		    KD_ALWAYS				},
+	ACTION_GOTO_2,		    KD_VIRTUAL				},
    {    "Screen2",	    	    "F2",		NULLFUNC,
-	ACTION_GOTO_2,		    KD_ALWAYS				},
+	ACTION_GOTO_2,		    KD_VIRTUAL				},
    {    "VirtualScreen3",	    "F3+Meta",		KeyMoveVDM,
-	ACTION_GOTO_3,		    KD_ALWAYS				},
+	ACTION_GOTO_3,		    KD_VIRTUAL				},
    {    "Screen3",	    	    "F3",		NULLFUNC,
-	ACTION_GOTO_3,		    KD_ALWAYS				},
+	ACTION_GOTO_3,		    KD_VIRTUAL				},
    {    "VirtualScreen4",	    "F4+Meta",		KeyMoveVDM,
-	ACTION_GOTO_4,		    KD_ALWAYS				},
+	ACTION_GOTO_4,		    KD_VIRTUAL				},
    {    "Screen4",	    	    "F4",		NULLFUNC,
-	ACTION_GOTO_4,		    KD_ALWAYS				},
+	ACTION_GOTO_4,		    KD_VIRTUAL				},
    {    "VirtualScreen5",	    "F5+Meta",		KeyMoveVDM,
-	ACTION_GOTO_5,		    KD_ALWAYS				},
+	ACTION_GOTO_5,		    KD_VIRTUAL				},
    {    "Screen5",	    	    "F5",		NULLFUNC,
-	ACTION_GOTO_5,		    KD_ALWAYS				},
+	ACTION_GOTO_5,		    KD_VIRTUAL				},
    {    "VirtualScreen6",	    "F6+Meta",		KeyMoveVDM,
-	ACTION_GOTO_6,		    KD_ALWAYS				},
+	ACTION_GOTO_6,		    KD_VIRTUAL				},
    {    "Screen6",	    	    "F6",		NULLFUNC,
-	ACTION_GOTO_6,		    KD_ALWAYS				},
+	ACTION_GOTO_6,		    KD_VIRTUAL				},
    {    "VirtualScreen7",	    "F7+Meta",		KeyMoveVDM,
-	ACTION_GOTO_7,		    KD_ALWAYS				},
+	ACTION_GOTO_7,		    KD_VIRTUAL				},
    {    "Screen7",	    	    "F7",		NULLFUNC,
-	ACTION_GOTO_7,		    KD_ALWAYS				},
+	ACTION_GOTO_7,		    KD_VIRTUAL				},
    {    "VirtualScreen8",	    "F8+Meta",		KeyMoveVDM,
-	ACTION_GOTO_8,		    KD_ALWAYS				},
+	ACTION_GOTO_8,		    KD_VIRTUAL				},
    {    "Screen8",	    	    "F8",		NULLFUNC,
-	ACTION_GOTO_8,		    KD_ALWAYS				},
+	ACTION_GOTO_8,		    KD_VIRTUAL				},
    {    "VirtualScreen9",	    "F9+Meta",		KeyMoveVDM,
-	ACTION_GOTO_9,		    KD_ALWAYS				},
+	ACTION_GOTO_9,		    KD_VIRTUAL				},
    {    "Screen9",	    	    "F9",		NULLFUNC,
-	ACTION_GOTO_9,		    KD_ALWAYS				},
+	ACTION_GOTO_9,		    KD_VIRTUAL				},
    {    "VirtualScreen10",	    "F10+Meta",		KeyMoveVDM,
-	ACTION_GOTO_10,		    KD_ALWAYS				},
+	ACTION_GOTO_10,		    KD_VIRTUAL				},
    {    "Screen10",	    	    "F10",		NULLFUNC,
-	ACTION_GOTO_10,		    KD_ALWAYS				},
+	ACTION_GOTO_10,		    KD_VIRTUAL				},
 };
 
 #define NUMKEYDESCRIPTORS (sizeof(KeyDescriptorTable)/sizeof(KeyDescriptor))
@@ -652,11 +665,11 @@ static int bindingTableSize = 0;
 static Bool suspended = False;
 static Bool quotenext = False;
 
-
 /*
  * Suspension and resumption of Mouseless functions.
  */
 static void
+/* ARGSUSED */
 keySuspend(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -677,7 +690,6 @@ keyResume(dpy, ke)
     suspended = False;
 }
 
-
 Bool
 IsMouselessSuspended()
 {
@@ -685,6 +697,7 @@ IsMouselessSuspended()
 }
 
 static void
+/* ARGSUSED */
 keyQuoteNext(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -948,7 +961,6 @@ establishKeyBindings(dpy)
     Display *dpy;
 {
     KeyDescriptor *d;
-    KeyBinding *kb;
     modsym syms[MAX_MAPPINGS];
     int nsyms;
     int i, j;
@@ -1004,34 +1016,44 @@ establishKeyBindings(dpy)
  * root window.  Run through the binding table and un/grab the key-modifier
  * combination itself, and also combined with the Lock and NumLock (if any)
  * modifier.  There thus may be up to four actual grabs per key binding.
+ *
+ * If virtual_only is true, we only grab the virtual root keys; this is
+ * e.g. when .olvwmrc changes the keys we're interested in.
  */
 static void
-grabRootKeys(dpy, root, grab)
+grabRootKeys(dpy, root, grab, virtual_only)
     Display *dpy;
     Window root;
     Bool grab;		/* True = grab, False = release */
+    Bool virtual_only;
 {
     KeyBinding *k;
     unsigned int NumLockMask =
 	FindModifierMask(XKeysymToKeycode(dpy, XK_Num_Lock));
+
     for (k=KeyBindingTable; k < KeyBindingTable+bindingTableCount; ++k) {
-	if (k->desc->function != NULLFUNC) {
+	if (k->desc->function != NULLFUNC &&
+	    (!virtual_only || k->desc->action == ACTION_VIRTUAL)) {
 	    if (grab) {
-		XGrabKey(dpy, k->keycode, k->modstate,
+		if (k->desc->action != ACTION_VIRTUAL || GRV.GrabVirtualKeys) {
+		    XGrabKey(dpy, k->keycode, k->modstate,
 			 root, False, GrabModeAsync, GrabModeSync);
-		XGrabKey(dpy, k->keycode, k->modstate | LockMask,
+		    XGrabKey(dpy, k->keycode, k->modstate | LockMask,
 			 root, False, GrabModeAsync, GrabModeSync);
+		}
 	    } else {
 		XUngrabKey(dpy, k->keycode, k->modstate, root);
 		XUngrabKey(dpy, k->keycode, k->modstate|LockMask, root);
 	    }
 	    if (NumLockMask != 0) {
 		if (grab) {
-		    XGrabKey(dpy, k->keycode, k->modstate | NumLockMask,
+		    if (k->desc->action != ACTION_VIRTUAL || GRV.GrabVirtualKeys) {
+		        XGrabKey(dpy, k->keycode, k->modstate | NumLockMask,
 			     root, False, GrabModeAsync, GrabModeSync);
-		    XGrabKey(dpy, k->keycode,
+		        XGrabKey(dpy, k->keycode,
 			     k->modstate | NumLockMask | LockMask,
 			     root, False, GrabModeAsync, GrabModeSync);
+		    }
 		} else {
 		    XUngrabKey(dpy, k->keycode, k->modstate | NumLockMask,
 			       root);
@@ -1113,6 +1135,7 @@ grabRootButtons(dpy, root, grab)
  */
 
 SemanticAction
+/* ARGSUSED */
 FindKeyboardAction(dpy, event)
     Display *dpy;
     XEvent *event;
@@ -1137,6 +1160,7 @@ FindKeyboardAction(dpy, event)
  * similar search as above but starts at the end.
  */
 SemanticAction
+/* ARGSUSED */
 FindNewKeyboardAction(dpy, event)
     Display *dpy;
     XEvent *event;
@@ -1235,33 +1259,51 @@ ExecuteKeyboardFunction(dpy, event)
  * grab = False, release the keys.  Note: the screens and the keyboard binding 
  * information must be initialized prior to calling this function.
  */
+
+void
+GrabVKeys(dpy, grab, virtual_only)
+    Display *dpy;
+    Bool grab;
+    Bool virtual_only;
+{
+    List *l = ScreenInfoList;
+    ScreenInfo *scr;
+    for (scr = ListEnum(&l); scr != NULL; scr = ListEnum(&l))
+	grabRootKeys(dpy, scr->rootid, grab, virtual_only);
+}
+
 void
 GrabKeys(dpy, grab)
     Display *dpy;
     Bool grab;
 {
-    List *l = ScreenInfoList;
-    ScreenInfo *scr;
-    for (scr = ListEnum(&l); scr != NULL; scr = ListEnum(&l))
-	grabRootKeys(dpy, scr->rootid, grab);
+    GrabVKeys(dpy, grab, False);
 }
 
-
 /*
  * Remove all key grabs, zero out the binding table, and rebuild it from the 
  * resource database.  Then, re-establish key grabs.
  */
+
 void
-RefreshKeyGrabs(dpy)
-    Display *dpy;
+RefreshKeyGrabsFile(dpy, file)
+    Display	*dpy;
+    char	*file;
+
 {
     GrabKeys(dpy, False);
     bindingTableCount = 0;
     establishKeyBindings(dpy);
-    ReInitOlvwmRC(dpy);
+    ReInitOlvwmRC(dpy, file);
     GrabKeys(dpy, True);
 }
 
+void
+RefreshKeyGrabs(dpy)
+    Display *dpy;
+{
+    RefreshKeyGrabsFile(dpy, NULL);
+}
 
 /*
  * Deal with button grabs on all root windows.  If grab = True, grab the 
@@ -1310,7 +1352,14 @@ UpdateBindings(dpy, newDB)
     Bool regrab = False;
     static XrmBinding bindings[] =
 	{ XrmBindTightly, XrmBindTightly, XrmBindTightly };
+    int	size = sizeof(mouselessMaskTable) / sizeof(mouselessMaskTable[0]);
+    int	i;
 
+    if (GRV.GrabVirtualKeys)
+        for (i = 0; i < size; i++)
+	    mouselessMaskTable[i] |= KD_VIRTUAL;
+     else for (i = 0; i < size; i++)
+	    mouselessMaskTable[i] &= ~KD_VIRTUAL;
     GrabButtons(dpy, False);
     establishModBindings(dpy, newDB);
     GrabButtons(dpy, True);
@@ -1378,14 +1427,48 @@ void
 InitBindings(dpy)
     Display *dpy;
 {
+int	size = sizeof(mouselessMaskTable) / sizeof(mouselessMaskTable[0]);
+int	i;
+
     kbdCmdInstanceQ = XrmStringToQuark("keyboardCommand");
     kbdCmdClassQ    = XrmStringToQuark("KeyboardCommand");
 
     modInstanceQ    = XrmStringToQuark("modifier");
     modClassQ	    = XrmStringToQuark("Modifier");
 
+    if (GRV.GrabVirtualKeys)
+        for (i = 0; i < size; i++)
+	    mouselessMaskTable[i] |= KD_VIRTUAL;
     KeyBindingTable = MemCalloc(KEYBINDING_TABLE_SIZE,sizeof(KeyBinding));
     bindingTableSize = KEYBINDING_TABLE_SIZE;
     establishKeyBindings(dpy);
     establishModBindings(dpy, OlwmDB);
 }
+
+/*
+ * Disable/Enable program keys in given range
+ */
+void
+SetProgKeys(dpy, start_sym, end_sym, modstate, off)
+    Display *dpy;
+    KeySym start_sym;
+    KeySym end_sym;
+    unsigned long modstate;
+    Boolean off;
+{
+    KeyBinding *k;
+    KeySym keysym;
+    extern CheckForKeyProg();
+
+    for(k=KeyBindingTable; k < KeyBindingTable+bindingTableCount; ++k) {
+      if (k->desc->action == ACTION_VIRTUAL) {
+          keysym = XKeycodeToKeysym(dpy, k->keycode, 0);
+          if ((modstate == 0L || (k->modstate & modstate))
+                  && (start_sym == NoSymbol || keysym >= start_sym)
+                  && (end_sym == NoSymbol || keysym <= end_sym)) {
+              k->desc->function =
+                  off ? NULLFUNC : (void (*)()) CheckForKeyProg;
+          }
+      }
+    }
+}
