@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
+#ifdef IDENT
 #ident	"@(#)gettext.h	1.4	91/09/14 SMI"
+#endif
 
 #define DEFAULT_DOMAIN	"default"
 #define DEFAULT_BINDING "/usr/lib/locale\n"
