@@ -8,7 +8,9 @@
  *	helpcmd.h
  * ---------------------------------------------------------------------*/
 
+#ifdef IDENT
 #ident	"@(#)helpcmd.h	26.6	91/09/14 SMI"
+#endif
 
 #include "cmdstream.h"
 
