@@ -3,7 +3,9 @@
  * license
  */
 
-#ident "@(#)images.c	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident "@(#)images.c	1.4 olvwm version 12/7/92"
+#endif
 
 /* Use small images */
 #define SMALL_IMAGES
@@ -39,10 +41,10 @@ extern int  WindowStickAction();
  *  resource is set, their pixlabels may be adjusted
  */
 
-static Button
+Button
 openButton = {
-    { { StringLabel, "Open", NULL },
-      { StringLabel, "Close", NULL } },
+    { { StringLabel, NULL, NULL },
+      { StringLabel, NULL, NULL } },
     {"window:Open", "window:Close"},
     0,
     False,
@@ -55,10 +57,10 @@ openButton = {
     NULL,
 };
 
-static Button
+Button
 fullSizeButton = {
-    { { StringLabel, "Full Size", NULL },
-      { StringLabel, "Restore Size", NULL } },
+    { { StringLabel, NULL, NULL },
+      { StringLabel, NULL, NULL } },
     {"window:FullSize", "window:RestoreSize"},
     0,
     False,
@@ -71,9 +73,9 @@ fullSizeButton = {
     NULL,
 };
 
-static Button
+Button
 moveButton = {
-    { { StringLabel, "Move", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     {"window:Move", NULL},
     0,
@@ -87,9 +89,9 @@ moveButton = {
     NULL,
 };
 
-static Button
+Button
 resizeButton = {
-    { { StringLabel, "Resize", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     {"window:Resize", NULL},
     0,
@@ -103,10 +105,10 @@ resizeButton = {
     NULL,
 };
 
-static Button
+Button
 stickyButton = {
-    { { StringLabel, "Stick", NULL },
-      { StringLabel, "Unstick", NULL } },
+    { { StringLabel, NULL, NULL },
+      { StringLabel, NULL, NULL } },
     {"window:Stick", "window:Unstick"},
     0,
     False,
@@ -119,9 +121,9 @@ stickyButton = {
     NULL,
 };
 
-static Button
+Button
 propertiesButton = {
-    { { StringLabel, "Properties", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     {"window:Properties", NULL},
     0,
@@ -135,9 +137,9 @@ propertiesButton = {
     NULL,
 };
 
-static Button
+Button
 backButton = {
-    { { StringLabel, "Back", NULL },    /****WINDOW FRONT?*/
+    { { StringLabel, NULL, NULL },    /****WINDOW FRONT?*/
       { NoType, NULL, NULL } },
     {"window:Back", NULL},
     0,
@@ -151,9 +153,9 @@ backButton = {
     NULL,
 };
 
-static Button
+Button
 refreshButton = {
-    { { StringLabel, "Refresh", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     {"window:Refresh", NULL},
     0,
@@ -167,9 +169,9 @@ refreshButton = {
     NULL,
 };
 
-static Button
+Button
 quitButton = {
-    { { StringLabel, "Quit", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     {"window:Quit", NULL},
     0,
@@ -183,9 +185,9 @@ quitButton = {
     NULL,
 };
 
-static Button
+Button
 dismissButton = {
-    { { StringLabel, "Dismiss", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     {"window:Dismiss", NULL},
     0,
@@ -199,9 +201,9 @@ dismissButton = {
     NULL,
 };
 
-static Button
+Button
 dismissThisButton = {
-    { { StringLabel, "This Window", NULL},
+    { { StringLabel, NULL, NULL},
       { NoType, NULL, NULL } },
     {"window:DismissThis", NULL},
     0,
@@ -215,9 +217,9 @@ dismissThisButton = {
     NULL,
 };
 
-static Button
+Button
 dismissAllButton = {
-    { { StringLabel, "All Pop-ups", NULL},
+    { { StringLabel, NULL, NULL},
       { NoType, NULL, NULL } },
     {"window:DismissAll", NULL},
     0,
@@ -231,9 +233,9 @@ dismissAllButton = {
     NULL,
 };
 
-static Button
+Button
 ownerButton = {
-    { { StringLabel, "Owner?", NULL},
+    { { StringLabel, NULL, NULL},
       { NoType, NULL, NULL } },
     {"window:Owner", NULL},
     0,
@@ -252,7 +254,7 @@ extern int	VDMMenuAction();
  * Menu buttons for VDM motion menu
  */
 Button moveRightButton = {
-    { { StringLabel, "Move East", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     { "virtual:Move", NULL },
     0,
@@ -264,7 +266,7 @@ Button moveRightButton = {
 };
  
 Button moveLeftButton = {
-    { { StringLabel, "Move West", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     { "virtual:Move", NULL },
     0,
@@ -276,7 +278,7 @@ Button moveLeftButton = {
 };
  
 Button moveUpButton = {
-    { { StringLabel, "Move North", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     { "virtual:Move", NULL },
     0,
@@ -288,7 +290,7 @@ Button moveUpButton = {
 };
 
 Button moveDownButton = {
-    { { StringLabel, "Move South", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     { "virtual:Move", NULL },
     0,
@@ -300,7 +302,7 @@ Button moveDownButton = {
 };
 
 Button moveUpRightButton = {
-    { { StringLabel, "Move NorthEast", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     { "virtual:Move", NULL },
     0,
@@ -312,7 +314,7 @@ Button moveUpRightButton = {
 };
 
 Button moveDownRightButton = {
-    { { StringLabel, "Move SouthEast", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     { "virtual:Move", NULL },
     0,
@@ -324,7 +326,7 @@ Button moveDownRightButton = {
 };
 
 Button moveUpLeftButton = {
-    { { StringLabel, "Move NorthWest", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     { "virtual:Move", NULL },
     0,
@@ -336,7 +338,7 @@ Button moveUpLeftButton = {
 };
 
 Button moveDownLeftButton = {
-    { { StringLabel, "Move SouthWest", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     { "virtual:Move", NULL },
     0,
@@ -348,7 +350,7 @@ Button moveDownLeftButton = {
 };
 
 Button moveHomeButton = {
-    { { StringLabel, "Move Home", NULL },
+    { { StringLabel, NULL, NULL },
       { NoType, NULL, NULL } },
     { "virtual:Move", NULL },
     0,
@@ -366,7 +368,7 @@ Button moveHomeButton = {
 
 #define Close_width 16
 #define Close_height 14
-static char     Close_bits[] = {
+static unsigned char     Close_bits[] = {
     0xc0, 0x3f, 0x40, 0x20, 0x40, 0x20, 0x40, 0xa1, 0xc0, 0x60, 0x64, 0xa0,
     0x5c, 0x60, 0x5c, 0xa0, 0xff, 0x7f, 0x05, 0xaa, 0x07, 0x55, 0x14, 0xaa,
     0x08, 0x00, 0x14, 0x00,
@@ -374,7 +376,7 @@ static char     Close_bits[] = {
 
 #define Open_width 16
 #define Open_height 14
-static char     Open_bits[] = {
+static unsigned char     Open_bits[] = {
     0xc0, 0x3f, 0x40, 0x20, 0xc0, 0x27, 0x40, 0xa7, 0x40, 0x67, 0xc0, 0xa4,
     0x60, 0x60, 0x50, 0xa0, 0xcf, 0x7f, 0x05, 0xaa, 0x07, 0x55, 0x14, 0xaa,
     0x08, 0x00, 0x14, 0x00,
@@ -382,7 +384,7 @@ static char     Open_bits[] = {
 
 #define FullSize_width 16
 #define FullSize_height 14
-static char     FullSize_bits[] = {
+static unsigned char     FullSize_bits[] = {
     0xf8, 0x7, 0x8, 0x4, 0x8, 0x4, 0x8, 0x14, 0x8, 0xc, 0x8, 0x14, 0xc8, 0xc,
     0xc8, 0x14, 0xc8, 0xc, 0xf8, 0x17, 0xe8, 0xd, 0xc8, 0x14, 0xf8, 0xf, 0x40,
     0x15,
@@ -390,14 +392,14 @@ static char     FullSize_bits[] = {
 
 #define NormalSize_width 16
 #define NormalSize_height 14
-static char     NormalSize_bits[] = {
+static unsigned char     NormalSize_bits[] = {
     0xf8, 0x7, 0x8, 0x4, 0x8, 0x4, 0x8, 0x14, 0x8, 0xc, 0x8, 0x14, 0x8, 0xc,
     0x8, 0x14, 0xf8, 0xf, 0xc0, 0x14, 0xe0, 0xb, 0xf0, 0x17, 0xc0, 0x0, 0xc0, 0x0,
 };
 
 #define Props_width 16
 #define Props_height 14
-static char     Props_bits[] = {
+static unsigned char     Props_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0xfe, 0x1f, 0x02, 0x10, 0xfa, 0x57, 0x02, 0x30,
     0xda, 0x56, 0x02, 0x30, 0x02, 0x50, 0xfe, 0x3f, 0x50, 0x55, 0xa8, 0x2a,
     0x50, 0x55, 0x00, 0x00,
@@ -405,7 +407,7 @@ static char     Props_bits[] = {
 
 #define Back_width 16
 #define Back_height 14
-static char     Back_bits[] = {
+static unsigned char     Back_bits[] = {
     0xff, 0x00, 0x81, 0x0f, 0x81, 0x3f, 0x81, 0x72, 0x81, 0xc2, 0x81, 0xaa,
     0x81, 0xb6, 0x81, 0xfa, 0xff, 0x7e, 0x04, 0x3a, 0xfc, 0x37, 0xa0, 0x2a,
     0x40, 0x05, 0xa0, 0x0a,
@@ -413,7 +415,7 @@ static char     Back_bits[] = {
 
 #define Refresh_width 16
 #define Refresh_height 14
-static char     Refresh_bits[] = {
+static unsigned char     Refresh_bits[] = {
     0x00, 0x00, 0xf8, 0x07, 0x48, 0x05, 0xc8, 0x07, 0x08, 0x14, 0x08, 0x0c,
     0x48, 0x14, 0x28, 0x0d, 0x08, 0x14, 0xf8, 0x0f, 0x40, 0x15, 0xa0, 0x0a,
     0x40, 0x15, 0x00, 0x00,
@@ -421,7 +423,7 @@ static char     Refresh_bits[] = {
 
 #define Stick_width 16
 #define Stick_height 14
-static char     Stick_bits[] = {
+static unsigned char     Stick_bits[] = {
     0xb0, 0x0f, 0xf0, 0x1f, 0xb0, 0x23, 0x40, 0x29, 0x80, 0x57, 0x87, 0x8b,
     0x82, 0x07, 0x82, 0x0b, 0x96, 0x07, 0x8a, 0x0b, 0x82, 0x07, 0x8a, 0x0b,
     0x00, 0x04, 0x08, 0x0a,
@@ -429,7 +431,7 @@ static char     Stick_bits[] = {
 
 #define UnStick_width 16
 #define UnStick_height 14
-static char     UnStick_bits[] = {
+static unsigned char     UnStick_bits[] = {
     0x04, 0x00, 0x02, 0x00, 0x03, 0x00, 0x13, 0x00, 0xff, 0x1f, 0xff, 0x1f,
     0xff, 0x1f, 0x56, 0x55, 0xaf, 0x2a, 0x57, 0x55, 0x08, 0x00, 0x17, 0x00,
     0x0a, 0x00, 0x02, 0x00,
@@ -437,7 +439,7 @@ static char     UnStick_bits[] = {
 
 #define Quit_width 16
 #define Quit_height 14
-static char     Quit_bits[] = {
+static unsigned char     Quit_bits[] = {
     0x10, 0x04, 0x38, 0x0e, 0x7c, 0x1f, 0xf8, 0x0f, 0xf0, 0x17, 0xe8, 0x2b,
     0xf0, 0x17, 0xf8, 0x0f, 0x7c, 0x1f, 0xb8, 0x0e, 0x50, 0x15, 0xa8, 0x2a,
     0x50, 0x14, 0x20, 0x08,
@@ -445,23 +447,25 @@ static char     Quit_bits[] = {
 
 #define Resize_width 16
 #define Resize_height 14
-static char Resize_bits[] = {
-   0x2e, 0x00, 0x4a, 0x01, 0x8e, 0x01, 0xc0, 0x01, 0x02, 0x00, 0x94, 0xff,
-   0x98, 0x80, 0x9c, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80,
-   0x80, 0x80, 0x80, 0xff};
+static unsigned char Resize_bits[] = {
+    0xf8, 0x07, 0x08, 0x04, 0x08, 0x04, 0x08, 0x14, 0xc8, 0x0d, 0xc8, 0x14,
+    0x48, 0x0d, 0x08, 0x16, 0xf8, 0x07, 0x40, 0x29, 0xa0, 0x32, 0x40, 0xb9,
+    0x00, 0x40, 0x00, 0xa0,
+};
 
 #define Move_width 16
 #define Move_height 14
-static char Move_bits[] = {
-   0xfe, 0x00, 0x82, 0x00, 0x82, 0x02, 0x82, 0x24, 0x82, 0x28, 0xfe, 0x30,
-   0x00, 0x3c, 0x04, 0x00, 0x48, 0x7f, 0x50, 0x41, 0x60, 0x41, 0x78, 0x41,
-   0x00, 0x41, 0x00, 0x7f};
+static unsigned char Move_bits[] = {
+   0xc0, 0x3f, 0x40, 0x20, 0x40, 0x20, 0x40, 0xa0, 0xc0, 0x63, 0x6a, 0xa3,
+   0xc1, 0x62, 0x40, 0xa0, 0xe1, 0x7f, 0x90, 0xaa, 0x09, 0x54, 0x80, 0xaa,
+   0x01, 0x00, 0xaa, 0x00,
+};
 
 #else SMALL_IMAGES
 
 #define Back_width 32
 #define Back_height 32
-static char Back_bits[] = {
+static unsigned char Back_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 0xff, 0x00, 0x00,
    0x14, 0x80, 0x00, 0x00, 0xfc, 0xff, 0x00, 0x00, 0x04, 0x80, 0xff, 0x01,
@@ -477,7 +481,7 @@ static char Back_bits[] = {
 
 #define Close_width 32
 #define Close_height 32
-static char Close_bits[] = {
+static unsigned char Close_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0x00, 0x40, 0x01, 0x08,
    0x00, 0xc0, 0xff, 0x0f, 0x00, 0x40, 0x00, 0x08, 0x00, 0x40, 0x04, 0x58,
@@ -493,7 +497,7 @@ static char Close_bits[] = {
 
 #define FullSize_width 32
 #define FullSize_height 32
-static char FullSize_bits[] = {
+static unsigned char FullSize_bits[] = {
    0x00, 0xfc, 0xff, 0x00, 0x00, 0x14, 0x80, 0x00, 0x00, 0xfc, 0xff, 0x00,
    0x00, 0x04, 0x80, 0x00, 0x00, 0x04, 0x80, 0x05, 0xc0, 0xff, 0x8f, 0x0a,
    0x40, 0x01, 0x88, 0x05, 0xc0, 0xff, 0x9f, 0x0a, 0x40, 0x00, 0x88, 0x05,
@@ -509,7 +513,7 @@ static char FullSize_bits[] = {
 
 #define Move_width 32
 #define Move_height 32
-static char Move_bits[] = {
+static unsigned char Move_bits[] = {
    0x00, 0x00, 0xfc, 0xff, 0x00, 0x00, 0x14, 0x80, 0x00, 0x00, 0xfc, 0xff,
    0x00, 0x00, 0x04, 0x80, 0x00, 0x00, 0x04, 0x80, 0x00, 0x00, 0xfe, 0x80,
    0x00, 0x00, 0xfc, 0x80, 0x00, 0x00, 0xf4, 0x80, 0x00, 0x00, 0xfc, 0x80,
@@ -525,7 +529,7 @@ static char Move_bits[] = {
 
 #define NormalSize_width 32
 #define NormalSize_height 32
-static char NormalSize_bits[] = {
+static unsigned char NormalSize_bits[] = {
    0x00, 0xfc, 0xff, 0x00, 0x00, 0x14, 0x80, 0x00, 0x00, 0xfc, 0xff, 0x00,
    0x00, 0x04, 0x80, 0x00, 0x00, 0x04, 0x80, 0x05, 0xc0, 0xff, 0x8f, 0x0a,
    0x40, 0x01, 0x88, 0x05, 0xc0, 0xff, 0x9f, 0x0a, 0x40, 0x00, 0x88, 0x05,
@@ -541,7 +545,7 @@ static char NormalSize_bits[] = {
 
 #define Open_width 32
 #define Open_height 32
-static char Open_bits[] = {
+static unsigned char Open_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0x00, 0x40, 0x01, 0x08,
    0x00, 0xc0, 0xff, 0x0f, 0x00, 0x40, 0x00, 0x08, 0x00, 0x40, 0x00, 0x58,
@@ -557,7 +561,7 @@ static char Open_bits[] = {
 
 #define Props_width 32
 #define Props_height 32
-static char Props_bits[] = {
+static unsigned char Props_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
@@ -573,7 +577,7 @@ static char Props_bits[] = {
 
 #define Quit_width 32
 #define Quit_height 32
-static char Quit_bits[] = {
+static unsigned char Quit_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 0x01, 0x00, 0x00, 0xff, 0x07, 0x00,
    0xc0, 0x03, 0x1e, 0x00, 0xe0, 0x00, 0x38, 0x00, 0x70, 0x00, 0x70, 0x00,
    0xb8, 0xff, 0xff, 0x00, 0x98, 0x02, 0xdc, 0x00, 0x8c, 0xff, 0x9f, 0x01,
@@ -589,7 +593,7 @@ static char Quit_bits[] = {
 
 #define Refresh_width 32
 #define Refresh_height 32
-static char Refresh_bits[] = {
+static unsigned char Refresh_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x80, 0xff, 0x1f, 0x00, 0x80, 0x02, 0x10, 0x00, 0x80, 0xff, 0x18, 0x00,
@@ -605,7 +609,7 @@ static char Refresh_bits[] = {
 
 #define Resize_width 32
 #define Resize_height 32
-static char Resize_bits[] = {
+static unsigned char Resize_bits[] = {
    0xff, 0x03, 0x00, 0x00, 0x05, 0x02, 0x00, 0x00, 0xff, 0x03, 0x00, 0x00,
    0x01, 0x02, 0x00, 0x00, 0x01, 0x02, 0x00, 0x00, 0x01, 0x02, 0x00, 0x00,
    0x41, 0x02, 0x00, 0x00, 0xe1, 0x02, 0x00, 0x00, 0xc1, 0x03, 0x00, 0x00,
@@ -621,7 +625,7 @@ static char Resize_bits[] = {
 
 #define Stick_width 32
 #define Stick_height 32
-static char Stick_bits[] = {
+static unsigned char Stick_bits[] = {
    0x00, 0x0e, 0xff, 0x00, 0x00, 0x9e, 0xff, 0x03, 0x00, 0xfe, 0xff, 0x07,
    0x00, 0xfe, 0xff, 0x0f, 0x00, 0x9e, 0x5f, 0x0d, 0x00, 0x6e, 0xaf, 0x3a,
    0x00, 0xd0, 0x56, 0x51, 0x00, 0xa0, 0xae, 0x20, 0x00, 0x50, 0x5f, 0x40,
@@ -637,7 +641,7 @@ static char Stick_bits[] = {
 
 #define UnStick_width 32
 #define UnStick_height 32
-static char UnStick_bits[] = {
+static unsigned char UnStick_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x00, 0x00, 0x70, 0x00, 0x00, 0x00,
    0x38, 0x00, 0x00, 0x00, 0x1c, 0x04, 0x00, 0x00, 0x9c, 0x02, 0x00, 0x00,
    0x5e, 0x01, 0x00, 0x00, 0xbe, 0x00, 0x00, 0x00, 0x5e, 0x00, 0x00, 0x00,
@@ -657,69 +661,67 @@ static char UnStick_bits[] = {
  */
 #define ArwUpLeft_width 16
 #define ArwUpLeft_height 14
-static char ArwUpLeft_bits[] = {
+static unsigned char ArwUpLeft_bits[] = {
 0xfe,0x07, 0x02,0x02, 0x02,0x01, 0x82,0x00, 0x02,0x01, 0x02,0x02, 0x12,0x04,
 0x2a,0x08, 0x46,0x10, 0x82,0x20, 0x00,0x11, 0x00,0x0a, 0x00,0x04, 0x00,0x00,
 };
 
 #define ArwLeft_width 16
 #define ArwLeft_height 14
-static char ArwLeft_bits[] = {
+static unsigned char ArwLeft_bits[] = {
 0x80,0x00, 0xc0,0x00, 0xa0,0x00, 0x90,0x00, 0x88,0x7f, 0x04,0x40, 0x02,0x40,
 0x04,0x40, 0x88,0x7f, 0x90,0x00, 0xa0,0x00, 0xc0,0x00, 0x80,0x00, 0x00,0x00,
 };
 
 #define ArwDownLeft_width 16
 #define ArwDownLeft_height 14
-static char ArwDownLeft_bits[] = {
+static unsigned char ArwDownLeft_bits[] = {
 0x00,0x00, 0x00,0x04, 0x00,0x0a, 0x00,0x11, 0x82,0x20, 0x46,0x10, 0x2a,0x08,
 0x12,0x04, 0x02,0x02, 0x02,0x01, 0x82,0x00, 0x02,0x01, 0x02,0x02, 0xfe,0x07,
 };
 
 #define ArwUp_width 16
 #define ArwUp_height 14
-static char ArwUp_bits[] = {
+static unsigned char ArwUp_bits[] = {
 0x80,0x00, 0x40,0x01, 0x20,0x02, 0x10,0x04, 0x08,0x08, 0x04,0x10, 0x3e,0x3e,
 0x20,0x02, 0x20,0x02, 0x20,0x02, 0x20,0x02, 0x20,0x02, 0x20,0x02, 0xe0,0x03,
 };
 
 #define ArwHome_width 16
 #define ArwHome_height 14
-static char ArwHome_bits[] = {
+static unsigned char ArwHome_bits[] = {
 0x80,0x00, 0x40,0x0d, 0x20,0x0e, 0x10,0x0c, 0x08,0x08, 0x04,0x10, 0xfe,0x3f,
 0x04,0x10, 0x74,0x17, 0x54,0x15, 0x54,0x17, 0x54,0x10, 0xfc,0x1f, 0x00,0x00,
 };
 
 #define ArwDown_width 16
 #define ArwDown_height 14
-static char ArwDown_bits[] = {
+static unsigned char ArwDown_bits[] = {
 0xe0,0x03, 0x20,0x02, 0x20,0x02, 0x20,0x02, 0x20,0x02, 0x20,0x02, 0x20,0x02,
 0x3e,0x3e, 0x04,0x10, 0x08,0x08, 0x10,0x04, 0x20,0x02, 0x40,0x01, 0x80,0x00,
 };
 
 #define ArwUpRight_width 16
 #define ArwUpRight_height 14
-static char ArwUpRight_bits[] = {
+static unsigned char ArwUpRight_bits[] = {
 0xe0,0x7f, 0x40,0x40, 0x80,0x40, 0x00,0x41, 0x80,0x40, 0x40,0x40, 0x20,0x48,
 0x10,0x54, 0x08,0x62, 0x04,0x41, 0x88,0x00, 0x50,0x00, 0x20,0x00, 0x00,0x00,
 };
 
 #define ArwRight_width 16
 #define ArwRight_height 14
-static char ArwRight_bits[] = {
+static unsigned char ArwRight_bits[] = {
 0x00,0x01, 0x00,0x03, 0x00,0x05, 0x00,0x09, 0xfe,0x11, 0x02,0x20, 0x02,0x40,
 0x02,0x20, 0xfe,0x11, 0x00,0x09, 0x00,0x05, 0x00,0x03, 0x00,0x01, 0x00,0x00,
 };
 
 #define ArwDownRight_width 16
 #define ArwDownRight_height 14
-static char ArwDownRight_bits[] = {
+static unsigned char ArwDownRight_bits[] = {
 0x00,0x00, 0x20,0x00, 0x50,0x00, 0x88,0x00, 0x04,0x41, 0x08,0x62, 0x10,0x54,
 0x20,0x48, 0x40,0x40, 0x80,0x40, 0x00,0x41, 0x80,0x40, 0x40,0x40, 0xe0,0x7f,
 };
 
-extern Button	openButton;
-
 Button *
 MakeOpenButton(dpy, scrInfo)
     Display	*dpy;
@@ -735,7 +737,7 @@ static int openbuttoninit = 0;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				Open_bits, Open_width, Open_height,
+				(char *) Open_bits, Open_width, Open_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -745,7 +747,7 @@ static int openbuttoninit = 0;
 	b->label[1].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[1].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				Close_bits, Close_width, Close_height,
+				(char *) Close_bits, Close_width, Close_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -753,10 +755,6 @@ static int openbuttoninit = 0;
 	b->label[1].pixlabel->height = Close_height;
 	b->label[1].kind = ComboLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -773,7 +771,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				FullSize_bits, FullSize_width, FullSize_height,
+				(char *) FullSize_bits, FullSize_width, FullSize_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -782,7 +780,7 @@ Button	*b;
 	b->label[0].kind = ComboLabel;
 	b->label[1].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[1].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
-				scrInfo->rootid, NormalSize_bits,
+				scrInfo->rootid, (char *) NormalSize_bits,
 				NormalSize_width, NormalSize_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
@@ -791,10 +789,6 @@ Button	*b;
 	b->label[1].pixlabel->height = NormalSize_height;
 	b->label[1].kind = ComboLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -811,7 +805,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				Stick_bits, Stick_width, Stick_height,
+				(char *) Stick_bits, Stick_width, Stick_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -820,7 +814,7 @@ Button	*b;
 	b->label[0].kind = ComboLabel;
 	b->label[1].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[1].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
-				scrInfo->rootid, UnStick_bits,
+				scrInfo->rootid, (char *) UnStick_bits,
 				UnStick_width, UnStick_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
@@ -829,10 +823,6 @@ Button	*b;
 	b->label[1].pixlabel->height = UnStick_height;
 	b->label[1].kind = ComboLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -849,7 +839,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				Props_bits, Props_width, Props_height,
+				(char *) Props_bits, Props_width, Props_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -857,10 +847,6 @@ Button	*b;
 	b->label[0].pixlabel->height = Props_height;
 	b->label[0].kind = ComboLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -877,7 +863,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				Back_bits, Back_width, Back_height,
+				(char *) Back_bits, Back_width, Back_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -885,10 +871,6 @@ Button	*b;
 	b->label[0].pixlabel->height = Back_height;
 	b->label[0].kind = ComboLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -905,7 +887,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				Resize_bits, Resize_width, Resize_height,
+				(char *) Resize_bits, Resize_width, Resize_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -913,10 +895,6 @@ Button	*b;
 	b->label[0].pixlabel->height = Resize_height;
 	b->label[0].kind = ComboLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -933,7 +911,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				Move_bits, Move_width, Move_height,
+				(char *) Move_bits, Move_width, Move_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -941,10 +919,6 @@ Button	*b;
 	b->label[0].pixlabel->height = Move_height;
 	b->label[0].kind = ComboLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -961,7 +935,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				Quit_bits, Quit_width, Quit_height,
+				(char *) Quit_bits, Quit_width, Quit_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -969,10 +943,6 @@ Button	*b;
 	b->label[0].pixlabel->height = Quit_height;
 	b->label[0].kind = ComboLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -989,7 +959,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				Refresh_bits, Refresh_width, Refresh_height,
+				(char *) Refresh_bits, Refresh_width, Refresh_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -997,14 +967,11 @@ Button	*b;
 	b->label[0].pixlabel->height = Refresh_height;
 	b->label[0].kind = ComboLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
 Button *
+/* ARGSUSED */
 MakeDismissButton(dpy, scrInfo)
     Display	*dpy;
     ScreenInfo	*scrInfo;
@@ -1013,14 +980,11 @@ Button	*b;
 
     b = (Button *) MemAlloc(sizeof(Button));
     *b = dismissButton;
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
 Button *
+/* ARGSUSED */
 MakeDismissAllButton(dpy, scrInfo)
     Display	*dpy;
     ScreenInfo	*scrInfo;
@@ -1029,14 +993,11 @@ Button	*b;
 
     b = (Button *) MemAlloc(sizeof(Button));
     *b = dismissAllButton;
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
 Button *
+/* ARGSUSED */
 MakeDismissThisButton(dpy, scrInfo)
     Display	*dpy;
     ScreenInfo	*scrInfo;
@@ -1045,14 +1006,11 @@ Button	*b;
 
     b = (Button *) MemAlloc(sizeof(Button));
     *b = dismissThisButton;
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
 Button *
+/* ARGSUSED */
 MakeOwnerButton(dpy, scrInfo)
     Display	*dpy;
     ScreenInfo	*scrInfo;
@@ -1061,10 +1019,6 @@ Button	*b;
 
     b = (Button *) MemAlloc(sizeof(Button));
     *b = ownerButton;
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -1080,7 +1034,7 @@ Button	*b;
     if (GRV.UseImageMenu != UseNone) {
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
-				scrInfo->rootid, ArwUpLeft_bits,
+				scrInfo->rootid, (char *) ArwUpLeft_bits,
 				ArwUpLeft_width, ArwUpLeft_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
@@ -1089,10 +1043,6 @@ Button	*b;
 	b->label[0].pixlabel->height = ArwUpLeft_height;
 	b->label[0].kind = ImageLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -1109,7 +1059,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				ArwLeft_bits, ArwLeft_width, ArwLeft_height,
+				(char *) ArwLeft_bits, ArwLeft_width, ArwLeft_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -1117,10 +1067,6 @@ Button	*b;
 	b->label[0].pixlabel->height = ArwLeft_height;
 	b->label[0].kind = ImageLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -1136,7 +1082,7 @@ Button	*b;
     if (GRV.UseImageMenu != UseNone) {
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
-				scrInfo->rootid, ArwDownLeft_bits,
+				scrInfo->rootid, (char *) ArwDownLeft_bits,
 				ArwDownLeft_width, ArwDownLeft_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
@@ -1145,10 +1091,6 @@ Button	*b;
 	b->label[0].pixlabel->height = ArwDownLeft_height;
 	b->label[0].kind = ImageLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -1165,7 +1107,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				ArwUp_bits, ArwUp_width, ArwUp_height,
+				(char *) ArwUp_bits, ArwUp_width, ArwUp_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -1173,10 +1115,6 @@ Button	*b;
 	b->label[0].pixlabel->height = ArwUp_height;
 	b->label[0].kind = ImageLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -1193,7 +1131,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				ArwHome_bits, ArwHome_width, ArwHome_height,
+				(char *) ArwHome_bits, ArwHome_width, ArwHome_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -1201,10 +1139,6 @@ Button	*b;
 	b->label[0].pixlabel->height = ArwHome_height;
 	b->label[0].kind = ImageLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -1221,7 +1155,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				ArwDown_bits, ArwDown_width, ArwDown_height,
+				(char *) ArwDown_bits, ArwDown_width, ArwDown_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -1229,10 +1163,6 @@ Button	*b;
 	b->label[0].pixlabel->height = ArwDown_height;
 	b->label[0].kind = ImageLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -1248,7 +1178,7 @@ Button	*b;
     if (GRV.UseImageMenu != UseNone) {
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
-				scrInfo->rootid, ArwUpRight_bits,
+				scrInfo->rootid, (char *) ArwUpRight_bits,
 				ArwUpRight_width, ArwUpRight_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
@@ -1257,10 +1187,6 @@ Button	*b;
 	b->label[0].pixlabel->height = ArwUpRight_height;
 	b->label[0].kind = ImageLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -1277,7 +1203,7 @@ Button	*b;
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
 				scrInfo->rootid,
-				ArwRight_bits, ArwRight_width, ArwRight_height,
+				(char *) ArwRight_bits, ArwRight_width, ArwRight_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
 				scrInfo->depth);
@@ -1285,10 +1211,6 @@ Button	*b;
 	b->label[0].pixlabel->height = ArwRight_height;
 	b->label[0].kind = ImageLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
 
@@ -1304,7 +1226,7 @@ Button	*b;
     if (GRV.UseImageMenu != UseNone) {
 	b->label[0].pixlabel = (Pixlabel *) MemAlloc(sizeof(Pixlabel));
 	b->label[0].pixlabel->pixmap = XCreatePixmapFromBitmapData(dpy,
-				scrInfo->rootid, ArwDownRight_bits,
+				scrInfo->rootid, (char *) ArwDownRight_bits,
 				ArwDownRight_width, ArwDownRight_height,
 				scrInfo->colorInfo.fgColor,
 				scrInfo->colorInfo.bg1Color,
@@ -1313,9 +1235,5 @@ Button	*b;
 	b->label[0].pixlabel->height = ArwDownRight_height;
 	b->label[0].kind = ImageLabel;
     }
-#ifdef OW_I18N_L3
-    b->label[0].string = gettext(b->label[0].string);
-    b->label[1].string = gettext(b->label[1].string);
-#endif
     return b;
 }
