@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)kbdfuncs.c	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident	"@(#)kbdfuncs.c	1.4 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -329,8 +331,6 @@ selectNextPrevWindow(dpy, ke, prev)
     XKeyEvent *ke;
     Bool prev;
 {
-    GroupID grpid;
-    Group *group;
     FindClosure closure;
 
     if (ke->type != KeyPress)
@@ -373,7 +373,6 @@ selectNextPrevApp(dpy, ke, prev)
     Client *next = NULL;
     Client *first = NULL;
     List *l = ActiveClientList;
-    int cmp;
     Bool seencur = False;
 
     if (ke->type != KeyPress)
@@ -524,6 +523,8 @@ KeyRaiseLowerPointer(dpy, ke)
      * override-redirect windows.
      */
     if (childUnderPointer(dpy, ke, &child, &childinfo, &cli)) {
+	if (cli->wmDecors->flags & WMNoDecor)
+	    return;
 	if (cli->transientFor != 0 &&
 		GRV.KeepTransientsAbove &&
 		(owner = WIGetInfo(cli->transientFor)) != NULL &&
@@ -575,7 +576,8 @@ KeyOpenClosePointer(dpy, ke)
     if (ke->type != KeyPress)
 	return;
 
-    if (childUnderPointer(dpy, ke, &child, &childinfo, &cli))
+    if (childUnderPointer(dpy, ke, &child, &childinfo, &cli) &&
+		!(cli->wmDecors->flags & WMNoDecor))
 	ClientOpenCloseToggle(cli);
 }
 
@@ -690,6 +692,7 @@ KeyTogglePin(dpy, ke)
  * Refresh the active window.
  */
 void
+/* ARGSUSED */
 KeyRefresh(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -706,6 +709,7 @@ KeyRefresh(dpy, ke)
  * Raise the active window to the front.
  */
 void
+/* ARGSUSED */
 KeyFrontFocus(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -713,7 +717,8 @@ KeyFrontFocus(dpy, ke)
     if (ke->type != KeyPress)
 	return;
 
-    if (CurrentClient->framewin != NULL)
+    if (CurrentClient->framewin != NULL &&
+		!(CurrentClient->wmDecors->flags & WMNoDecor))
 	ClientFront(CurrentClient);
 }
 
@@ -722,6 +727,7 @@ KeyFrontFocus(dpy, ke)
  * Send the active window to the back.
  */
 void
+/* ARGSUSED */
 KeyBackFocus(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -729,7 +735,8 @@ KeyBackFocus(dpy, ke)
     if (ke->type != KeyPress)
 	return;
 
-    if (CurrentClient->framewin != NULL)
+    if (CurrentClient->framewin != NULL &&
+		!(CurrentClient->wmDecors->flags & WMNoDecor))
 	ClientBack(CurrentClient);
 }
 
@@ -738,6 +745,7 @@ KeyBackFocus(dpy, ke)
  * Toggle the open/close state of the active window.
  */
 void
+/* ARGSUSED */
 KeyOpenCloseFocus(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -745,7 +753,8 @@ KeyOpenCloseFocus(dpy, ke)
     if (ke->type != KeyPress)
 	return;
 
-    if (CurrentClient->framewin != NULL)
+    if (CurrentClient->framewin != NULL &&
+		!(CurrentClient->wmDecors->flags & WMNoDecor))
 	ClientOpenCloseToggle(CurrentClient);
 }
 
@@ -754,6 +763,7 @@ KeyOpenCloseFocus(dpy, ke)
  * Toggle the full/restored size of the active window.
  */
 void
+/* ARGSUSED */
 KeyFullRestore(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -761,7 +771,8 @@ KeyFullRestore(dpy, ke)
     if (ke->type != KeyPress)
 	return;
 
-    if (CurrentClient->framewin != NULL)
+    if (CurrentClient->framewin != NULL &&
+		!(CurrentClient->wmDecors->flags & WMNoDecor))
 	ClientFullRestoreSizeToggle(CurrentClient);
 }
 
@@ -770,6 +781,7 @@ KeyFullRestore(dpy, ke)
  * Quit the active window.
  */
 void
+/* ARGSUSED */
 KeyQuit(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -777,7 +789,8 @@ KeyQuit(dpy, ke)
     if (ke->type != KeyPress)
 	return;
 
-    if (CurrentClient->framewin != NULL)
+    if (CurrentClient->framewin != NULL &&
+		!(CurrentClient->wmDecors->flags & WMNoDecor))
 	ClientKill(CurrentClient, True);
 }
 
@@ -786,6 +799,7 @@ KeyQuit(dpy, ke)
  * Flash the owner window of the active window.
  */
 void
+/* ARGSUSED */
 KeyOwner(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -802,6 +816,7 @@ KeyOwner(dpy, ke)
  * Move the active window.
  */
 void
+/* ARGSUSED */
 KeyMove(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -809,7 +824,8 @@ KeyMove(dpy, ke)
     if (ke->type != KeyPress)
 	return;
 
-    if (CurrentClient->framewin != NULL)
+    if (CurrentClient->framewin != NULL &&
+		!(CurrentClient->wmDecors->flags & WMNoDecor))
 	ClientMove(CurrentClient,ke);
 }
 
@@ -818,6 +834,7 @@ KeyMove(dpy, ke)
  * Resize the active window.
  */
 void
+/* ARGSUSED */
 KeyResize(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -825,7 +842,8 @@ KeyResize(dpy, ke)
     if (ke->type != KeyPress)
 	return;
 
-    if (CurrentClient->framewin != NULL)
+    if (CurrentClient->framewin != NULL &&
+		!(CurrentClient->wmDecors->flags & WMNoDecor))
 	ClientResize(CurrentClient, ke, keyevent, NULL, NULL);
 }
 
@@ -834,6 +852,7 @@ KeyResize(dpy, ke)
  * Bring up the Properties window for the active window.
  */
 void
+/* ARGSUSED */
 KeyProperties(dpy, ke)
     Display *dpy;
     XKeyEvent *ke;
@@ -874,3 +893,74 @@ KeyWindowMenu(dpy, ke)
 	ShowStandardMenu(frameInfo, ke, False);
     }
 }
+
+ /*
+  * Toggle the resource FullSizeZoomX.
+  */
+void
+/* ARGSUSED */
+KeyToggleFullSizeZoomX(dpy, ke)
+     Display *dpy;
+     XKeyEvent *ke;
+{
+     if (ke->type != KeyPress)
+	 return;
+     GRV.FullSizeZoomX = !GRV.FullSizeZoomX;
+}
+
+ /*
+  * Toggle the resource DragWindow
+  */
+void
+/* ARGSUSED */
+KeyToggleDragWindow(dpy, ke)
+     Display *dpy;
+     XKeyEvent *ke;
+{
+     if (ke->type != KeyPress)
+	 return;
+     GRV.DragWindow = !GRV.DragWindow;
+}
+
+ /*
+  * Toggle the resource VirtualMoveGroups resource
+  */
+void
+/* ARGSUSED */
+KeyToggleMoveGroups(dpy, ke)
+     Display *dpy;
+     XKeyEvent *ke;
+{
+     if (ke->type != KeyPress)
+	 return;
+     GRV.VirtualMoveGroups = !GRV.VirtualMoveGroups;
+}
+
+/*
+ * Perform the Stick/Unstick Action
+ */
+void
+/* ARGSUSED */
+KeyToggleSticky(dpy, ke)
+     Display *dpy;
+     XKeyEvent *ke;
+{
+     if (ke->type != KeyPress)
+	 return;
+     if (CurrentClient->framewin != NULL &&
+		!(CurrentClient->wmDecors->flags & WMNoDecor))
+         ClientStickUnstickToggle(CurrentClient);
+}
+
+/*
+ * Save the workspace
+ */
+void
+KeySaveWorkspace(dpy, ev)
+    Display	*dpy;
+    XEvent	*ev;
+{
+    if (ev->type != KeyPress)
+	return;
+    SaveWorkspaceFunc(dpy, lookupWindow(ev), NULL, 0);
+}
