@@ -1,3 +1,6 @@
+#ifdef IDENT
+#ident	"@(#)mem.h	1.2	92/07/16 SMI"
+#endif
 /*
  *      (c) Copyright 1989 Sun Microsystems, Inc. Sun design patents
  *      pending in the U.S. and foreign countries. See LEGAL_NOTICE
@@ -7,23 +10,16 @@
 #ifndef _OLWM_MEM_H
 #define _OLWM_MEM_H
 
-#ident	"@(#)mem.h	26.9	91/09/14 SMI"
-
-#define MAXPID 65537
-
 #ifndef COHERENT
 extern void *MemAlloc();	/* malloc frontend */
 extern void *MemCalloc();	/* calloc frontend */
+extern void *MemRealloc();	/* realloc frontend */
 #else
 extern char *MemAlloc();	/* malloc frontend */
 extern char *MemCalloc();	/* calloc frontend */
-#endif
-extern void MemFree();		/* free frontend */
-#ifndef COHERENT
-extern void *MemRealloc();	/* realloc frontend */
-#else
 extern char *MemRealloc();	/* realloc frontend */
 #endif
+extern void MemFree();		/* free frontend */
 
 #ifdef MEMDEBUG
 extern void *d_MemAlloc();
@@ -47,14 +43,3 @@ extern int AcctTag;
 #endif
 
 #endif /* _OLWM_MEM_H */
-
-
-
-
-
-
-
-
-
-
-
