@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)menu.c	1.2 olvwm version 1/27/92"
+#ifdef IDENT
+#ident	"@(#)menu.c	1.5 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -33,11 +35,12 @@
 #include <X11/Xresource.h>
 #define XK_MISCELLANY
 #include <X11/keysymdef.h>
+
+#include "i18n.h"
 #include <olgx/olgx.h>
 #include <assert.h>
 #include <string.h>
 
-#include "i18n.h"
 #include "ollocale.h"
 #include "mem.h"
 #include "events.h"
@@ -347,11 +350,10 @@ menuTitle(mInfo)
  * so ShowStandardMenuSync() will use these to that
  * effect
  */
-#ifndef COHERENT
 void (*clickProc)();
+#ifndef COHERENT
 void *clickData;
 #else
-char (*clickProc)();
 char *clickData;
 #endif
 
@@ -366,11 +368,10 @@ SetClickMode(flclick)
 
 void
 SetClickCallback(proc, data)
-#ifndef COHERENT
     void (*proc)();
+#ifndef COHERENT
     void  *data;
 #else
-    char (*proc)();
     char  *data;
 #endif
 {
@@ -497,6 +498,7 @@ DrawMenuWithHints(dpy, mInfo)
 }
 
 void
+/* ARGSUSED */
 SetMenuRedrawHints(dpy, ee, mInfo)
     Display *dpy;
     XExposeEvent *ee;
@@ -541,7 +543,7 @@ DrawMenu(dpy, mInfo)
     GC          windowGC = WinGC(winInfo, WINDOW_GC);
     Graphics_info *gisNormal = WinGI(winInfo, NORMAL_GINFO);
     int         bindex;
-    char       *mtit;
+    char	*mtit;
 
     /* Draw the basic menu background if this menu isn't pinned */
     if (mInfo->origmenuInfo != NULL || !winInfo->core.client->scrInfo->use3D) {
@@ -559,7 +561,7 @@ DrawMenu(dpy, mInfo)
 
 	olgx_draw_text(gisNormal, win, mtit,
 		       mInfo->titleX, mInfo->titleY, 0,
-		       False, OLGX_NORMAL);
+		       OLGX_NORMAL);
 
 	olgx_draw_text_ledge(gisNormal, win,
 			     BUTT_HSPACE, mInfo->titleHeight - 6,
@@ -695,11 +697,10 @@ StartMenuGrabs(dpy, winInfo)
 void
 MenuMakeFirst(mInfo, sfunc, sinfo)
     MenuInfo *mInfo;
-#ifndef COHERENT
     void (*sfunc)();
+#ifndef COHERENT
     void *sinfo;
 #else
-    char (*sfunc)();
     char *sinfo;
 #endif
 {
@@ -718,11 +719,10 @@ MenuShowSync(dpy, winInfo, menu, pevent, sfunc, sinfo, flkbd, flbutton)
     WinGeneric  *winInfo;
     Menu        *menu;
     XEvent      *pevent;
-#ifndef COHERENT
     void       (*sfunc) ();
+#ifndef COHERENT
     void        *sinfo;
 #else
-    char       (*sfunc) ();
     char        *sinfo;
 #endif
     Bool         flkbd;
@@ -881,11 +881,12 @@ findMaxDepth(menuCache)
  *		     and created all needed structures.
  */
 MenuInfo *
-MenuInfoCreate(menuCache, winInfo, menu, depth)
+MenuInfoCreate(menuCache, winInfo, menu, depth, slot)
     MenuCache  *menuCache;
     WinGeneric *winInfo;
     Menu       *menu;
     int         depth;
+    int		slot;
 {
     MenuInfo   *menuInfo;
 
@@ -910,12 +911,15 @@ MenuInfoCreate(menuCache, winInfo, menu, depth)
     menuInfo->pinnedBrother = NULL;
 
     /* insert it into the list */
-    if (menuCache->nextSlot == menuCache->maxSlots - 1) {
-	menuCache->maxSlots += 10;
-	menuCache->menuInfoList = MemRealloc(menuCache->menuInfoList,
+    if (slot == MENU_NEWSLOT) {
+        if (menuCache->nextSlot == menuCache->maxSlots - 1) {
+	    menuCache->maxSlots += 10;
+	    menuCache->menuInfoList = MemRealloc(menuCache->menuInfoList,
 					     sizeof(MenuInfo) * menuCache->maxSlots);
+        }
+        menuCache->menuInfoList[menuCache->nextSlot++] = menuInfo;
     }
-    menuCache->menuInfoList[menuCache->nextSlot++] = menuInfo;
+    else menuCache->menuInfoList[slot] = menuInfo;
 
     return menuInfo;
 }
@@ -1005,6 +1009,9 @@ buttonInfoCreate(menuCache, winInfo, menuInfo)
     for (bindex = 0; bindex < buttonCount; bindex++) {
 	Button *pb = menuInfo->menu->buttons[bindex];
 
+	if (pb == NULL)
+	    continue;
+
 	bInfo = &(buttonInfo[bindex]);
 
 	/* erase everything; if we decide not to use this item (visible == False)
@@ -1025,7 +1032,8 @@ buttonInfoCreate(menuCache, winInfo, menuInfo)
 	if (bInfo->button->stacked && bInfo->button->action.submenu) {
 	    bInfo->subMenu = MenuInfoCreate(menuCache, winInfo,
 					    bInfo->button->action.submenu,
-					    menuInfo->depth + 1);
+					    menuInfo->depth + 1,
+					    MENU_NEWSLOT);
 	} else {
 	    bInfo->subMenu = (MenuInfo *) NULL;
 	}
@@ -1037,7 +1045,7 @@ buttonInfoCreate(menuCache, winInfo, menuInfo)
 }
 
 /*
- * MenuInfoDestroy
+ * menuInfoDestroy
  */
 void
 MenuInfoDestroy(menuInfo)
@@ -1263,6 +1271,8 @@ calcmenusize(menuInfo, winInfo, menu)
 		    break;	/* last column may not have all the btnPerCol */
 	    }
 	    colheight = MAX(colheight, tempheight);
+	    if (currow + curcol * menu->btnPerCol == menu->buttonCount - 1)
+		break;	/* last column may not have all the btnPerCol */
 	}
 	menHeight = menuInfo->titleHeight + HEAD_VSPACE +
 		    colheight + BUTT_VSPACE;
@@ -1366,6 +1376,7 @@ recalcCachedMenu(win, menu)
  *	Assumes that the window menus will tkae up the first MENU_NONE slots
  */
 int
+/* ARGSUSED */
 DestroyWindowMenuInfo(dpy, scrInfo)
     Display    *dpy;
     ScreenInfo *scrInfo;
@@ -1390,7 +1401,8 @@ CreateUserMenuInfo(dpy, scrInfo)
 
     scrInfo->menuCache->nextSlot = (int) MENU_ROOT;
     (void) MenuInfoCreate(scrInfo->menuCache, scrInfo->rootwin,
-			  scrInfo->menuTable[(int) MENU_ROOT], 1);
+			  scrInfo->menuTable[(int) MENU_ROOT], 1,
+			  MENU_NEWSLOT);
 
     maxDepth = findMaxDepth(scrInfo->menuCache);
     if (maxDepth > scrInfo->menuCache->maxDepth) {
@@ -1408,6 +1420,7 @@ CreateUserMenuInfo(dpy, scrInfo)
  *	Assumes that root menu info starts in slot MENU_ROOT in the menu cache.
  */
 int
+/* ARGSUSED */
 DestroyUserMenuInfo(dpy, scrInfo)
     Display    *dpy;
     ScreenInfo *scrInfo;
@@ -1524,23 +1537,22 @@ _setdefault(cli, bfi)
  */
 void
 VisitPinnedMenuClients(pproc, extra)
-#ifndef COHERENT
     void (*pproc)();
+#ifndef COHERENT
     void *extra;
 #else
-    char (*pproc)();
     char *extra;
 #endif
 {
-    List	*l = ActiveClientList;
-    Client	*cli;
+    List        *l = ActiveClientList;
+    Client      *cli;
 
     for (cli = ListEnum(&l); cli != NULL; cli = ListEnum(&l)) {
 	if (cli->framewin && cli->framewin->fcore.panewin &&
 	    cli->framewin->fcore.panewin->core.kind == WIN_PINMENU) {
 	    (*pproc)(cli, extra);
 	}
-    }
+    }    
 }
 
 void
@@ -1754,6 +1766,7 @@ menuHelpCommand(dpy, xke, closure)
 
 
 Bool
+/* ARGSUSED */
 MenuHandleKeyEvent(dpy, pevent, win, closure)
     Display *dpy;
     XEvent *pevent;
@@ -2081,7 +2094,7 @@ menuHandlePress(dpy, pevent)
       case ML_OFFMENU:
 	return True;
       case ML_BUTTONDISABLED:
-	break;	/*don't do anything*/
+	break;  /*don't do anything*/
       case ML_PIN:
 	unmapChildren(dpy, mInfo);
 	setMenuPin(dpy, mInfo, True, flDoSetDefault);
@@ -2224,7 +2237,7 @@ menuHandleMotion(dpy, pevent)
 	break;
 
       case ML_BUTTONDISABLED:
-	return;
+	break;
     }	   /* End switch */
 
     /*
@@ -2452,7 +2465,6 @@ menuHandleRelease(dpy, pevent)
 	    SetClickMode(True);	/*for window buttons*/
 	    setClick = True;
 	}
-
 	switch (mInfo->action) {
 	  case ACTION_SELECT:
 	    return True;	/*always return true on SELECT*/
@@ -2938,6 +2950,9 @@ drawButton(dpy, menuInfo, idx, fDefault)
 
     pb = menuInfo->buttons[idx].button;
 
+    if (pb == NULL)
+	return;
+
     state = OLGX_NORMAL | OLGX_ERASE | OLGX_MENU_ITEM;
 
     if (! pb->enabled)
@@ -3001,6 +3016,9 @@ drawRevButton(dpy, menuInfo, idx)
 
     pb = menuInfo->buttons[idx].button;
 
+    if (pb == NULL)
+	return;
+
     /* if the button is disabled, do nothing */
     if (! pb->enabled)
 	return;
@@ -3218,7 +3236,8 @@ InitScreenMenus(dpy, scrInfo)
 
     for (index = 0; index < (int) NUM_MENUS; index++) {
 	(void) MenuInfoCreate(menuCache, scrInfo->rootwin,
-			      scrInfo->menuTable[index], 1);
+			      scrInfo->menuTable[index], 1,
+			      MENU_NEWSLOT);
     }
 
     maxDepth = findMaxDepth(menuCache);
@@ -3250,12 +3269,16 @@ DoDefaultMenuAction(win)
     Menu *menu;
     int defitem;
     Button *pb;
+    Bool fullsize;
    
     /*
      * find the menu associated with this frame,
      * this ensures that the menu is enabled correctly
      */
-    menu = GetEnabledMenu(win->core.client, win->fcore.fullsize,
+    if (win->core.kind == WIN_FRAME)
+	fullsize = win->fcore.fullsize;
+    else fullsize = False;
+    menu = GetEnabledMenu(win->core.client, fullsize,
 				False, win->core.client->sticky);
 
     if (!menu)
