@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident "@(#)moveresize.c	1.2 olvwm version 1/27/92"
+#ifdef IDENT
+#ident "@(#)moveresize.c	1.5 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -130,10 +132,10 @@ createStatusWindow(dpy, scrinfo, proto)
     ScreenInfo *scrinfo;
     char *proto;
 {
-    int width, height;
     XSetWindowAttributes attr;
     StatusWinInfo *sw;
-    int	changed, x, y, w, h;
+    int	changed, x, y;
+    unsigned int w, h;
 
     sw = MemNew(StatusWinInfo);
     sw->dpy = dpy;
@@ -150,12 +152,12 @@ createStatusWindow(dpy, scrinfo, proto)
 	changed = XParseGeometry(GRV.ResizePosition, &x, &y, &w, &h);
 	if (changed & XValue)
 	    if (changed & XNegative)
-		x = DisplayWidth(dpy, scrinfo->screen) + x;
+		x = DisplayWidth(dpy, scrinfo->screen) + x - sw->width;
 	    else ;
 	else x = 0;
 	if (changed & YValue)
 	    if (changed & YNegative)
-		y = DisplayHeight(dpy, scrinfo->screen) + y;
+		y = DisplayHeight(dpy, scrinfo->screen) + y - sw->height;
 	    else ;
 	else y = 0;
     }
@@ -228,9 +230,11 @@ typedef struct {
     VirtualDesktop	*vdm;
     int			targetScreenX;
     int			targetScreenY;
+    int			initScreenX;
+    int			initScreenY;
     Region		region;
     Window		*children;
-    int			num_children;
+    unsigned int	num_children;
     int			vdm_stacking_order;
 } MoveClosure;
 
@@ -239,10 +243,12 @@ static Bool movewinInterposer();
 #ifndef COHERENT
 static void *moveOneWindow();
 static void *configOneWindow();
+static void *configOneWindowCleanup();
 static void *drawOneBox();
 #else
 static char *moveOneWindow();
 static char *configOneWindow();
+static char *configOneWindowCleanup();
 static char *drawOneBox();
 #endif
 static void moveDone();
@@ -284,7 +290,6 @@ moveAddRegion(cli, mstuff)
 {
 Region		new;
 XRectangle	rect;
-int		stacking_order;
 
     if (!cli->framewin)
 	return NULL;
@@ -344,20 +349,20 @@ UserMoveWindows(cli, first)
     static MoveClosure mstuff;
     Time 	timestamp;
     XRectangle	rect;
-    int		dummy;
+    Window	dummy_window;
 
     {
     /*
      * Set up where the VDM is to allow/prevent moving into it
      */
 	VirtualDesktop		*vdm;
-	unsigned int	x, y, w, h, bw, d;
+	unsigned int	w, h, bw, d;
+	int		x, y;
 	Window		root;
 
 	vdm = cli->scrInfo->vdm;
-	if (vdm && vdm->client->wmState != IconicState &&
-		vdm->client != cli && GRV.AllowMoveIntoDesktop) {
-	    mstuff.check_vdm = True;
+	if (vdm && vdm->client->wmState != IconicState && vdm->client != cli) {
+	    mstuff.check_vdm = GRV.AllowMoveIntoDesktop;
 	    XGetGeometry(dpy, vdm->client->framewin->core.self,
 			 &root, &x, &y, &w, &h, &bw, &d);
 	    mstuff.vdm_screenX = x;
@@ -372,8 +377,18 @@ UserMoveWindows(cli, first)
 	    rect.width = w;
 	    rect.height = h;
 	}
-	else mstuff.check_vdm = False;
-        mstuff.vdm = vdm;
+	else {
+	    mstuff.vdm = vdm;
+	    mstuff.check_vdm = False;
+	}
+	if (first) {
+	    if (first->xmotion.window == PANEWINOFCLIENT(vdm->client))
+	        mstuff.inVDM = True;
+	    else if (VGetInfo(first->xmotion.window))
+	        mstuff.inVDM = True;
+	    else mstuff.inVDM = False;
+	}
+	else mstuff.inVDM = False;
     }
 
     mstuff.dpy = dpy;
@@ -421,6 +436,15 @@ UserMoveWindows(cli, first)
 	if (first->xbutton.state & ModMaskMap[MOD_CONSTRAIN])
 	    mstuff.constraint = EitherConstrained;
     }
+    mstuff.initScreenX = (mstuff.frame->core.x +
+				(int) mstuff.frame->core.width / 2 -
+				mstuff.vdm->offsetX) / 
+		DisplayWidth(dpy, mstuff.frame->core.client->screen);
+    mstuff.initScreenY = (mstuff.frame->core.y +
+				(int) mstuff.frame->core.height / 2 -
+				mstuff.vdm->offsetY) /
+		DisplayHeight(dpy, mstuff.frame->core.client->screen);
+
     /*
      * This is esoteric: we don't want to allow a drag into an obscured
      * part of the VDM.  If we're dragging the outline, then it's easy,
@@ -437,12 +461,13 @@ UserMoveWindows(cli, first)
 	    mstuff.region = XCreateRegion();
 	    /* rect is set up above */
 	    XUnionRectWithRegion(&rect, mstuff.region, mstuff.region);
-	    if (!XQueryTree(dpy, WinRootID(mstuff.frame), &dummy, &dummy,
+	    if (!XQueryTree(dpy, WinRootID(mstuff.frame),
+			   &dummy_window, &dummy_window,
 			   &mstuff.children, &mstuff.num_children))
 		mstuff.num_children = 0;
 	    mstuff.vdm_stacking_order =
 		getWindowStackingOrder(mstuff.vdm->client->framewin->core.self,
-					mstuff);
+					&mstuff);
 	    ListApply(ActiveClientList, moveAddRegion, &mstuff);
 	}
 	else mstuff.region = NULL;
@@ -502,8 +527,7 @@ UserMoveWindows(cli, first)
     if (GRV.ShowMoveGeometry)
 	mstuff.statuswindow = createStatusWindow(dpy, cli->scrInfo,
 				gettext("location: 0000 , 0000"));
-    else
-	mstuff.statuswindow = NULL;
+    else mstuff.statuswindow = NULL;
 
     /*
      * If we're dragging the outlines, we must also grab the server and draw 
@@ -536,9 +560,9 @@ moveUpdate(mstuff, event)
 	        mstuff->inVDM = True;
 	    else if (mstuff->dragwin) {
 	        /*
-	         * If we're dragging the window and the event is on the window's
-	         * frame (ie we moved just a little) see if we're over the vdm.
-	         * If so, move into the vdm
+	         * If we're dragging the window, then we took care of setting
+		 * the VDM when we do the regioning stuff.
+		 * REMIND:  Can we ever get here?
 	         */
 	    }    
 	    else mstuff->inVDM = False;
@@ -546,7 +570,6 @@ moveUpdate(mstuff, event)
 	else mstuff->inVDM = XPointInRegion(mstuff->region,
 				event->xmotion.x_root, event->xmotion.y_root);
     }
-    else mstuff->inVDM = False;
 
     if (mstuff->inVDM) {
         mstuff->offX = (mstuff->curX - mstuff->vdm_screenX) *
@@ -980,8 +1003,7 @@ configOneWindow(win, mstuff)
 {
 int	dw, dh;
 int 	offX, offY;
-int	newScreenX, curScreenX,	newScreenY, curScreenY;
-int	width, height;
+int	newScreenX, newScreenY;
 Client	*leader;
 
     if (win->core.client->flags & CLMoved)
@@ -993,38 +1015,36 @@ Client	*leader;
     dw = DisplayWidth(win->core.client->dpy, win->core.client->screen);
     dh = DisplayHeight(win->core.client->dpy, win->core.client->screen);
     windowOff(win, mstuff, &offX, &offY);
-    width = win->core.width;
-    height = win->core.height;
-    if (GRV.VirtualMoveGroups) {
-	switch(win->core.client->groupmask) {
-	    case GROUP_LEADER:
-		leader = win->core.client;
-		break;
-	    case GROUP_DEPENDENT:
-	        leader = GroupLeader(win->core.client->groupid);
-		if (!leader) {
-		    doConfigOneWindow(win, mstuff);
-#ifndef COHERENT
-		    return (void *) 0;
-#else
-		    return (char *) 0;
-#endif
-		}
-		break;
-	    case GROUP_INDEPENDENT:
+    switch(win->core.client->groupmask) {
+	case GROUP_LEADER:
+	    leader = win->core.client;
+	    break;
+	case GROUP_DEPENDENT:
+	    leader = GroupLeader(win->core.client->groupid);
+	    if (!leader) {
 		doConfigOneWindow(win, mstuff);
 #ifndef COHERENT
 		return (void *) 0;
 #else
 		return (char *) 0;
 #endif
-	}
-	curScreenX = (win->core.x - mstuff->vdm->offsetX) / dw;
-	newScreenX = (win->core.x + offX - mstuff->vdm->offsetX) / dw;
-	mstuff->targetScreenX = newScreenX - curScreenX;
-	curScreenY = (win->core.y - mstuff->vdm->offsetY) / dh;
-	newScreenY = (win->core.y + offY - mstuff->vdm->offsetY) / dh;
-	mstuff->targetScreenY = newScreenY - curScreenY;
+	    }
+	    break;
+	case GROUP_INDEPENDENT:
+	    doConfigOneWindow(win, mstuff);
+#ifndef COHERENT
+	    return (void *) 0;
+#else
+	    return (char *) 0;
+#endif
+    }
+    if (GRV.VirtualMoveGroups) {
+	newScreenX = (win->core.x + (win->core.width / 2) +
+				offX - mstuff->vdm->offsetX) / dw;
+	mstuff->targetScreenX = newScreenX - mstuff->initScreenX;
+	newScreenY = (win->core.y + (win->core.height / 2) +
+				offY - mstuff->vdm->offsetY) / dh;
+	mstuff->targetScreenY = newScreenY - mstuff->initScreenY;
 	if (mstuff->targetScreenY == 0 && mstuff->targetScreenX == 0)
 	    doConfigOneWindow(win, mstuff);
 	else GroupApply(leader->groupid, configOneClient, mstuff,
@@ -1114,7 +1134,7 @@ moveDone(mstuff)
     if (mstuff->region) {
 	XDestroyRegion(mstuff->region);
 	if (mstuff->num_children)
-	    XFree(mstuff->children);
+	    XFree((char *) mstuff->children);
     }
 
     destroyStatusWindow(mstuff->statuswindow);
@@ -1192,11 +1212,10 @@ typedef struct {
     int			maxAspectX, maxAspectY;
     int			baseW, baseH;
     int			borderW, borderH;   /* size of frame border */
-#ifndef COHERENT
     void		(*callback)();
+#ifndef COHERENT
     void		*cbarg;
 #else
-    char		(*callback)();
     char		*cbarg;
 #endif
     StatusWinInfo	*statuswindow;
@@ -1234,8 +1253,10 @@ resizeDraw(rstuff)
     drawDouble(rstuff->cli->dpy,
 		PANEWINOFCLIENT(rstuff->cli->scrInfo->vdm->client),
 		WinGC(rstuff->cli->framewin, ROOT_GC),
-		rstuff->winX / rstuff->cli->scrInfo->vdm->resources->scale,
-		rstuff->winY / rstuff->cli->scrInfo->vdm->resources->scale,
+		(rstuff->winX - rstuff->cli->scrInfo->vdm->offsetX) /
+				rstuff->cli->scrInfo->vdm->resources->scale,
+		(rstuff->winY - rstuff->cli->scrInfo->vdm->offsetY) /
+				rstuff->cli->scrInfo->vdm->resources->scale,
 		rstuff->winW / rstuff->cli->scrInfo->vdm->resources->scale,
 		rstuff->winH / rstuff->cli->scrInfo->vdm->resources->scale);
 }
@@ -1248,6 +1269,9 @@ resizePaintStatus(rstuff)
     char buf[30];
     int w, h;
 
+    if (!rstuff->statuswindow)
+	return;
+
     w = rstuff->winW - rstuff->borderW;
     h = rstuff->winH - rstuff->borderH;
 
@@ -1262,6 +1286,7 @@ resizePaintStatus(rstuff)
 
 
 static void
+/* ARGSUSED */
 resizeDone(dpy, e, w, rstuff, doit)
     Display *dpy;
     XEvent *e;
@@ -1542,7 +1567,6 @@ resizeInterposer(dpy, e, w, rstuff)
     WinGeneric *w;
     ResizeClosure *rstuff;
 {
-    int dx, dy;
     unsigned int mask;
     SemanticAction action;
 
@@ -1663,6 +1687,11 @@ UserResizeWin(cli, trigger, corner, callback, cbarg)
     Window root = WinRootID(cli->framewin);
     Time timestamp;
     int frameMinWidth, frameMinHeight;
+    Cursor	resizePointer;
+
+    if (GRV.SpecialResizePointers)
+	resizePointer = GRV.ResizePointers[corner];
+    else resizePointer = GRV.ResizePointer;
 
     if (trigger == NULL || trigger->type == KeyPress) {
 	if (trigger == NULL)
@@ -1701,7 +1730,7 @@ UserResizeWin(cli, trigger, corner, callback, cbarg)
     if (XGrabPointer(cli->dpy, root, True,
 		     ButtonPressMask | ButtonReleaseMask | PointerMotionMask,
 		     GrabModeAsync, GrabModeAsync, root,
-		     GRV.ResizePointer, timestamp) != GrabSuccess)
+		     resizePointer, timestamp) != GrabSuccess)
     {
 	ErrorWarning(gettext("failed to grab pointer"));
 	return;
@@ -1802,8 +1831,7 @@ UserResizeWin(cli, trigger, corner, callback, cbarg)
     if (GRV.ShowResizeGeometry)
 	rstuff.statuswindow = createStatusWindow(cli->dpy, cli->scrInfo,
 						 gettext("size: 0000 x 0000"));
-    else
-	rstuff.statuswindow = NULL;
+    else rstuff.statuswindow = NULL;
 
     if (trigger == NULL || trigger->type == KeyPress) {
 	resizeDraw(&rstuff);
@@ -1828,15 +1856,15 @@ typedef struct _rootboxclosure {
     GC rootGC;
 #ifndef COHERENT
     void *closure;
-    void (*callback)();
 #else
     char *closure;
-    char (*callback)();
 #endif
+    void (*callback)();
 } RootBoxClosure;
 
 
 static int
+/* ARGSUSED */
 rootBoxInterposer(dpy, event, w, rbc)
     Display *dpy;
     XEvent *event;
@@ -1942,11 +1970,10 @@ TraceRootBox(dpy, winInfo, pEvent, callback, closure)
 Display	*dpy;
 WinRoot *winInfo;
 XEvent	*pEvent;
-#ifndef COHERENT
 void	(*callback)();
+#ifndef COHERENT
 void	*closure;
 #else
-char	(*callback)();
 char	*closure;
 #endif
 {
