@@ -1,4 +1,6 @@
-#ident "@(#)ol_button.c	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident "@(#)ol_button.c	1.3 olvwm version 25 Nov 1992"
+#endif
 
 /*
  * Based on
@@ -20,6 +22,8 @@
 #include <stdio.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
+
+#include "i18n.h"
 #include "olgx_impl.h"
 
 #include "win.h"
@@ -342,7 +346,7 @@ olgx_draw_varheight_button(info, win, x, y, width, height, state)
 {
 
 
-    char            string[2];
+    char   	    string[2];
     XSegment        seg[4];
 
 
@@ -361,23 +365,23 @@ olgx_draw_varheight_button(info, win, x, y, width, height, state)
 	string[0] = PIXLABEL_BUTTON_UL;
 	XDrawString(info->dpy, win, (state & OLGX_INVOKED) ?
 	    info->gc_rec[OLGX_BG3]->gc : info->gc_rec[OLGX_WHITE]->gc, x, y,
-		    string, 1);
+		    (char *) string, 1);
 
 	string[0] = PIXLABEL_BUTTON_UR;
 	XDrawString(info->dpy, win, (state & OLGX_INVOKED) ?
 		  info->gc_rec[OLGX_BG3]->gc : info->gc_rec[OLGX_WHITE]->gc,
-		    x + width - VARHEIGHT_BUTTON_CORNER_DIMEN, y, string, 1);
+		    x + width - VARHEIGHT_BUTTON_CORNER_DIMEN, y, (char *) string, 1);
 
 	string[0] = PIXLABEL_BUTTON_LL;
 	XDrawString(info->dpy, win, (state & OLGX_INVOKED) ?
 	   info->gc_rec[OLGX_WHITE]->gc : info->gc_rec[OLGX_BG3]->gc, x, y +
-		    height - VARHEIGHT_BUTTON_CORNER_DIMEN, string, 1);
+		    height - VARHEIGHT_BUTTON_CORNER_DIMEN, (char *) string, 1);
 
 	string[0] = PIXLABEL_BUTTON_LR;
 	XDrawString(info->dpy, win, (state & OLGX_INVOKED) ?
 		  info->gc_rec[OLGX_WHITE]->gc : info->gc_rec[OLGX_BG3]->gc,
 		    x + width - VARHEIGHT_BUTTON_CORNER_DIMEN,
-		    y + height - VARHEIGHT_BUTTON_CORNER_DIMEN, string, 1);
+		    y + height - VARHEIGHT_BUTTON_CORNER_DIMEN, (char *) string, 1);
 
 	seg[0].x1 = x + VARHEIGHT_BUTTON_CORNER_DIMEN;
 	seg[0].y1 = seg[0].y2 = y;
@@ -413,19 +417,19 @@ olgx_draw_varheight_button(info, win, x, y, width, height, state)
 			   y + 1, width - 2, height - 2);
 
 	string[0] = PIXLABEL_BUTTON_UL;
-	XDrawString(info->dpy, win, info->gc_rec[OLGX_BLACK]->gc, x, y, string, 1);
+	XDrawString(info->dpy, win, info->gc_rec[OLGX_BLACK]->gc, x, y, (char *) string, 1);
 	string[0] = PIXLABEL_BUTTON_UR;
 	XDrawString(info->dpy, win, info->gc_rec[OLGX_BLACK]->gc,
-		    x + width - VARHEIGHT_BUTTON_CORNER_DIMEN, y, string, 1);
+		    x + width - VARHEIGHT_BUTTON_CORNER_DIMEN, y, (char *) string, 1);
 
 	string[0] = PIXLABEL_BUTTON_LL;
 	XDrawString(info->dpy, win, info->gc_rec[OLGX_BLACK]->gc, x,
-		    y + height - VARHEIGHT_BUTTON_CORNER_DIMEN, string, 1);
+		    y + height - VARHEIGHT_BUTTON_CORNER_DIMEN, (char *) string, 1);
 
 	string[0] = PIXLABEL_BUTTON_LR;
 	XDrawString(info->dpy, win, info->gc_rec[OLGX_BLACK]->gc,
 		    x + width - VARHEIGHT_BUTTON_CORNER_DIMEN,
-		    y + height - VARHEIGHT_BUTTON_CORNER_DIMEN, string, 1);
+		    y + height - VARHEIGHT_BUTTON_CORNER_DIMEN, (char *) string, 1);
 
 	seg[0].x1 = x + VARHEIGHT_BUTTON_CORNER_DIMEN;
 	seg[0].y1 = seg[0].y2 = y;
@@ -452,22 +456,22 @@ olgx_draw_varheight_button(info, win, x, y, width, height, state)
 
 	string[0] = PIXLABEL_DEF_BUTTON_UL;
 	XDrawString(info->dpy, win, info->gc_rec[OLGX_BLACK]->gc, x, y,
-		    string, 1);
+		    (char *) string, 1);
 
 	string[0] = PIXLABEL_DEF_BUTTON_UR;
 	XDrawString(info->dpy, win, info->gc_rec[OLGX_BLACK]->gc, x + width -
-		    VARHEIGHT_BUTTON_CORNER_DIMEN, y, string, 1);
+		    VARHEIGHT_BUTTON_CORNER_DIMEN, y, (char *) string, 1);
 
 	string[0] = PIXLABEL_DEF_BUTTON_LL;
 	XDrawString(info->dpy, win,
 		    info->gc_rec[OLGX_BLACK]->gc, x, y + height -
-		    VARHEIGHT_BUTTON_CORNER_DIMEN, string, 1);
+		    VARHEIGHT_BUTTON_CORNER_DIMEN, (char *) string, 1);
 
 	string[0] = PIXLABEL_DEF_BUTTON_LR;
 	XDrawString(info->dpy, win,
 		    info->gc_rec[OLGX_BLACK]->gc, x + width -
 		    VARHEIGHT_BUTTON_CORNER_DIMEN, y + height -
-		    VARHEIGHT_BUTTON_CORNER_DIMEN, string, 1);
+		    VARHEIGHT_BUTTON_CORNER_DIMEN, (char *) string, 1);
 
 	seg[0].x1 = x + VARHEIGHT_BUTTON_CORNER_DIMEN;
 	seg[0].y1 = seg[0].y2 = y + 2;
