@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
+#ifdef IDENT
 #ident	"@(#)ollocale.h	1.6	91/09/14 SMI"
+#endif
 
 #ifndef _OLLOCALE_H
 #define _OLLOCALE_H
