@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)olwm.c	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident	"@(#)olwm.c	1.4 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -24,9 +26,7 @@
 #include <sys/param.h>
 #include <sys/resource.h>
 #include <sys/stat.h>
-#ifndef COHERENT
 #include <sys/wait.h>
-#endif
 
 #include <X11/Xos.h>
 #include <X11/Xlib.h>
@@ -49,6 +49,10 @@
 
 #include "patchlevel.h"
 
+#ifdef COHERENT
+#define MAXPID PID_MAX
+#endif
+
 typedef	void	(*VoidFunc)();
 
 /*
@@ -76,35 +80,33 @@ XrmQuark OlwmQ;
 /* Current Display */
 Display	*DefDpy;
 
-
 static Display *openDisplay();
 static void	parseCommandline();
 static void	sendSyncSignal();
 
-
 /* Note that changes to RMTable instance names must also be made here !! */
 static	XrmOptionDescRec	optionTable[] = {
 	{ "-display",		".display",	
 		XrmoptionSepArg, (caddr_t) NULL },
 	{ "-f",			".setInput",
 		XrmoptionNoArg, (caddr_t) "follow" },
-	{ "-follow",		".setInput", 
+	{ "-follow",		".setInput",
 		XrmoptionNoArg, (caddr_t) "follow" },
-	{ "-c", 		".setInput",	
+	{ "-c",			".setInput",
 		XrmoptionNoArg, (caddr_t) "select" },
-	{ "-click", 		".setInput",	
+	{ "-click",		".setInput",
 		XrmoptionNoArg, (caddr_t) "select" },
-	{ "-2d", 		".use3D",	
+	{ "-2d",		".use3D",	
 		XrmoptionNoArg, (caddr_t) "False" },
-	{ "-3d", 		".use3D",	
+	{ "-3d",		".use3D",	
 		XrmoptionNoArg, (caddr_t) "True" },
-	{ "-parent", 		".reparentOK",	
+	{ "-parent",		".reparentOK",	
 		XrmoptionNoArg, (caddr_t) "False" },
-	{ "-orphans", 		".printOrphans", 
+	{ "-orphans",		".printOrphans",	
 		XrmoptionNoArg, (caddr_t) "True" },
-	{ "-all", 		".printAll", 
+	{ "-all",		".printAll",	
 		XrmoptionNoArg, (caddr_t) "True" },
-	{ "-synchronize",	".synchronize",
+	{ "-synchronize",       ".synchronize",	
 		XrmoptionNoArg, (caddr_t) "True" },
 	{ "-debug",	".printOrphans", XrmoptionNoArg, (caddr_t) "True" },
 	{ "-name",		".name",	
@@ -115,23 +117,24 @@ static	XrmOptionDescRec	optionTable[] = {
 	{ "-foreground","*Foreground",	XrmoptionSepArg, (caddr_t) NULL },
 	{ "-bd",	"*Background",	
 		XrmoptionSepArg, (caddr_t) NULL },
-	{ "-bordercolor",	"*Background",	
+	{ "-bordercolor",       "*Background",	
 		XrmoptionSepArg, (caddr_t) NULL },
 	{ "-fn",	"*TitleFont",	XrmoptionSepArg, (caddr_t) NULL },
 	{ "-font",	"*TitleFont",	XrmoptionSepArg, (caddr_t) NULL },
 	{ "-xrm",	NULL,		XrmoptionResArg, (caddr_t) NULL },
 	{ "-single",	".singleScreen",XrmoptionNoArg, (caddr_t) "True" },
 	{ "-multi",	".singleScreen",XrmoptionNoArg, (caddr_t) "False" },
-	{ "-syncpid",   ".syncPid",     XrmoptionSepArg, (caddr_t) NULL },
-	{ "-syncsignal",".syncSignal",  XrmoptionSepArg, (caddr_t) NULL },
+	{ "-syncpid",	".syncPid",	XrmoptionSepArg, (caddr_t) NULL },
+	{ "-syncsignal",".syncSignal",	XrmoptionSepArg, (caddr_t) NULL },
 	{ "-depth",	"*depth",	XrmoptionSepArg, (caddr_t) NULL },
 	{ "-visual",	"*visual",	XrmoptionSepArg, (caddr_t) NULL },
 #ifdef OW_I18N_L3
         { "-basiclocale", "*basicLocaleCL", XrmoptionSepArg, (caddr_t) NULL },
-       	{ "-displaylang", "*displayLangCL", XrmoptionSepArg, (caddr_t) NULL },
-       	{ "-inputlang",   "*inputLangCL", XrmoptionSepArg, (caddr_t) NULL },
-       	{ "-numeric",     "*numericCL", XrmoptionSepArg, (caddr_t) NULL },
-       	{ "-dateFormat",  "*dateFormatCL", XrmoptionSepArg, (caddr_t) NULL },
+        { "-displaylang", "*displayLangCL", XrmoptionSepArg, (caddr_t) NULL },
+        { "-inputlang",   "*inputLangCL", XrmoptionSepArg, (caddr_t) NULL },
+        { "-numeric",     "*numericCL", XrmoptionSepArg, (caddr_t) NULL },
+        { "-numeric",     "*numericCL", XrmoptionSepArg, (caddr_t) NULL },
+        { "-dateFormat",  "*dateFormatCL", XrmoptionSepArg, (caddr_t) NULL },
 #endif /* OW_I18N_L3 */
 };
 #define OPTION_TABLE_ENTRIES (sizeof(optionTable)/sizeof(XrmOptionDescRec))
@@ -139,7 +142,7 @@ static	XrmOptionDescRec	optionTable[] = {
 static void	initWinClasses();
 
 /* Child Process Handling */
-void HandleChildSignal();
+static void handleChildSignal();
 void ReapChildren();
 int DeadChildren = 0;
 int SlavePid;
@@ -198,7 +201,7 @@ main(argc, argv)
 	char **argv;
 {
 	int			ErrorHandler();
-	int			ExitOLWM();
+	int			ExitOLWM(), RestartOLWM();
 	XrmDatabase		commandlineDB = NULL;
 	char			*dpystr;
 
@@ -242,8 +245,8 @@ main(argc, argv)
 		 * may be only for the command line processing.
 		 */
 		fprintf(stderr, gettext("\
-		olwm: Warning: '%s' is invalid locale, using 'C' locale.\n"),
-				getenv("LANG"));
+		olvwm: Warning: '%s' is invalid locale, using 'C' locale.\n"),
+				 getenv("LANG"));
 		(void)setlocale(LC_ALL,"C");
 	}
 	if ((OpenWinHome = getenv("OPENWINHOME")) != 0)
@@ -262,10 +265,19 @@ main(argc, argv)
 	 * the windows back into a usable state.  Specifically we
 	 * need to reset the focus so they will be able to get input.
 	 */
+#ifdef SYSV
+	sigset(SIGHUP, (VoidFunc)ExitOLWM);
+	sigset(SIGINT, (VoidFunc)ExitOLWM);
+	sigset(SIGTERM, (VoidFunc)ExitOLWM);
+	sigset(SIGUSR1, (VoidFunc)RestartOLWM);
+	sigset(SIGCHLD, handleChildSignal);
+#else
 	signal(SIGHUP, (VoidFunc)ExitOLWM);
 	signal(SIGINT, (VoidFunc)ExitOLWM);
 	signal(SIGTERM, (VoidFunc)ExitOLWM);
-	signal(SIGCHLD, HandleChildSignal);
+	signal(SIGUSR1, (VoidFunc)RestartOLWM);
+	signal(SIGCHLD, handleChildSignal);
+#endif
 
 	/* initialize the resource manager */
 	XrmInitialize();
@@ -342,7 +354,7 @@ main(argc, argv)
 
 	/* Init screen */
 	InitScreens(DefDpy);
-	InitOlvwmRC(DefDpy);
+	InitOlvwmRC(DefDpy, NULL);
 	GrabKeys(DefDpy, True);
 	GrabButtons(DefDpy, True);
 	ReparentScreens(DefDpy);
@@ -436,11 +448,17 @@ XrmDatabase	*tmpDB;
 	/* check to see if there are any arguments left unparsed */
 	if ( *argc != 1 )
 	{
+	
+	    if (!strcmp(argv[1], "-allowSynthetic"))
+	            GRV.AllowSyntheticEvents = True;
+	    else {
+		GRV.AllowSyntheticEvents = False;
 		/* check to see if it's -help */
 		if ( argv[1][0] == '-' && argv[1][1] == 'h' )
 			usage(gettext("Command line arguments accepted"),gettext("are:"));
 		else
-			usage(gettext("Unknown argument(s)"), gettext("encountered"));
+		 	usage(gettext("Unknown argument(s)"), gettext("encountered"));
+	    }
 	}
 }
 
@@ -471,6 +489,8 @@ openDisplay(rdb)
 
     dpy = XOpenDisplay(dpystr);
     if (dpy == NULL) {
+	if (!dpystr)
+	    dpystr = gettext("DEFAULT DISPLAY");
 	fprintf(stderr, gettext("%s: cannot connect to %s\n"),
 		ProgramName, dpystr);
 	exit(1);
@@ -623,6 +643,13 @@ cleanup()
 int
 RestartOLWM()
 {
+#ifndef SYSV
+int	mask;
+    mask = sigblock(SIGUSR1);
+    sigsetmask(mask & ~(sigmask(SIGUSR1)));
+#else
+    sigrelse(SIGUSR1);
+#endif
     cleanup();
     execvp(argVec[0], argVec);
     ErrorGeneral("cannot restart");
@@ -640,15 +667,20 @@ ExitOLWM()
 
 
 /*
- * HandleChildSignal - keep track of children that have died
+ * handleChildSignal - keep track of children that have died
  */
 static void
-HandleChildSignal()
+handleChildSignal()
 {
 	/*
 	 * Following is only neede for SYSV but it doesn't hurt in BSD
+	 * Okay, it's needed for SVR3 but not SVR4
 	 */
-	signal(SIGCHLD, HandleChildSignal);
+#ifdef SYSV
+#ifndef SVR4
+	signal(SIGCHLD, handleChildSignal);
+#endif
+#endif
 	++DeadChildren;
 }
 
@@ -658,9 +690,7 @@ HandleChildSignal()
 void
 ReapChildren()
 {
-#ifndef COHERENT
-#ifdef SYSV
-        sigset_t newmask, oldmask;
+#if defined (SYSV) && !defined(_BSD)
         int status;
         pid_t pid;
 #else
@@ -668,31 +698,18 @@ ReapChildren()
 	int pid;
 	union wait status;
 #endif
-#else
-	int pid;
-	int status;
-#endif
 
-#ifndef COHERENT
 #ifdef SYSV
-        sigemptyset(&newmask);
-        sigemptyset(&oldmask);
-        sigaddset(&newmask, SIGCHLD);
-        sigprocmask(SIG_BLOCK, &newmask, &oldmask);
+	sighold(SIGCHLD);
 #else
 	oldmask = sigblock(sigmask(SIGCHLD));
-#endif
 #endif
 	while (DeadChildren>0)
 	{
-#ifndef COHERENT
 #ifdef SYSV
                 pid = waitpid(-1, &status, WNOHANG);
 #else
                 pid = wait3(&status, WNOHANG, (struct rusage *)0);
-#endif
-#else
-		pid = wait(&status);
 #endif
 		/* if it's the slave process then stop its use */
 		if (pid == SlavePid) 
@@ -704,21 +721,17 @@ ReapChildren()
 			DeadChildren = 0;
 			break;
 		}
-#ifndef COHERENT
 		if (WIFSTOPPED(status))
 		{
 			kill(pid, SIGKILL);
 		}
-#endif
 		--DeadChildren;
 	}
-#ifndef COHERENT
 #ifdef SYSV
-        sigprocmask(SIG_SETMASK, &oldmask, &oldmask);
+	sigrelse(SIGCHLD);
 #else
         (void) sigsetmask(oldmask);
 #endif
-#endif
 }
 
 /*
@@ -730,15 +743,14 @@ char	*s1, *s2;
 {
     fprintf(stderr, "%s %s\n", s1, s2);
     fprintf(stderr,
-	"usage: %s [-2d] [-3d] [-click] [-follow] [-parent]\n", ProgramName);
+	    "usage: %s [-2d] [-3d] [-click] [-follow] [-parent]\n", ProgramName);
     fputs(
        /* STRING_EXTRACTION - do not translate "-display" ,"-name"
-        * and "-xrm", becuase those are namne of command line option.
+        * and "-xrm", because those are the namne of command line option.
         */
-	gettext("\t[-display <display>] [-name <classname>] [-xrm <rsrcstring>]\n"),
-	stderr);
+        gettext("\t[-display <display>] [-name <classname>] [-xrm <rsrcstring>]\n"),
+        stderr);
     fputs("\t[-all] [-debug] [-orphans] [-synchronize] [-single]\n", stderr);
     fputs("\t[-syncpid pid] [-syncsignal signal]\n", stderr);
     exit(1);
 }
-
