@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident "@(#)resources.c	1.2 olvwm version 1/27/92"
+#ifdef IDENT
+#ident "@(#)resources.c	1.5 olvwm version 12/7/92"
+#endif
 
 /*
  *
@@ -28,9 +30,9 @@
 #include <X11/keysym.h>
 #include <X11/cursorfont.h>
 
+#include "i18n.h"
 #include <olgx/olgx.h>
 
-#include "i18n.h"
 #include "ollocale.h"
 #include "mem.h"
 #include "olwm.h"
@@ -43,7 +45,6 @@
 #include "events.h"
 #include "virtual.h"
 
-
 /* converters */
 
 static Bool cvtBeepStatus();
@@ -60,6 +61,8 @@ static Bool cvtString();
 static Bool cvtStringList();
 static Bool cvtGridEnum();
 static Bool cvtImageType();
+static Bool cvtSortType();
+static Bool cvtNoop();
 
 /* internationalization stuff */
 
@@ -75,6 +78,7 @@ static Bool cvtOLLCCL();
 /* updaters */
 
 static void updButtonFont();
+static void updCursors();
        void UpdFocusStyle();			/* yes, this one's global */
 static void updGlyphFont();
 static void updIconFont();
@@ -102,20 +106,23 @@ static void updVirtualFontColor();
 static void updVirtualScale();
 static void updVirtualGridColor();
 static void updInputFocusColor();
+static void updVirtualDrawSticky();
+static void updIconSlots();
 
-extern void setScreenVirtualForegroundColor();
-extern void setScreenVirtualBackgroundColor();
-extern void setScreenVirtualFontColor();
-extern void setScreenVirtualGridColor();
-extern void setScreenInputFocusColor();
-extern void updateScreenVirtualFont();
-extern void updateScreenVirtualMap();
-extern void updateScreenVirtualGeometry();
-extern void updateScreenVirtualDesktop();
-extern void updateScreenVirtualIconGeometry();
-extern void updateScreenVirtualScale();
-extern void setScreenVirtualPixmapColor();
-extern void setScreenInputFocusColor();
+extern void SetScreenVirtualForegroundColor();
+extern void SetScreenVirtualBackgroundColor();
+extern void SetScreenVirtualFontColor();
+extern void SetScreenVirtualGridColor();
+extern void SetScreenInputFocusColor();
+extern void UpdateScreenVirtualFont();
+extern void UpdateScreenVirtualMap();
+extern void UpdateScreenVirtualGeometry();
+extern void UpdateScreenVirtualDesktop();
+extern void UpdateScreenVirtualIconGeometry();
+extern void UpdateScreenVirtualScale();
+extern void UpdateScreenVirtualDrawSticky();
+extern void SetScreenVirtualPixmapColor();
+extern void SetScreenInputFocusColor();
 
 /* resource table */
 
@@ -154,7 +161,6 @@ ResourceItem ResourceTable[] = {
 {   "cursorFont",		"CursorFont",
     "-sun-open look cursor-*-*-*-*-*-120-*-*-*-*-*-*",
     &(GRV.BasicPointer),	cvtCursorFont,		NULL },
-
 {   "foreground",		"Foreground",		"#000000",
     &(GRV.ForegroundColor),	cvtString,		updForeground },
 {   "background",		"Background",		"#ffffff",
@@ -249,7 +255,7 @@ ResourceItem ResourceTable[] = {
     &(GRV.SingleScreen),	cvtBoolean,		NULL },
 {   "autoReReadMenuFile",        "AutoReReadMenuFile",  "True",
     &(GRV.AutoReReadMenuFile),  cvtBoolean,		NULL },
-{   "keepTransientsAbove",	"KeepTransientsAbove",	"True",
+{   "keepTransientsAbove",	"KeepTransientsAbove",	"False",
     &(GRV.KeepTransientsAbove),	cvtBoolean,		NULL },
 {   "transientsSaveUnder",	"TransientsSaveUnder",	"True",
     &(GRV.TransientsSaveUnder),	cvtBoolean,		NULL },
@@ -263,7 +269,7 @@ ResourceItem ResourceTable[] = {
     &(GRV.ShowResizeGeometry),	cvtBoolean,		NULL },
 {   "invertFocusHighlighting",	"InvertFocusHighlighting", "False",
     &(GRV.InvertFocusHighlighting), cvtBoolean,		NULL },
-{   "runSlaveProcess",		"RunSlaveProcess",	"False",
+{   "runSlaveProcess",		"RunSlaveProcess",	"True",
     &(GRV.RunSlaveProcess),	cvtBoolean,		NULL },
 {   "selectToggleStacking",	"SelectToggleStacking","False",
     &(GRV.SelectToggleStacking),cvtBoolean,		NULL },
@@ -281,7 +287,7 @@ ResourceItem ResourceTable[] = {
     &(GRV.SelectDisplaysMenu),	cvtBoolean,		NULL },
 {   "selectionFuzz",		"SelectionFuzz",	"1",
     &(GRV.SelectionFuzz),	cvtInteger,		NULL },
-{   "autoInputFocus",		"AutoInputFocus",	"True",
+{   "autoInputFocus",		"AutoInputFocus",	"False",
     &(GRV.AutoInputFocus),	cvtBoolean,		NULL },
 {   "autoColorFocus",		"AutoColorFocus",	"False",
     &(GRV.AutoColorFocus),	cvtBoolean,		NULL },
@@ -301,29 +307,29 @@ ResourceItem ResourceTable[] = {
 #ifdef OW_I18N_L3
 
 {   "basicLocale",		"BasicLocale",		NULL,
-    &(GRV.LC.BasicLocale),      cvtOLLC,                NULL },
+    &(GRV.LC.BasicLocale),	cvtOLLC,		NULL },
 {   "basicLocaleCL",		"BasicLocaleCL",	NULL,
-    &(GRV.LC.BasicLocale),      cvtOLLCCL,              NULL },
+    &(GRV.LC.BasicLocale),	cvtOLLCCL,		NULL },
 
 {   "displayLang",		"DisplayLang",		NULL,
-    &(GRV.LC.DisplayLang),      cvtOLLC,                NULL },
+    &(GRV.LC.DisplayLang),	cvtOLLC,		NULL },
 {   "displayLangCL",		"DisplayLangCL",	NULL,
-    &(GRV.LC.DisplayLang),      cvtOLLCCL,              NULL },
+    &(GRV.LC.DisplayLang),	cvtOLLCCL,		NULL },
 
 {   "inputLang",		"InputLang",		NULL,
-    &(GRV.LC.InputLang),        cvtOLLC,                NULL },
+    &(GRV.LC.InputLang),	cvtOLLC,		NULL },
 {   "inputLangCL",		"InputLangCL",		NULL,
-    &(GRV.LC.InputLang),        cvtOLLCCL,              NULL },
-
+    &(GRV.LC.InputLang),	cvtOLLCCL,		NULL },
+ 
 {   "numeric",			"Numeric",		NULL,
-    &(GRV.LC.Numeric),          cvtOLLC,                NULL },
+    &(GRV.LC.Numeric),		cvtOLLC,		NULL },
 {   "numericCL",		"NumericCL",		NULL,
-    &(GRV.LC.Numeric),          cvtOLLCCL,              NULL },
-
+    &(GRV.LC.Numeric),		cvtOLLCCL,		NULL },
+ 
 {   "dateFormat",		"DateFormat",		NULL,
-    &(GRV.LC.DateFormat),       cvtOLLC,                NULL },
+    &(GRV.LC.DateFormat),	cvtOLLC,		NULL },
 {   "dateFormatCL",		"DateFormatCL",		NULL,
-    &(GRV.LC.DateFormat),       cvtOLLCCL,              NULL },
+    &(GRV.LC.DateFormat),	cvtOLLCCL,		NULL },
 
 #endif /* OW_I18N_L3 */
 
@@ -352,43 +358,101 @@ ResourceItem ResourceTable[] = {
 {   "virtualFontColor",		"VirtualFontColor",	NULL,
     &(GRV.VirtualFontColor),	cvtString,		updVirtualFontColor },
 {   "virtualIconic",		"VirtualIconic",	"False",
-    &(GRV.VirtualIconic),	cvtBoolean,		NULL 		},
+    &(GRV.VirtualIconic),	cvtBoolean,		NULL		},
 {   "virtualSticky",		"VirtualSticky",	"",
-    &(GRV.StickyList),		cvtStringList,		NULL, 		},
+    &(GRV.StickyList),		cvtStringList,		NULL		},
 {   "relativePosition",		"RelativePosition",	"True",
-    &(GRV.UseRelativePosition),	cvtBoolean,		NULL 		},
+    &(GRV.UseRelativePosition),	cvtBoolean,		NULL		},
 {   "grabVirtualKeys",		"GrabVirtualKeys",	"True",
-    &(GRV.GrabVirtualKeys),	cvtBoolean,		NULL 		},
+    &(GRV.GrabVirtualKeys),	cvtBoolean,		NULL		},
 {   "virtualGrid",		"VirtualGrid",		"Visible",
-    &(GRV.VirtualGrid),		cvtGridEnum,		NULL 		},
+    &(GRV.VirtualGrid),		cvtGridEnum,		NULL		},
 {   "virtualGridColor",		"VirtualGridColor",	"Black",
     &(GRV.VirtualGridColor),	cvtString,		updVirtualGridColor },
 {   "raiseOnMove",		"RaiseOnMove",		"False",
-    &(GRV.VirtualRaiseOnMove),	cvtBoolean,		NULL 		},
+    &(GRV.VirtualRaiseOnMove),	cvtBoolean,		NULL,		},
 {   "virtualRaiseVDM",		"VirtualRaiseVDM",	"False",
-    &(GRV.VirtualRaiseVDM),	cvtBoolean,		NULL 		},
+    &(GRV.VirtualRaiseVDM),	cvtBoolean,		NULL		},
 {   "AutoShowRootMenu",		"AutoShowRootMenu",	"False",
-    &(GRV.AutoShowRootMenu),	cvtBoolean,		NULL 		},
+    &(GRV.AutoShowRootMenu),	cvtBoolean,		NULL		},
 {   "AutoRootMenuX",		"AutoRootMenuX",	"0",
-    &(GRV.AutoRootMenuX),	cvtInteger,		NULL 		},
+    &(GRV.AutoRootMenuX),	cvtInteger,		NULL		},
 {   "AutoRootMenuY",		"AutoRootMenuY",	"0",
-    &(GRV.AutoRootMenuY),	cvtInteger,		NULL 		},
+    &(GRV.AutoRootMenuY),	cvtInteger,		NULL		},
 {   "inputFocusColor",		"InputFocusColor",	NULL,
     &(GRV.InputFocusColor),	cvtString,		updInputFocusColor },
 {   "fullSizeZoomX",		"FullSizeZoomX",	"False",
-    &(GRV.FullSizeZoomX),	cvtBoolean,		NULL 		},
+    &(GRV.FullSizeZoomX),	cvtBoolean,		NULL		},
 {   "noDecor",			"NoDecor",		"",
-    &(GRV.NoDecors),		cvtStringList,		NULL 		},
+    &(GRV.NoDecors),		cvtStringList,		NULL		},
 {   "resizeMoveGeometry",	"ResizeMoveGeometry",	"0+0",
-    &(GRV.ResizePosition),	cvtString,		NULL 		},
+    &(GRV.ResizePosition),	cvtString,		NULL		},
 {   "useImages",		"UseImages",		"UseVDM",
     &(GRV.UseImageMenu),	cvtImageType,		NULL		},
 {   "virtualMoveGroup",		"VirtualMoveGroup",	"True",
     &(GRV.VirtualMoveGroups),	cvtBoolean,		NULL		},
-{   "pointerWorkspace",		"PointerWorkspace",	"False",
+{   "stickyIcons",		"StickyIcons",		"False",
+    &(GRV.StickyIcons),		cvtBoolean,		NULL		},
+{   "stickyIconScreen",		"StickyIconScreen",	"False",
+    &(GRV.StickyIconScreen),	cvtBoolean,		NULL		},
+{   "pointerWorkspace",		"PointerWorkspace",	"True",
     &(GRV.PointerWorkspace),	cvtBoolean,		NULL		},
 {   "saveWorkspaceCmd",		"SaveWorkspaceCmd",	NULL,
     &(GRV.SaveWorkspaceCmd),	cvtString,		NULL		},
+{   "sortMenuType",		"SortMenuType",		"Alphabetic",
+    &(GRV.VirtualMenuSort),	cvtSortType,		NULL		},
+{   "sortDirType",		"SortDirType",		"Alphabetic",
+    &(GRV.VirtualDirSort),	cvtSortType,		NULL		},
+{   "cursorSpecialResize",    "CursorSpecialResize",  "False",
+    &(GRV.SpecialResizePointerData), cvtString,         updCursors	},
+{   "cursorBasic",            "CursorBasic",          "OLC_basic",
+    &(GRV.BasicPointerData),  cvtString,              updCursors	},
+{   "cursorMove",             "CursorMove",           "OLC_basic",
+    &(GRV.MovePointerData),   cvtString,              updCursors	},
+{   "cursorBusy",             "CursorBusy",           "OLC_busy",
+    &(GRV.BusyPointerData),   cvtString,              updCursors	},
+{   "cursorIcon",             "CursorIcon",           "OLC_basic",
+    &(GRV.IconPointerData),   cvtString,              updCursors	},
+{   "cursorResize",           "CursorResize",         "OLC_beye",
+    &(GRV.ResizePointerData), cvtString,              updCursors	},
+{   "cursorMenu",             "CursorMenu",           "OLC_basic",
+    &(GRV.MenuPointerData),   cvtString,              updCursors	},
+{   "cursorQuestion",         "CursorQuestion",       "OLC_basic",
+    &(GRV.QuestionPointerData),       cvtString,      updCursors	},
+{   "cursorTarget",           "CursorTarget",         "OLC_basic",
+    &(GRV.TargetPointerData), cvtString,              updCursors	},
+{   "cursorPan",              "CursorPan",            "OLC_basic",
+    &(GRV.PanPointerData),    cvtString,              updCursors	},
+{   "cursorCloseUp",          "CursorCloseUp",        "OLC_basic",
+    &(GRV.CloseUpPointerData),        cvtString,      updCursors	},
+{   "cursorCloseDown",        "CursorCloseDown",      "OLC_basic",
+    &(GRV.CloseDownPointerData),cvtString,            updCursors	},
+{   "virtualReRead",          "VirtualReRead",        "True",
+    &(GRV.VirtualReRead),     cvtBoolean,             NULL		},
+{   "SyntheticEvents",        "SyntheticEvents",      "False",
+    &(GRV.SyntheticEvents),    cvtBoolean,            NULL		},
+{   "allowSyntheticsEvents",  "AllowSyntheticEvents","False",
+    &(GRV.AllowSyntheticEvents),cvtNoop,              NULL		},
+{   "parentScreenPopup",	"ParentScreenPopup", "True",
+    &(GRV.ParentScreenPopup), cvtBoolean,             NULL		},
+{   "noVirtualKey",           "NoVirtualKey",         "",
+    &(GRV.NoVirtualKey),      cvtStringList,          NULL		},
+{   "noVirtualFKey",          "NoVirtualFKey",        "",
+    &(GRV.NoVirtualFKey),     cvtStringList,          NULL		},
+{   "noVirtualLKey",          "NoVirtualLKey",        "",
+    &(GRV.NoVirtualLKey),     cvtStringList,          NULL		},
+{   "noVirtualRKey",          "NoVirtualRKey",        "",
+    &(GRV.NoVirtualRKey),     cvtStringList,          NULL		},
+{   "virtualDrawSticky",      "VirtualDrawSticky",    "True",
+    &(GRV.VirtualDrawSticky), cvtBoolean,             updVirtualDrawSticky },
+{   "freeIconSlots",         "FreeIconSlots",        "False",
+    &(GRV.FreeIconSlots),    cvtBoolean,             NULL		},
+{   "iconGridHeight",        "IconGridHeight",       "13",
+    &(GRV.IconGridHeight),   cvtInteger,             updIconSlots	},
+{   "iconGridWidth",         "IconGridWidth",        "13",
+    &(GRV.IconGridWidth),    cvtInteger,             updIconSlots	},
+{   "uniqueIconSlots",       "UniqueIconSlots",      "False",
+    &(GRV.UniqueIconSlots),  cvtBoolean,             NULL		},
 };
 
 #define NRESOURCEITEMS (sizeof(ResourceTable)/sizeof(ResourceItem))
@@ -400,7 +464,7 @@ ResourceItem ResourceTable[] = {
 /*
  * Copy a string, converting it to lower case.
  */
-static void
+void
 strnlower(dest, src, n)
     char *dest;
     char *src;
@@ -440,7 +504,7 @@ MatchString(value, pattern)
  * true, false.  Pass back the boolean matched in ret, and return True.  
  * Otherwise, return False.  Matches are case-insensitive.
  */
-static Bool
+Bool
 matchBool(value, ret)
     char *value;
     Bool *ret;
@@ -727,14 +791,14 @@ parseKeySpec(dpy, str, modmask, keycode)
 
 
 #ifdef OW_I18N_L3
-
+ 
 static void
 setOLLCPosix()
 {
        register OLLCItem       *ollci, *ollci_end;
-       register char           *current;
-
-
+       register char	       *current;
+ 
+ 
        ollci = &(GRV.LC.BasicLocale);
        ollci_end = &ollci[OLLC_LC_MAX];
        for (ollci++; ollci < ollci_end; ollci++)
@@ -747,9 +811,9 @@ setOLLCPosix()
                                                ollci->posix_category, NULL));
                        OLLCUpdated = True;
                }
-      }
+       }
 }
-
+ 
 #endif /* OW_I18N_L3 */
 
 
@@ -771,6 +835,7 @@ setOLLCPosix()
 
 
 static Bool
+/* ARGSUSED */
 cvtBoolean(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -784,8 +849,8 @@ cvtBoolean(dpy, item, string, addr)
     return matchBool(string, (Bool *)addr);
 }
 
-
 static Bool
+/* ARGSUSED */
 cvtFont(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -821,8 +886,12 @@ cvtFont(dpy, item, string, addr)
  *
  * REMIND: this appears to have a resource leak, in that cursorFont is loaded 
  * but never unloaded.
+ *
+ * This function became obsolete in version 3.2 of olvwm, when all cursors
+ * started to be defined in initCursor in cursor.c
  */
 static Bool
+/* ARGSUSED */
 cvtCursorFont(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -833,6 +902,7 @@ cvtCursorFont(dpy, item, string, addr)
     char	    *addr;
 #endif
 {
+#ifdef not
     Font	    cursorFont;
     int		    ii;
     Cursor	    *tmpVariable;
@@ -850,7 +920,7 @@ cvtCursorFont(dpy, item, string, addr)
      * thing.
      */
 
-    if (cursorFont == (Font)NULL)
+    if (cursorFont == NULL)
 	return False;
 
     /*
@@ -932,15 +1002,15 @@ cvtCursorFont(dpy, item, string, addr)
 #endif
 	}
     }
-
+#endif
     return True;
 }
 
-
 /*
  * Converting a string simply means making a copy of it.
  */
 static Bool
+/* ARGSUSED */
 cvtString(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -962,6 +1032,7 @@ cvtString(dpy, item, string, addr)
 
 
 static Bool
+/* ARGSUSED */
 cvtFloat(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -981,6 +1052,7 @@ cvtFloat(dpy, item, string, addr)
  * hexadecimal representations.
  */
 static Bool
+/* ARGSUSED */
 cvtInteger(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -999,6 +1071,7 @@ cvtInteger(dpy, item, string, addr)
  * Convert a string representing tenths of a second into milliseconds.
  */
 static Bool
+/* ARGSUSED */
 cvtClickTimeout(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1031,6 +1104,7 @@ cvtClickTimeout(dpy, item, string, addr)
 
 
 static Bool
+/* ARGSUSED */
 cvtFocusStyle(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1046,6 +1120,7 @@ cvtFocusStyle(dpy, item, string, addr)
 
 
 static Bool
+/* ARGSUSED */
 cvtBeepStatus(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1061,6 +1136,7 @@ cvtBeepStatus(dpy, item, string, addr)
 
 
 static Bool
+/* ARGSUSED */
 cvtMouseless(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1076,6 +1152,7 @@ cvtMouseless(dpy, item, string, addr)
 
 
 static Bool
+/* ARGSUSED */
 cvtIconLocation(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1095,6 +1172,7 @@ cvtIconLocation(dpy, item, string, addr)
  * key specification stuff in evbind.c.
  */
 static Bool
+/* ARGSUSED */
 cvtKey(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1146,6 +1224,7 @@ static void *
 #else
 static char *
 #endif
+/* ARGSUSED */
 freeStringList(str,junk)
 char *str;
 #ifndef COHERENT
@@ -1160,6 +1239,7 @@ char *junk;
 
 
 static Bool
+/* ARGSUSED */
 cvtStringList(dpy, item, string, addr)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1187,6 +1267,7 @@ cvtStringList(dpy, item, string, addr)
  * handles both the conversion and update functions itself.
  */
 static Bool
+/* ARGSUSED */
 _cvtOLLC(dpy, item, string, addr, priority)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1238,7 +1319,6 @@ _cvtOLLC(dpy, item, string, addr, priority)
     return True;
 }
 
-
 static Bool
 cvtOLLC(dpy, item, string, addr)
     Display	    *dpy;
@@ -1248,22 +1328,21 @@ cvtOLLC(dpy, item, string, addr)
 {
     return _cvtOLLC(dpy, item, string, addr, OLLC_SRC_RESOURCE);
 }
-
-
+ 
+ 
 static Bool
 cvtOLLCCL(dpy, item, string, addr)
-    Display	    *dpy;
+    Display         *dpy;
     ResourceItem    *item;
-    char	    *string;
-    void	    *addr;
+    char            *string;
+    void            *addr;
 {
     return _cvtOLLC(dpy, item, string, addr, OLLC_SRC_COMMAND_LINE);
 }
-
+ 
 #endif /* OW_I18N_L3 */
 
 
-
 /* ===== Updaters ========================================================= */
 
 
@@ -1280,6 +1359,7 @@ cvtOLLCCL(dpy, item, string, addr)
  */
 
 static void
+/* ARGSUSED */
 updString(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1291,6 +1371,7 @@ updString(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updStringList(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1303,6 +1384,7 @@ updStringList(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updWorkspace(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1315,6 +1397,7 @@ updWorkspace(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updWindow(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1327,6 +1410,7 @@ updWindow(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updForeground(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1338,6 +1422,7 @@ updForeground(dpy, item, cur, new)
 }
 
 static void
+/* ARGSUSED */
 updBackground(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1349,6 +1434,7 @@ updBackground(dpy, item, cur, new)
 }
 
 static void
+/* ARGSUSED */
 updBorder(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1361,6 +1447,7 @@ updBorder(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updSync(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1374,6 +1461,7 @@ updSync(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updTitleFont(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1386,6 +1474,7 @@ updTitleFont(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updTextFont(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1398,6 +1487,7 @@ updTextFont(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updButtonFont(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1410,6 +1500,7 @@ updButtonFont(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updIconFont(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1422,6 +1513,7 @@ updIconFont(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updGlyphFont(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1434,6 +1526,7 @@ updGlyphFont(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updIconLocation(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1447,6 +1540,7 @@ updIconLocation(dpy, item, cur, new)
 
 
 static void
+/* ARGSUSED */
 updMouseless(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1522,6 +1616,7 @@ reconfigureFocus(cli)
  * services.c.  This call passes NULL for item.  This needs to be cleaned up.
  */
 void
+/* ARGSUSED */
 UpdFocusStyle(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1537,7 +1632,6 @@ UpdFocusStyle(dpy, item, cur, new)
 
 /* ===== Global Functions ================================================= */
 
-
 /*
  * InitGlobals -- probe OlwmDB for resources and store values into global 
  * variables.  Called once at startup time.
@@ -1554,13 +1648,15 @@ InitGlobals(dpy)
     XrmQuark instances[3];
     char buf[1000];
     Bool	found;
-
+ 
+    found = GRV.AllowSyntheticEvents;
     (void) memset((char *) &GRV, 0, sizeof(GRV));
-
+    GRV.AllowSyntheticEvents = found;
+ 
 #ifdef OW_I18N_L3
     GRVLCInit();
 #endif /* OW_I18N_L3 */
-
+ 
     classes[2] = instances[2] = NULLQUARK;
     instances[0] = TopInstanceQ;
 
@@ -1584,8 +1680,8 @@ InitGlobals(dpy)
 
 	if (!XrmQGetResource(OlwmDB, instances, classes, &type, &value)) {
 	    classes[0] = OlwmQ;
-	    found = XrmQGetResource(OlwmDB, instances, classes, &type, &value);
-	}
+	    found = XrmQGetResource(OlwmDB, instances, classes, &type, &value);	
+    }
 	else found = True;
 	if (found)
 	    found = (*item->converter)(dpy, item,
@@ -1625,7 +1721,6 @@ typedef union _datum {
 
 static XrmBinding Bindings[] = { XrmBindTightly, XrmBindTightly };
 
-
 /*
  * UpdateGlobals -- handle updates to the server's resource database.  Called
  * every time the server's RESOURCE_MANAGER property changes.  stringdb is the
@@ -1693,14 +1788,14 @@ UpdateGlobals(dpy, stringdb)
 	     */
 	    classes[0] = OlwmQ;
 	    if (XrmQGetResource(newDB, instances, classes, &type, &newvalue)) {
-	        if (XrmQGetResource(OlwmDB, instances, classes,
+	            if (XrmQGetResource(OlwmDB, instances, classes,
 				&type, &oldvalue) &&
-	            0 == strcmp((char *)newvalue.addr, (char *)oldvalue.addr))
-	    	    {
-	        	    /* old and new values the same; ignore */
+	                0 == strcmp((char *)newvalue.addr, (char *)oldvalue.addr))
+	            {
+		            /* old and new values the same; ignore */
 			    classes[0] = OpenWinQ;
-	        	    continue;
-	    	    }
+			    continue;
+	             }
 
 	        XrmQPutStringResource(&OlwmDB, Bindings, instances,
 			              (char *)newvalue.addr);
@@ -1709,9 +1804,9 @@ UpdateGlobals(dpy, stringdb)
 	            (void) (*item->converter)(dpy, item, (char *)newvalue.addr,
 				              item->addr);
 	        } else {
-	            (void) memset((char *) &datum, 0, sizeof(datum));
+		    (void) memset((char *) &datum, 0, sizeof(datum));
 	            if ((*item->converter)(dpy, item,
-					   (char *)newvalue.addr, &datum))
+				           (char *)newvalue.addr, &datum))
 		        (*item->updater)(dpy, item, item->addr, &datum);
 		}
 	    }
@@ -1728,39 +1823,38 @@ UpdateGlobals(dpy, stringdb)
     XrmDestroyDatabase(newDB);
 }
 
-
 #ifdef OW_I18N_L3
 
  /*
-  * GRVLCInit: Here is the table for OPEN LOOK locale and POSIX/ANSI-C
+  * GRVLCInit:  here is the table for OPEN LOOK local and POSIX/ANSI-C
   * locale categories.
   */
 static void
 GRVLCInit()
 {
-       GRV.LC.BasicLocale.posix_category       = LC_CTYPE;
-       GRV.LC.DisplayLang.posix_category       = LC_MESSAGES;
-       GRV.LC.InputLang.posix_category         = -1;
-       GRV.LC.Numeric.posix_category           = LC_NUMERIC;
-       GRV.LC.DateFormat.posix_category        = LC_TIME;
+       GRV.LC.BasicLocale.posix_category	= LC_CTYPE;
+       GRV.LC.DisplayLang.posix_category	= LC_MESSAGES;
+       GRV.LC.InputLang.posix_category		= -1;
+       GRV.LC.Numeric.posix_category		= LC_NUMERIC;
+       GRV.LC.DateFormat.posix_category		= LC_TIME;
 }
 
 /*
  * ReInitAllUserMenus -- Reinitalize the user menus for each screen
  */
 static void
-ReInitAllUserMenus(dpy, force) 
+ReInitAllUserMenus(dpy, force)
     Display         *dpy;
-    Bool	    force;
+    Bool            force;
 {
 ScreenInfo      *si;
 extern List	*ScreenInfoList;
 List            *l = ScreenInfoList;
-			   
+ 
     for (si = ListEnum(&l); si; si = ListEnum(&l))
 	ReInitUserMenu(dpy, si, force);
 }
-
+ 
 void
 EffectOLLC(dpy)
 Display       *dpy;
@@ -1769,8 +1863,8 @@ Display       *dpy;
        register char           *current;
        register int            require_all_update;
        int                     messages_updated;
-
-
+ 
+ 
        if (!OLLCUpdated)
                return;
 
@@ -1787,7 +1881,7 @@ Display       *dpy;
        if (strcmp(current, "C") == 0
         && ollci_basic->locale != NULL
         && strcmp(current, ollci_basic->locale) != 0)
-       {
+       { 
                /*
                 * I'm doing LC_ALL rather only LC_CTYPE, becuase
                 * there are some locale category which does not
@@ -1798,17 +1892,17 @@ Display       *dpy;
 #endif
                setlocale(LC_ALL, ollci_basic->locale);
                require_all_update = True;
-       }
+       } 
 
 
        for (ollci = ollci_basic + 1; ollci < ollci_end; ollci++)
-       {
+       { 
                if (ollci->posix_category < 0)
                        continue;
                current = setlocale(ollci->posix_category, NULL);
                if (strcmp(current, ollci->locale) != 0
                || require_all_update == True)
-               {
+               { 
                        /*
                         * Again, we need following silly restriction
                         * in order to work well with EUC based
@@ -1817,7 +1911,7 @@ Display       *dpy;
                       if (strcmp(current, "C") == 0
                         || strcmp(ollci->locale, "C") == 0
                         || strcmp(ollci->locale, ollci_basic->locale) == 0)
-                       {
+                       { 
 #ifdef notdef
  fprintf(stderr, "locale#%d -> %s\n", ollci->posix_category, ollci->locale);
 #endif
@@ -1825,22 +1919,23 @@ Display       *dpy;
                                        ollci->locale);
                                if (ollci->posix_category == LC_MESSAGES)
                                        messages_updated = True;
-                       }
+                       } 
                }
-       }
+       } 
        OLLCUpdated = False;
 
        if (messages_updated == True) {
-		WindowMenuDestroy(dpy);
-		WindowMenuCreate(dpy);
-		ReInitAllUserMenus(dpy,True);
-       }
+                WindowMenuDestroy(dpy);
+                WindowMenuCreate(dpy);
+                ReInitAllUserMenus(dpy,True);
+       } 
 }
 
 #endif /* OW_I18N_L3 */
 
+
 /*
- * SetVirtualScreenAttribute - set the given attribute for each vdm
+ * setVirtualScreenAttribute - set the given attribute for each vdm
  */
 static void
 setVirtualScreenAttribute(dpy, f) 
@@ -1858,6 +1953,7 @@ List            *l = ScreenInfoList;
 }
 
 static void
+/* ARGSUSED */
 updVirtualFgColor(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1865,10 +1961,11 @@ updVirtualFgColor(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, setScreenVirtualForegroundColor);
+    setVirtualScreenAttribute(dpy, SetScreenVirtualForegroundColor);
 }
 
 static void
+/* ARGSUSED */
 updVirtualBgColor(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1876,10 +1973,11 @@ updVirtualBgColor(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, setScreenVirtualBackgroundColor);
+    setVirtualScreenAttribute(dpy, SetScreenVirtualBackgroundColor);
 }
 
 static void
+/* ARGSUSED */
 updVirtualFontColor(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1887,10 +1985,11 @@ updVirtualFontColor(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, setScreenVirtualFontColor);
+    setVirtualScreenAttribute(dpy, SetScreenVirtualFontColor);
 }
 
 static void
+/* ARGSUSED */
 updVirtualGridColor(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1898,10 +1997,11 @@ updVirtualGridColor(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, setScreenVirtualGridColor);
+    setVirtualScreenAttribute(dpy, SetScreenVirtualGridColor);
 }
 
 static void
+/* ARGSUSED */
 updInputFocusColor(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1909,10 +2009,11 @@ updInputFocusColor(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, setScreenInputFocusColor);
+    setVirtualScreenAttribute(dpy, SetScreenInputFocusColor);
 }
 
 static void
+/* ARGSUSED */
 updVirtualFont(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1920,10 +2021,11 @@ updVirtualFont(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, updateScreenVirtualFont);
+    setVirtualScreenAttribute(dpy, UpdateScreenVirtualFont);
 }
 
 static void
+/* ARGSUSED */
 updVirtualGeometry(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1931,10 +2033,11 @@ updVirtualGeometry(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, updateScreenVirtualGeometry);
+    setVirtualScreenAttribute(dpy, UpdateScreenVirtualGeometry);
 }
 
 static void
+/* ARGSUSED */
 updVirtualMap(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1942,10 +2045,11 @@ updVirtualMap(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, updateScreenVirtualMap);
+    setVirtualScreenAttribute(dpy, UpdateScreenVirtualMap);
 }
 
 static void
+/* ARGSUSED */
 updVirtualMapColor(dpy, item, cur, new)
     Display	    *dpy;
     ResourceItem    *item;
@@ -1953,10 +2057,11 @@ updVirtualMapColor(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, setScreenVirtualPixmapColor);
+    setVirtualScreenAttribute(dpy, SetScreenVirtualPixmapColor);
 }
 
 static void
+/* ARGSUSED */
 updVirtualDesktop(dpy, item, cur, new)
     Display		*dpy;
     ResourceItem	*item;
@@ -1964,10 +2069,11 @@ updVirtualDesktop(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, updateScreenVirtualDesktop);
+    setVirtualScreenAttribute(dpy, UpdateScreenVirtualDesktop);
 }
 
 static void
+/* ARGSUSED */
 updVirtualIconGeometry(dpy, item, cur, new)
     Display		*dpy;
     ResourceItem	*item;
@@ -1975,18 +2081,29 @@ updVirtualIconGeometry(dpy, item, cur, new)
 {
     MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, updateScreenVirtualIconGeometry);
+    setVirtualScreenAttribute(dpy, UpdateScreenVirtualIconGeometry);
 }
 
 static void
+/* ARGSUSED */
 updVirtualScale(dpy, item, cur, new)
     Display		*dpy;
     ResourceItem	*item;
     char		**cur, **new;
 {
-    MemFree(*cur);
     *cur = *new;
-    setVirtualScreenAttribute(dpy, updateScreenVirtualScale);
+    setVirtualScreenAttribute(dpy, UpdateScreenVirtualScale);
+}
+
+static void
+/* ARGSUSED */
+updVirtualDrawSticky(dpy, item, cur, new)
+    Display		*dpy;
+    ResourceItem	*item;
+    char		**cur, **new;
+{
+    *cur = *new;
+    setVirtualScreenAttribute(dpy, UpdateScreenVirtualDrawSticky);
 }
 
 static Bool
@@ -2015,6 +2132,37 @@ cvtGridEnum(dpy, item, value, ret)
 	return False;
 }
 
+static Bool
+/* ARGSUSED */
+cvtSortType(dpy, item, value, ret)
+    Display	    *dpy;
+    ResourceItem    *item;
+    char	    *value;
+    VirtualGridType *ret;
+{
+	if (MatchString(value,"alphabetic"))
+	{
+	    *ret = SortAlpha;
+	    return True;
+	}
+	if (MatchString(value,"youngest"))
+	{
+	    *ret = SortYounger;
+	    return True;
+	}
+	if (MatchString(value,"allalphabetic"))
+	{
+	    *ret = SortAlphaAll;
+	    return True;
+	}
+	if (MatchString(value,"allyoungest"))
+	{
+	    *ret = SortYoungerAll;
+	    return True;
+	}
+	return False;
+}
+
 static Bool
 /* ARGSUSED */
 cvtImageType(dpy, item, value, ret)
@@ -2040,3 +2188,46 @@ cvtImageType(dpy, item, value, ret)
 	}
 	return False;
 }
+
+static Bool
+/* ARGSUSED */
+cvtNoop(dpy, item, value, ret)
+    Display	    *dpy;
+    ResourceItem    *item;
+    char	    *value;
+#ifndef COHERENT
+    void 	    *ret;
+#else
+    char 	    *ret;
+#endif
+{
+    return False;
+}
+
+static void
+/* ARGSUSED */
+updCursors(dpy, item, cur, new)
+    Display		*dpy;
+    ResourceItem	*item;
+    char		**cur, **new;
+{
+    /* free the new string, as the cursors never update */
+    MemFree(*new);
+}
+
+static void
+updIconSlots(dpy, item, cur, new)
+    Display		*dpy;
+    ResourceItem	*item;
+    char		**cur, **new;
+{
+    ScreenInfo      *si;
+    extern List	    *ScreenInfoList;
+    List            *l = ScreenInfoList;
+			   
+    *cur = *new;
+
+    for (si = ListEnum(&l); si; si = ListEnum(&l)) {
+	SlotSetLocations(dpy,si->iconGrid);
+    }
+}
