@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)screen.c	1.2 olvwm version 1/27/92"
+#ifdef IDENT
+#ident	"@(#)screen.c	1.5 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -22,9 +24,10 @@
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
 #include <X11/Xresource.h>
-#include <olgx/olgx.h>
 
 #include "i18n.h"
+#include <olgx/olgx.h>
+
 #include "ollocale.h"
 #include "mem.h"
 #include "olwm.h"
@@ -36,6 +39,7 @@
 #include "menu.h"
 #include "slots.h"
 #include "virtual.h"
+#include "cursors.h"
 
 #include "iconimage.h"
 #include "iconmask.h"
@@ -327,7 +331,6 @@ initVisual(dpy, scrInfo)
     ScreenInfo *scrInfo;
 {
     char *buf;
-    char *p;
     XVisualInfo vtemplate;
     unsigned int vinfomask = 0;
     XVisualInfo *vinfo = NULL;
@@ -885,10 +888,10 @@ setScreenBorderColor(dpy,scrInfo)
 }
 
 /*
- *	setScreenVirtualForegroundColor - sets virtual window color for a screen
+ *	SetScreenVirtualForegroundColor - sets virtual window color for a screen
  */
 void
-setScreenVirtualForegroundColor(dpy,scrInfo)
+SetScreenVirtualForegroundColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -931,14 +934,14 @@ setScreenVirtualForegroundColor(dpy,scrInfo)
 	}
 
 	if (update)
-		updateScreenVirtualForegroundColor(dpy,scrInfo);
+		UpdateScreenVirtualForegroundColor(dpy,scrInfo);
 }
 
 /*
- *	setScreenVirtualBackgroundColor - sets virtual backgr color for a screen
+ *	SetScreenVirtualBackgroundColor - sets virtual backgr color for a screen
  */
 void
-setScreenVirtualBackgroundColor(dpy,scrInfo)
+SetScreenVirtualBackgroundColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -981,14 +984,14 @@ setScreenVirtualBackgroundColor(dpy,scrInfo)
 	}
 
 	if (update)
-		updateScreenVirtualBackgroundColor(dpy,scrInfo);
+		UpdateScreenVirtualBackgroundColor(dpy,scrInfo);
 }
 
 /*
- *	setScreenVirtualPixmapColor - sets virtual Pixmap color for a screen
+ *	SetScreenVirtualPixmapColor - sets virtual Pixmap color for a screen
  */
 void
-setScreenVirtualPixmapColor(dpy,scrInfo)
+SetScreenVirtualPixmapColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -1029,14 +1032,14 @@ setScreenVirtualPixmapColor(dpy,scrInfo)
 	}
 
 	if (update)
-		updateScreenVirtualPixmapColor(dpy,scrInfo);
+		UpdateScreenVirtualPixmapColor(dpy,scrInfo);
 }
 
 /*
- *	setScreenVirtualFontColor - sets virtual Font color for a screen
+ *	SetScreenVirtualFontColor - sets virtual Font color for a screen
  */
 void
-setScreenVirtualFontColor(dpy,scrInfo)
+SetScreenVirtualFontColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -1076,14 +1079,14 @@ setScreenVirtualFontColor(dpy,scrInfo)
 	}
 
 	if (update)
-		updateScreenVirtualFontColor(dpy,scrInfo);
+		UpdateScreenVirtualFontColor(dpy,scrInfo);
 }
 
 /*
- *	setScreenVirtualGridColor - sets virtual Grid color for a screen
+ *	SetScreenVirtualGridColor - sets virtual Grid color for a screen
  */
 void
-setScreenVirtualGridColor(dpy,scrInfo)
+SetScreenVirtualGridColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -1124,11 +1127,12 @@ setScreenVirtualGridColor(dpy,scrInfo)
 	}
 
 	if (update)
-		updateScreenVirtualGridColor(dpy,scrInfo);
+		UpdateScreenVirtualGridColor(dpy,scrInfo);
 }
 
 void
-setScreenVirtualIconColor(dpy,scrInfo)
+/* ARGSUSED */
+SetScreenVirtualIconColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -1144,7 +1148,7 @@ setScreenVirtualIconColor(dpy,scrInfo)
  *	setScreenInputFocusColor - sets InputFocus color for a screen
  */
 void
-setScreenInputFocusColor(dpy,scrInfo)
+SetScreenInputFocusColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -1281,13 +1285,13 @@ initColors(dpy,scrInfo)
 	setScreenWindowColor(dpy,scrInfo);
 	setScreenWorkspaceColor(dpy,scrInfo);
 
-	setScreenVirtualForegroundColor(dpy,scrInfo);
-	setScreenVirtualBackgroundColor(dpy,scrInfo);
-	setScreenVirtualFontColor(dpy,scrInfo);
-	setScreenVirtualGridColor(dpy,scrInfo);
-	setScreenInputFocusColor(dpy,scrInfo);
-	setScreenVirtualPixmapColor(dpy, scrInfo);
-	setScreenVirtualIconColor(dpy, scrInfo);
+	SetScreenVirtualForegroundColor(dpy,scrInfo);
+	SetScreenVirtualBackgroundColor(dpy,scrInfo);
+	SetScreenVirtualFontColor(dpy,scrInfo);
+	SetScreenVirtualGridColor(dpy,scrInfo);
+	SetScreenInputFocusColor(dpy,scrInfo);
+	SetScreenVirtualPixmapColor(dpy, scrInfo);
+	SetScreenVirtualIconColor(dpy, scrInfo);
 }
 
 /*
@@ -1298,9 +1302,10 @@ initPixmaps(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
-	int		result, junk;
+	int		junk;
 	unsigned int	width, height;
 	Pixmap		tempPixmap;
+	Pixlabel	tempPixlabel;
 
 	scrInfo->pixmap[BUSY_STIPPLE] = XCreateBitmapFromData(
 		dpy,scrInfo->rootid,
@@ -1308,13 +1313,11 @@ initPixmaps(dpy,scrInfo)
 
 	scrInfo->pixmap[ICON_BITMAP] = None;
 	if (GRV.DefaultIconImage != NULL) {
-	    if (BitmapSuccess == XReadBitmapFile(dpy, scrInfo->rootid,
-		    GRV.DefaultIconImage, &width, &height,
-		    &tempPixmap, &junk, &junk))
-	    {
-		scrInfo->pixmap[ICON_BITMAP] = tempPixmap;
-		scrInfo->dfltIconWidth = width;
-		scrInfo->dfltIconHeight = height;
+	    if (CreatePixmapFile(dpy, scrInfo, GRV.DefaultIconImage,
+				 &tempPixlabel)) {
+		scrInfo->pixmap[ICON_BITMAP] = tempPixlabel.pixmap;
+		scrInfo->dfltIconWidth = tempPixlabel.width;
+		scrInfo->dfltIconHeight = tempPixlabel.height;
 	    }
 	}
 
@@ -1363,7 +1366,6 @@ initGCs(dpy,scrInfo)
 	XGCValues       values;
 static	char		dashList[2] = { 1, 1 };
 	Window		rootwin = scrInfo->rootid;
-	int		screen = scrInfo->screen;
 	unsigned long	valuemask;
 	char		*resString;
 
@@ -1430,7 +1432,7 @@ static	char		dashList[2] = { 1, 1 };
         values.graphics_exposures = False;
         scrInfo->gc[WINDOW_GC] = XCreateGC( dpy,
 		scrInfo->pixmap[PROTO_DRAWABLE],
-		( GCFunction | GCForeground | GCFont | GCGraphicsExposures ),
+                ( GCFunction | GCForeground | GCFont | GCGraphicsExposures ),
 		&values );
 
 	/* 
@@ -1471,7 +1473,7 @@ static	char		dashList[2] = { 1, 1 };
         scrInfo->gc[ICON_NORMAL_GC] = XCreateGC( dpy,
 		scrInfo->pixmap[PROTO_DRAWABLE],
 		( GCFunction | GCForeground | GCBackground | 
-		  GCFont | GCGraphicsExposures ),
+                  GCFont | GCGraphicsExposures ),
 		&values );
 
 	/* 
@@ -1510,10 +1512,11 @@ static	char		dashList[2] = { 1, 1 };
 	values.foreground = values.background = scrInfo->colorInfo.inputBg1Color;
 	values.graphics_exposures = False;
 	values.function = GXcopy;
+        values.font = GRV.TitleFontInfo->fid;
 	scrInfo->gc[INPUTFOCUS_GC] = XCreateGC(dpy,
 			scrInfo->pixmap[PROTO_DRAWABLE],
 			( GCFunction | GCForeground | GCBackground |
-		  	  GCGraphicsExposures ),
+		  	  GCGraphicsExposures | GCFont ),
 		 	&values);
 	
 	/*
@@ -1584,7 +1587,7 @@ initOLGX(dpy,scrInfo)
 	scrInfo->gi[NORMAL_GINFO] = olgx_main_initialize(dpy,
 		scrInfo->screen, scrInfo->depth, dflag,
 		GRV.GlyphFontInfo,
-		GRV.TitleFontInfo,
+                GRV.TitleFontInfo,
 		pixvals,NULL);
 
 	/* 
@@ -1610,7 +1613,7 @@ initOLGX(dpy,scrInfo)
 	scrInfo->gi[TEXT_GINFO] = olgx_main_initialize(dpy,
 		scrInfo->screen, scrInfo->depth, OLGX_2D,
 	       	GRV.GlyphFontInfo,
-		GRV.TextFontInfo,
+                GRV.TextFontInfo,
 		pixvals,NULL);
 
 	/* 
@@ -1623,7 +1626,7 @@ initOLGX(dpy,scrInfo)
 	scrInfo->gi[REVPIN_GINFO] = olgx_main_initialize(dpy,
 		scrInfo->screen, scrInfo->depth, dflag,
 		GRV.GlyphFontInfo,
-		GRV.TitleFontInfo,
+                GRV.TitleFontInfo,
 		pixvals,NULL);
 	
 	/*
@@ -1791,9 +1794,10 @@ updateScreenBorderColor(dpy,scrInfo)
 }
 
 /*
- * updateScreenVirtualForegroundColor -- change all GC/Ginfo's that use vfg
+ * UpdateScreenVirtualForegroundColor -- change all GC/Ginfo's that use vfg
  */
-updateScreenVirtualForegroundColor(dpy,scrInfo)
+static
+UpdateScreenVirtualForegroundColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -1809,9 +1813,10 @@ updateScreenVirtualForegroundColor(dpy,scrInfo)
 }
 
 /*
- * updateScreenVirtualBackgroundColor -- change all GC/Ginfo's that use vfg
+ * UpdateScreenVirtualBackgroundColor -- change all GC/Ginfo's that use vfg
  */
-updateScreenVirtualBackgroundColor(dpy,scrInfo)
+static
+UpdateScreenVirtualBackgroundColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -1825,9 +1830,10 @@ updateScreenVirtualBackgroundColor(dpy,scrInfo)
 }
 
 /*
- * updateScreenVirtualFontColor -- change all GC/Ginfo's that use vfg
+ * UpdateScreenVirtualFontColor -- change all GC/Ginfo's that use vfg
  */
-updateScreenVirtualFontColor(dpy,scrInfo)
+static
+UpdateScreenVirtualFontColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -1843,9 +1849,11 @@ updateScreenVirtualFontColor(dpy,scrInfo)
 }
 
 /*
- * updateScreenVirtualGridColor -- change all GC/Ginfo's that use vfg
+ * UpdateScreenVirtualGridColor -- change all GC/Ginfo's that use vfg
  */
-updateScreenVirtualGridColor(dpy,scrInfo)
+/* ARGSUSED */
+static
+UpdateScreenVirtualGridColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -1857,6 +1865,8 @@ updateScreenVirtualGridColor(dpy,scrInfo)
 /*
  * updateScreenInputFocusColor -- change all GC/Ginfo's that use vfg
  */
+/* ARGSUSED */
+static
 updateScreenInputFocusColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
@@ -1873,7 +1883,8 @@ updateScreenInputFocusColor(dpy,scrInfo)
 			     scrInfo->colorInfo.inputBg0Color, OLGX_SPECIAL);
 }
 
-updateScreenVirtualDesktop(dpy,scrInfo)
+/* ARGSUSED */
+UpdateScreenVirtualDesktop(dpy,scrInfo)
     Display		*dpy;
     ScreenInfo		*scrInfo;
 
@@ -1886,7 +1897,8 @@ char	*size;
     ResizeVDM(scrInfo->vdm, size);
 }
 
-updateScreenVirtualIconGeometry(dpy,scrInfo)
+/* ARGSUSED */
+UpdateScreenVirtualIconGeometry(dpy,scrInfo)
     Display		*dpy;
     ScreenInfo		*scrInfo;
 
@@ -1902,7 +1914,17 @@ char	*geometry;
     VirtualSetGeometry(scrInfo->vdm->client->iconwin, geometry);
 }
 
-updateScreenVirtualScale(dpy,scrInfo)
+/* ARGSUSED */
+UpdateScreenVirtualDrawSticky(dpy,scrInfo)
+    Display		*dpy;
+    ScreenInfo		*scrInfo;
+
+{
+    VirtualUpdateDrawSticky(scrInfo->vdm->client);
+}
+
+/* ARGSUSED */
+UpdateScreenVirtualScale(dpy,scrInfo)
     Display		*dpy;
     ScreenInfo		*scrInfo;
 
@@ -1938,34 +1960,36 @@ updateScreenTitleFont(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
-	XFontStruct	*font = GRV.TitleFontInfo;
+        XFontStruct     *font = GRV.TitleFontInfo;
 	XGCValues       values;
 
 	values.font = font->fid;
 	XChangeGC(dpy,scrInfo->gc[FOREGROUND_GC],GCFont,&values);
 	XChangeGC(dpy,scrInfo->gc[WINDOW_GC],GCFont,&values);
 
-	olgx_set_text_font(scrInfo->gi[NORMAL_GINFO],font,OLGX_NORMAL);
-	olgx_set_text_font(scrInfo->gi[REVPIN_GINFO],font,OLGX_NORMAL);
+        olgx_set_text_font(scrInfo->gi[NORMAL_GINFO],font,OLGX_NORMAL);
+        olgx_set_text_font(scrInfo->gi[REVPIN_GINFO],font,OLGX_NORMAL);
 }
 
 /*
  * updateScreenTextFont -- change all GC/Ginfo's that use TextFont
  */
 static
+/* ARGSUSED */
 updateScreenTextFont(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
-	XFontStruct	*font = GRV.TextFontInfo;
-
-	olgx_set_text_font(scrInfo->gi[TEXT_GINFO],font,OLGX_NORMAL);
+        XFontStruct     *font = GRV.TextFontInfo;
+ 
+        olgx_set_text_font(scrInfo->gi[TEXT_GINFO],font,OLGX_NORMAL);
 }
 
 /*
  * updateScreenButtonFont -- change all GC/Ginfo's that use ButtonFont
  */
 static
+/* ARGSUSED */
 updateScreenButtonFont(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
@@ -1983,17 +2007,18 @@ updateScreenIconFont(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
-	XFontStruct	*font = GRV.IconFontInfo;
-	XGCValues       values;
+        XFontStruct     *font = GRV.IconFontInfo;
+        XGCValues       values;
 
-	values.font = font->fid;
-	XChangeGC(dpy,scrInfo->gc[ICON_NORMAL_GC],GCFont,&values);
+        values.font = font->fid;
+        XChangeGC(dpy,scrInfo->gc[ICON_NORMAL_GC],GCFont,&values);
 }
 
 /*
  * updateScreenGlyphFont -- change all GC/Ginfo's that use GlyphFont
  */
 static
+/* ARGSUSED */
 updateScreenGlyphFont(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
@@ -2009,23 +2034,23 @@ updateScreenGlyphFont(dpy,scrInfo)
  	 * w/h of resize corner glyph.  Set if unset (ie 0)
 	 */
 	if (Resize_width == 0 && Resize_height == 0) {
-		char 		s[2];
+		unsigned char 		s[2];
 		XCharStruct	xcs;
 		int 		i1,i2;
 
 		/* US_RESIZE_OUTLINE is really unsigned char */
 		s[0]=UL_RESIZE_OUTLINE;  
 		s[1]='\0';
-		XTextExtents(GRV.GlyphFontInfo,s,1,&i1,&i2,&i2,&xcs);
+		XTextExtents(GRV.GlyphFontInfo,(char *)s,1,&i1,&i2,&i2,&xcs);
 		Resize_height = xcs.ascent + xcs.descent;
 		Resize_width = xcs.width;
 	}
 }
 
 /*
- * updateScreenVirtualFont -- change all GC/Ginfo's that use VirtualFont
+ * UpdateScreenVirtualFont -- change all GC/Ginfo's that use VirtualFont
  */
-updateScreenVirtualFont(dpy,scrInfo)
+UpdateScreenVirtualFont(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -2049,7 +2074,8 @@ updateScreenVirtualFont(dpy,scrInfo)
 
 /*
  */
-updateScreenVirtualGeometry(dpy,scrInfo)
+/* ARGSUSED */
+UpdateScreenVirtualGeometry(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
@@ -2066,13 +2092,12 @@ char	*geom;
 	VirtualSetGeometry(scrInfo->vdm->client->framewin, geom);
 }
 
-updateScreenVirtualMap(dpy,scrInfo)
+UpdateScreenVirtualMap(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
 Pixmap	pm;
 char	*name;
-XGCValues	gcv;
 	
 	name = getResource(scrInfo,virtualMapNameCQ,virtualMapNameIQ);
 	if (!name)
@@ -2090,13 +2115,11 @@ XGCValues	gcv;
 	}
 }
 
-updateScreenVirtualPixmapColor(dpy,scrInfo)
+UpdateScreenVirtualPixmapColor(dpy,scrInfo)
 	Display		*dpy;
 	ScreenInfo	*scrInfo;
 {
 Pixmap	pm;
-char	*name;
-XGCValues	gcv;
 	
 	if (!scrInfo->vdm->resources->background)
 	    return;
@@ -2120,8 +2143,6 @@ initScreenInfo(dpy,screenno,visInfo,nvis)
 {
 	ScreenInfo	*scrInfo;
 	Client		*client;
-	char		*s;
-	VirtualResources	*resources;
 
 	/*
          *	Create a new ScreenInfo and minimally initialize it
@@ -2150,6 +2171,7 @@ initScreenInfo(dpy,screenno,visInfo,nvis)
 	initGCs(dpy,scrInfo);
 	initOLGX(dpy,scrInfo);
 	initFonts(dpy,scrInfo);
+	InitCursors(dpy,scrInfo);
 
 	/*
 	 *	Initialize the screen dependent parts of menus
@@ -2175,12 +2197,24 @@ initScreenInfo(dpy,screenno,visInfo,nvis)
 	 */
 	ColorFocusInit(dpy,scrInfo->rootwin);
 
+	initVDM(dpy, scrInfo, client);
+
 	/*
  	 *	Set the cursor for that screen's root window
 	 */
-	if (!GRV.PointerWorkspace)
+	if (GRV.PointerWorkspace)
 	    XDefineCursor(dpy,scrInfo->rootid,GRV.BasicPointer);
 
+}
+
+initVDM(dpy, scrInfo, client)
+    Display	*dpy;
+    ScreenInfo	*scrInfo;
+    Client	*client;
+{
+	char		*s;
+	VirtualResources	*resources;
+
 	/*
 	 * Create VDM for screen
 	 */
@@ -2218,7 +2252,7 @@ initScreenInfo(dpy,screenno,visInfo,nvis)
 	 * Need this to set the ascent value; there's probably a better
 	 * way REMIND SDO
 	 */
-        updateScreenVirtualFont(dpy,scrInfo);
+        UpdateScreenVirtualFont(dpy,scrInfo);
 }
 
 /*-------------------------------------------------------------------------
@@ -2291,13 +2325,17 @@ DestroyScreens(dpy)
  	 */
 	for (si = ListEnum(&l); si; si = ListEnum(&l)) {
 
+
+		/*
+		 * Should only do this if we painted it in the first place
+		 */
+		if (GRV.PaintWorkspace) {
+		    InstallDefaultColormap(dpy,si->rootwin,False);
+		    XSetWindowBackgroundPixmap(dpy,si->rootid,None);
+		    XClearWindow(dpy,si->rootid);
+		}
+
 		(*(WinFunc(si->rootwin,core.destroyfunc)))(dpy,si->rootwin);
-
-		InstallDefaultColormap(dpy,si->rootwin,False);
-
-		XSetWindowBackgroundPixmap(dpy,si->rootid,None);
-		XClearWindow(dpy,si->rootid);
-
 		XSetInputFocus(dpy,PointerRoot,RevertToPointerRoot,CurrentTime);
 	}
 }
@@ -2600,8 +2638,6 @@ CreateAutoRootMenuScreen(dpy, si)
     ScreenInfo	*si;
 {
 MenuInfo	*info;
-WinPinMenu	*win;
-XEvent		ev;
 extern MenuInfo	*FindMenuInfo();
 
     info = FindMenuInfo(si->rootwin, si->menuTable[MENU_ROOT]);
@@ -2609,7 +2645,7 @@ extern MenuInfo	*FindMenuInfo();
 	return;
     info->menuX = GRV.AutoRootMenuX;
     info->menuY = GRV.AutoRootMenuY;
-    win = MakePinMenu(dpy, si->rootwin, info);
+    (void) MakePinMenu(dpy, si->rootwin, info);
 }
 
 int
