@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)services.c	1.2 olvwm version 1/27/92"
+#ifdef IDENT
+#ident	"@(#)services.c	1.4 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -13,11 +15,7 @@
  */
 
 #include <stdio.h>
-#ifdef SYSV
 #include <string.h>
-#else
-#include <strings.h>
-#endif
 #include <errno.h>
 #include <sys/time.h>
 #include <sys/types.h>
@@ -351,7 +349,7 @@ PrintScreenFunc(dpy, winInfo, menuInfo, idx)
 	char		*buttons[1];
 	char		*msg;
 
-	buttons[0] = gettext("Ok");
+	buttons[0] =gettext("Ok");
 	msg = gettext("Sorry, Print Screen is not yet implemented.");
 
 
@@ -478,8 +476,9 @@ SaveWorkspaceFunc(dpy, winInfo, menuInfo, idx)
 	MenuInfo    	*menuInfo;
 	int     	idx;
 {
-static	char		*owplacesCmd =
+static  char            *defaultOwplacesCmd =
 	"owplaces -silent -multi -script -tw -output $HOME/.openwin-init";
+	char		*owplacesCmd;
 	char		*buttons[1];
 	char		*msg;
 	int		status;
@@ -490,6 +489,7 @@ static	char		*owplacesCmd =
 
 	if (GRV.SaveWorkspaceCmd)
 	    owplacesCmd = GRV.SaveWorkspaceCmd;
+	else owplacesCmd = defaultOwplacesCmd;
 	VirtualSaveDesktops(dpy, 0, 0);
 	if (XGrabPointer(dpy, NoFocusWin, False, ButtonPressMask,
 			 GrabModeAsync, GrabModeAsync, None,
@@ -758,19 +758,19 @@ WindowDismissAllAction(dpy, winInfo, menuInfo, idx)
 {
 	Client	*cli = winInfo->core.client;
 
-	/* dismiss all followers in this window's group */
+        /* dismiss all followers in this window's group */
 #ifndef COHERENT
 	GroupApply(cli->groupid,ClientKill,(void *)False,GROUP_DEPENDENT);
 #else
 	GroupApply(cli->groupid,ClientKill,(char *)False,GROUP_DEPENDENT);
 #endif
 
-	/*
-	 * If this window is not a dependent follower, make sure to dismiss
-	 * it too.
-	 */
-	if (cli->groupmask != GROUP_DEPENDENT)
-		ClientKill(winInfo->core.client, False);
+        /*
+         * If this window is not a dependent follower, make sure to dismiss
+         * it too.
+         */
+        if (cli->groupmask != GROUP_DEPENDENT)
+                ClientKill(winInfo->core.client, False);
 }
 
 /***************************************************************************
