@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)slots.c	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident	"@(#)slots.c	1.3 olvwm version 25 Nov 1992"
+#endif
 
 /*
  * Based on
@@ -60,24 +62,26 @@ SlotOrder so;
 	return("SOIllegal");
 }
 
-#ifdef notused
 #ifdef DEBUG
 /* dumpocc -- print the occupancy count table to stderr
  */
 static void
-dumpocc()
+dumpocc(iconGrid)
+IconGrid	*iconGrid;
 {
 	int ima, imi;
 
 	fprintf(stderr,"dump of occupancy table:\n");
-	for (ima = 0; ima<maslots; ima++)
-	    for (imi = 0; imi<mislots; imi++)
-		if (OCCUPANCY(ima,imi)!=0)
-		    fprintf(stderr,"%x: occ[%d,%d]/[%d] = %d\n",AOCCUPANCY(ima,imi),ima,imi,SLOTOFFSET(ima,imi),OCCUPANCY(ima,imi));
+	for (ima = 0; ima<iconGrid->maslots; ima++)
+	    for (imi = 0; imi<iconGrid->mislots; imi++)
+		if (OCCUPANCY(iconGrid,ima,imi)!=0)
+		    fprintf(stderr,"%x: occ[%d,%d]/[%d] = %d\n",
+			    AOCCUPANCY(iconGrid,ima,imi),ima,imi,
+			    SLOTOFFSET(iconGrid,ima,imi),
+			    OCCUPANCY(iconGrid,ima,imi));
 	fprintf(stderr,"end of dump of occupancy table\n");
 }
 #endif
-#endif
 
 
 /* setMajorMinor -- set two output variables from two input variables,
@@ -272,12 +276,66 @@ IconSlot *slot;
 	    y = iconGrid->pixvert - slot->mi*ICON_GRID_HEIGHT - win->core.height;
 	}
     }
-
-    x += slot->off_x;
-    y += slot->off_y;
     (WinFunc(win,core.newposfunc))(win, x, y);
 }
 
+/* slotsIntersect -- check to see if the two slots intersect.
+ */
+static Bool
+slotsIntersect(slot1,slot2)
+IconSlot *slot1, *slot2;
+{
+    if ((slot1->ma > (slot2->ma + slot2->maw)) ||
+	(slot1->mi > (slot2->mi + slot2->miw)) ||
+	(slot2->ma > (slot1->ma + slot1->maw)) ||
+	(slot2->mi > (slot1->mi + slot1->miw)))
+	return False;
+    else
+	return True;
+}
+
+/* 
+ * bounceOverlappingIcons -- given an icon and its slot(s), move any icons that
+ *                           in those slots to new positions.
+ */
+static void 
+bounceOverlappingIcons(win, slot)
+WinIconFrame *win;
+IconSlot *slot;
+{
+    int           x,y;
+    IconGrid     *iconGrid = win->core.client->scrInfo->iconGrid;
+    List         *l = iconGrid->iconList;
+    List         *move = NULL_LIST;
+    WinIconFrame *w;
+
+    /* First, make a list of the icons that need to move
+     * Must do this in two steps, since the iconList will change when we
+     * start moving icons
+     */
+    for (w = ListEnum(&l); w != NULL; w = ListEnum(&l))
+    {
+	/* if the slots overlap, move to new one */
+	if (w != win && slotsIntersect(w->iconslot, slot))
+	    move = ListCons(w,move);
+    }
+
+    l = move;
+    for (w = ListEnum(&l); w != NULL; w = ListEnum(&l))
+    {
+	/* free its slot */
+	SlotFree(w);
+
+	/* set this as auto-positioned now */
+	w->fManuallyPositioned = False;
+
+	/* allocate a new slot for it */
+	SlotAlloc(w, False, GRV.FSnapToGrid);
+	(WinFunc(w,core.setconfigfunc))(w->core.client->dpy, w);
+    }
+    ListDestroy(move);
+}
+
 /* incrPositionedSlots -- an icon has been explicitly positioned; create an
  * iconslot record and increment the occupancy count of the affected slots.
  */
@@ -288,8 +346,9 @@ int x,y,w,h;
 Bool snaptogrid;
 {
 	IconSlot *slot = MemNew(IconSlot);
-#define ROUNDIF(v,w) (snaptogrid?ROUND((v),(w)):(v))/(w)
-#define ROUNDDIM(p,s,w) (ROUNDUP(((p)%(w))+(s),(w)))
+#define ROUNDPOS(v,w) (snaptogrid?ROUND((v),(w)):(v))
+#define ROUNDIF(v,w) (ROUNDPOS(v,w)/(w))
+#define ROUNDDIM(p,s,w) (ROUNDUP(((ROUNDPOS(p,w))%(w))+(s),(w)))
 
 	if (iconGrid->SOmajor == SOTopToBottom)
 	{
@@ -420,29 +479,33 @@ Bool snaptogrid;
     int		scr_x, scr_y;
     int		dw, dh;
 
+    dw = DisplayWidth(winicon->core.client->dpy, winicon->core.client->screen);
+    dh = DisplayHeight(winicon->core.client->dpy, winicon->core.client->screen);
+    scr_x = (winicon->core.x + ICON_HORZBORDER) / dw;
+    scr_y = (winicon->core.y + ICON_VERTBORDER) / dh;
+    if (winicon->core.x < -ICON_HORZBORDER)
+	scr_x--;
+    if (winicon->core.y < -ICON_VERTBORDER)
+	scr_y--;
+    winicon->core.x -= scr_x * dw;
+    winicon->core.y -= scr_y * dh;
+
     iconGrid->iconList = ListCons(winicon, iconGrid->iconList);
 
     if (positioned)
     {
-	dw = DisplayWidth(winicon->core.client->dpy,
-						winicon->core.client->screen);
-	dh = DisplayHeight(winicon->core.client->dpy,
-						winicon->core.client->screen);
-	scr_x = abs((winicon->core.x + ICON_HORZBORDER) % dw);
-	scr_y = abs((winicon->core.y + ICON_VERTBORDER) % dh);
-	slot = incrPositionedSlots(iconGrid, scr_x, scr_y,
+	slot = incrPositionedSlots(iconGrid, winicon->core.x, winicon->core.y,
 		winicon->core.width, winicon->core.height, snaptogrid);
-	if (winicon->core.x > 0)
-	    slot->off_x = ((winicon->core.x + ICON_HORZBORDER) / dw) * dw;
-	else slot->off_x = ((winicon->core.x + ICON_HORZBORDER - dw) / dw) * dw;
-	if (winicon->core.y > 0)
-	    slot->off_y = ((winicon->core.y + ICON_VERTBORDER) / dh) * dh;
-	else slot->off_y = ((winicon->core.y + ICON_VERTBORDER - dh) / dh) * dh;
 	winicon->iconslot = slot;
 	if (snaptogrid)
 	    setIconPos(winicon, slot);
 	else
-	    (WinFunc(winicon,core.newposfunc))(winicon,winicon->core.x,winicon->core.y);
+	    (WinFunc(winicon,core.newposfunc))(winicon,winicon->core.x, winicon->core.y);
+	/* any icons that are covered by this icon shall be bounced
+	   to new, open icon slots.  However, don't bother trying if there 
+	   are no open spots! */
+	if (GRV.UniqueIconSlots && (iconGrid->minoccupancy == 0))
+	    bounceOverlappingIcons(winicon, slot);
     }
     else
     {
@@ -450,12 +513,17 @@ Bool snaptogrid;
         nvert = ROUNDUP(winicon->core.height, ICON_GRID_HEIGHT);
 	setMajorMinor(iconGrid, nvert, nhoriz, &nmajor, &nminor);
 	slot = incrDynamicSlots(iconGrid, nmajor, nminor);
-	slot->off_x = winicon->core.x + ICON_HORZBORDER;
-	slot->off_y = winicon->core.y + ICON_VERTBORDER;
 	winicon->iconslot = slot;
 	setIconPos(winicon,slot);
     }
-
+    if (scr_x || scr_y) {
+        (WinFunc(winicon,core.newposfunc))(winicon,
+					   winicon->core.x + scr_x * dw,
+					   winicon->core.y + scr_y * dh);
+    }
+#ifdef DEBUG
+    dumpocc(iconGrid);
+#endif
     return slot;
 }
 
@@ -468,9 +536,7 @@ Bool
 SlotFree(winicon)
 WinIconFrame *winicon;
 {
-	List **l;
 	IconGrid	*iconGrid = winicon->core.client->scrInfo->iconGrid;
-	WinIconFrame	*win;
 
 	if (winicon->iconslot == NULL)
 	{
@@ -481,15 +547,11 @@ WinIconFrame *winicon;
 	MemFree(winicon->iconslot);
 	winicon->iconslot = NULL;
 
-	l = &iconGrid->iconList;
-	for (win = ListEnum(l); win != NULL; win = ListEnum(l))
-	{
-	    if (win == winicon)
-	    {
-		ListDestroyCell(l);
-		break;
-	    }
-	}
+	iconGrid->iconList =
+		ListDestroyCellByValue(winicon, iconGrid->iconList);
+#ifdef DEBUG
+	dumpocc(iconGrid);
+#endif
 }
 
 /* sets the order in which slots are allocated for icons which are
@@ -570,9 +632,9 @@ IconGrid *iconGrid;
 	/* partition existing icons */
 	lauto = NULL_LIST;
 	lpos = NULL_LIST;
-	l = &iconGrid->iconList;
-	for (win = ListEnum(l); win != NULL; win = ListEnum(l))
+	for (l = &iconGrid->iconList; *l != NULL; l = &((*l)->next))
 	{
+	    win = (*l)->value;
 	    if (!win->iconslot->positioned)
 	    {
 		lauto = ListCons(win,lauto);
@@ -593,20 +655,23 @@ IconGrid *iconGrid;
 		OCCUPANCY(iconGrid,ima,imi)=0;
 
 	/* place positioned icons */
-	l = &lpos;
-	for (win = ListEnum(l); win != NULL; win = ListEnum(l))
+	for (l = &lpos; *l != NULL; l = &((*l)->next))
 	{
-	    SlotAlloc(win,True,False);
+	    win = (*l)->value;
+	    SlotAlloc(win,True,GRV.FSnapToGrid);
 	    (WinFunc(win,core.setconfigfunc))(win->core.client->dpy,win);
 	}
 	ListDestroy(lpos);
 
 	/* place auto-positioned icons */
-	l = &lauto;
-	for (win = ListEnum(l); win != NULL; win = ListEnum(l))
+	for (l = &lauto; *l != NULL; l = &((*l)->next))
 	{
-	    SlotAlloc(win,False,False);
-	    (WinFunc(win,core.setconfigfunc))(win->core.client->dpy,win);
+	    win = (*l)->value;
+	    /* only place iconified windows if FreeIconSlots is in effect */
+	    if (win->core.client->wmState == IconicState || !GRV.FreeIconSlots){
+	        SlotAlloc(win,False,GRV.FSnapToGrid);
+	        (WinFunc(win,core.setconfigfunc))(win->core.client->dpy,win);
+	    }
 	}
 	ListDestroy(lauto);
 }
