@@ -7,7 +7,9 @@
  *	(Normal, Iconic, Withdrawn)
  */
 
-#ident	"@(#)states.c	1.2 olvwm version 1/27/92"
+#ifdef IDENT
+#ident	"@(#)states.c	1.5 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -21,6 +23,7 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
+#include <X11/keysym.h>
 
 #include "i18n.h"
 #include "ollocale.h"
@@ -68,6 +71,8 @@ extern	int	WinDrawFunc();
 extern	void	IconPaneSetPixmap();
 extern	void	IconPaneSetMask();
 
+static void	checkGroupBinding();
+
 /***************************************************************************
 * private data
 ***************************************************************************/
@@ -292,17 +297,17 @@ Client	*cli;
 		} else if (winAttrs->win_type == AtomWTOther) {
 		    	*decors = OtherWindow;
 
-		    	/* 
+			/*
 			 * This is the only case where we look at menu type
 			 */
-		    	if (winAttrs->flags & WA_MENUTYPE) {
+			if (winAttrs->flags & WA_MENUTYPE) {
 				if (winAttrs->menu_type == AtomMenuFull)
 					decors->menu_type = MENU_FULL;
 				else if (winAttrs->menu_type == AtomMenuLimited)
 					decors->menu_type = MENU_LIMITED;
 				else if (winAttrs->menu_type == AtomNone)
 					decors->menu_type = MENU_NONE;
-		   	 }
+			}
 		}
 
 		/*
@@ -373,6 +378,19 @@ Client	*cli;
         return  decors;
 }
 
+int
+stateGetScreen(cli)
+	Client	 *cli;
+{
+	int xscreen, yscreen;
+
+	xscreen = (-cli->scrInfo->vdm->offsetX / DisplayWidth(cli->dpy, cli->screen));
+
+	yscreen = (-cli->scrInfo->vdm->offsetY / DisplayHeight(cli->dpy, cli->screen));
+
+	return(xscreen + (yscreen * cli->scrInfo->vdm->columns) + 1);
+}
+
 
 /*
  * calcPosition
@@ -450,7 +468,7 @@ WinGeneric *winIcon;
  */
 #ifndef COHERENT
 static void *
-#else
+else
 static char *
 #endif
 deiconifyOne(cli, winIcon, raise)
@@ -590,7 +608,6 @@ WinPane *ourWinInfo;
 	int		initstate;
 	XWindowAttributes paneAttr;
 	int 		screen;
-	int		tmpx, tmpy;
 	ScreenInfo 	*scrInfo;
 	int		winState;
 	Window		iconWin;
@@ -866,7 +883,8 @@ WinPane *ourWinInfo;
 	if (!XFetchName(dpy, window, &mc.name))
 	    mc.name = NULL;
 	icon_x = icon_y = 0;
-	if (cli->groupmask != GROUP_DEPENDENT)
+	if (cli->groupmask != GROUP_DEPENDENT ||
+		(!GroupLeader(cli->groupid) && GRV.ParentScreenPopup))
 	    if (cli->wmHints)
 	        if (cli->wmHints->flags & IconPositionHint)
 	            SearchProgString(dpy, cli->scrInfo, mc.name,
@@ -889,16 +907,20 @@ WinPane *ourWinInfo;
 	    int	dh = DisplayHeight(dpy, screen);
 
 	    if (leader != NULL) {
-		curScreen = leader->framewin->core.x / dw;
-		if (leader->framewin->core.x < 0)
+		curScreen = (leader->framewin->core.x +
+				(int) (leader->framewin->core.width / 2)) / dw;
+		if (leader->framewin->core.x +
+				(int) (leader->framewin->core.width / 2) < 0)
 		    curScreen--;
 		if (paneAttr.x + (int) paneAttr.width < 0)
 		    paneAttr.x = dw + (paneAttr.x % dw) + (curScreen * dw);
 		else paneAttr.x = (paneAttr.x % dw) + (curScreen * dw);
-		curScreen = leader->framewin->core.y / dh;
-		if (leader->framewin->core.y < 0)
+		curScreen = (leader->framewin->core.y +
+				(int) (leader->framewin->core.height / 2)) / dh;
+		if (leader->framewin->core.y +
+				(int) (leader->framewin->core.height / 2) < 0)
 		    curScreen--;
-		if (paneAttr.y + (int) paneAttr.width < 0)
+		if (paneAttr.y + (int) paneAttr.height < 0)
 		    paneAttr.y = dh + (paneAttr.y % dh) + (curScreen * dh);
 		else paneAttr.y = (paneAttr.y % dh) + (curScreen * dh);
 	    }
@@ -938,6 +960,12 @@ WinPane *ourWinInfo;
 	/* 
 	 * Size and generally configure the icon window tree
 	 */
+	if (!fexisting && cli->wmHints &&
+	    	(cli->wmHints->flags & IconPositionHint) &&
+		 !GRV.UseRelativePosition) {
+	    cli->wmHints->icon_x += cli->scrInfo->vdm->offsetX;
+	    cli->wmHints->icon_y += cli->scrInfo->vdm->offsetY;
+	}
 	WinCallConfig(dpy, winIconPane, NULL);
 	if (cli->wmHints != NULL && (cli->wmHints->flags & IconPositionHint))
 	    IconSetPos(winIcon,cli->wmHints->icon_x,cli->wmHints->icon_y);
@@ -948,9 +976,12 @@ WinPane *ourWinInfo;
         /*
 	 * We manually move the icon pane window, since all the configuration
 	 * has been done with the icon pane parented to root.
-	 */
+	 *
+	 * No longer true, since we always have a parented icon frame
+	 * now; see winipane.c
         WinRootPos(winIconPane, &tmpx, &tmpy);
         XMoveWindow(dpy, winIconPane->core.self, tmpx, tmpy);
+	 */
 
 	/*
 	 * Set the sticky bit according to the sticky list.  We check the
@@ -1009,9 +1040,11 @@ WinPane *ourWinInfo;
 	/*
 	 * Put the window into the correct initial state
 	 */
+
+	cli->restoreSticky = STICKY_NO_RESTORE;
 	switch ( initstate ) {
 	case NormalState:
-	    cli->wmState = NormalState;
+	    cli->wmState= NormalState;
 	    MapRaised(winFrame);
 	    XMapRaised(dpy, winPane->core.self);
 	    if (!fexisting) {
@@ -1023,13 +1056,30 @@ WinPane *ourWinInfo;
 	    }
 	    break;
 	case IconicState:
-	    cli->wmState = IconicState;
+	    cli->wmState= IconicState;
 	    /* unmap the window in case it was mapped originally */
 	    XUnmapWindow(dpy, winPane->core.self);
 	    winPane->pcore.pendingUnmaps++;
 	    /* dependent group followers don't get their own icons */
-	    if (cli->groupmask != GROUP_DEPENDENT)
+	    if (cli->groupmask != GROUP_DEPENDENT) {
+		if (!cli->sticky) {
+		    if (GRV.StickyIcons) {
+			MakeSticky(cli, True);
+			if (GRV.StickyIconScreen)
+			    cli->restoreSticky = stateGetScreen(cli);
+			else cli->restoreSticky = STICKY_RESTORE_CURRENT;
+		    }
+		}
+		/* we won't end up allocating a slot above, so do it
+		   now that we've decided the window starts iconified. */
+		if (winIcon->iconslot == NULL) {
+		    SlotAlloc(winIcon, winIcon->fManuallyPositioned, 
+			      GRV.FSnapToGrid);
+		    (WinFunc(winIcon,core.setconfigfunc))(cli->dpy, winIcon);
+		}
 		IconShow(cli, winIcon);
+	    }
+		
 	    break;
 	}
 	ClientSetWMState(cli);
@@ -1093,7 +1143,7 @@ void
 StateNormIcon(cli)
 Client *cli;
 {
-	WinIconFrame *winIcon = cli->iconwin;
+	WinIconFrame 	*winIcon = cli->iconwin;
 
 	if (winIcon == NULL)
 		return;
@@ -1101,51 +1151,86 @@ Client *cli;
 	/* don't do some other transition */
 	if (cli->wmState != NormalState)
 		return;
+	
+        switch (cli->groupmask) {
+            case GROUP_LEADER:
+            case GROUP_INDEPENDENT:
+		if (!cli->sticky) {
+		    if (GRV.StickyIcons) {
+			MakeSticky(cli, True);
+			if (GRV.StickyIconScreen)
+			    cli->restoreSticky = stateGetScreen(cli);
+			else cli->restoreSticky = STICKY_RESTORE_CURRENT;
+		    }
+		}
+		if (winIcon->iconslot == NULL) {
+		    SlotAlloc(winIcon, winIcon->fManuallyPositioned,
+			      GRV.FSnapToGrid);
+		    (WinFunc(winIcon,core.setconfigfunc))
+				(winIcon->core.client->dpy, winIcon);
+		}
+                IconShow(cli, winIcon);
+		if (cli->groupmask == GROUP_LEADER)
+                    GroupApply(cli->groupid, iconifyOne, winIcon,
+                                GROUP_LEADER|GROUP_DEPENDENT);
+		else iconifyOne(cli, winIcon);
 
-	/* we can't iconify if we are a dependent */
-	if (cli->groupmask == GROUP_DEPENDENT)
-		return;
+                break;
 
-	/* Map the icon window */
-	IconShow(cli, winIcon);
+            case GROUP_DEPENDENT:
+                return;
+        }
 
-	/* iconify self and dependents */
-	if (cli->groupmask == GROUP_LEADER)
-	    GroupApply(cli->groupid, iconifyOne, winIcon,
-		       GROUP_LEADER|GROUP_DEPENDENT);
-	else
-	    iconifyOne(cli,winIcon);
-
-	if (cli == CurrentClient && !GRV.FocusFollowsMouse)
-	    ClientSetFocus(cli, False, TimeFresh(cli->iconwin));
+        if (cli == CurrentClient && !GRV.FocusFollowsMouse)
+                ClientSetFocus(cli, False, TimeFresh(cli->iconwin));
 }
 
 /* 
- * StateIconNorm - transition a window to NormalState from IconicState 
+ * StateIconNorm - transition a window to NormalState from IconicState
  */
 void
 StateIconNorm(cli)
 Client *cli;
 {
-	WinIconFrame *winIcon = cli->iconwin;
-
-	if (winIcon == NULL)
-		return;
-
+        WinIconFrame    *winIcon = cli->iconwin;
+ 
+        if (winIcon == NULL)
+                return;
+	
 	/* don't do some other transition */
 	if (cli->wmState != IconicState)
 		return;
 
-	if (cli->groupmask == GROUP_LEADER)
+	if (cli->sticky && cli->restoreSticky != STICKY_NO_RESTORE) {
+	    if (cli->restoreSticky != STICKY_RESTORE_CURRENT)
+		VDMGoto(cli->dpy, cli, cli->restoreSticky);
+	    MakeSticky(cli, False);
+	    cli->restoreSticky = STICKY_NO_RESTORE;
+	}
+        /*
+         * Unmap the icon.  This must be done before mapping the
+         * frame windows, so that we get LeaveNotify events (that
+         * cause us to change focus) before the exposure events on
+         * the frame.  If we mapped the frames first, they'd be
+         * painted with the focus highlight.
+         */
+        IconHide(cli, winIcon);
+	/* free the autoallocated slots, so that icons will
+	 * pile up in the appropriate corner */
+	if (!winIcon->fManuallyPositioned && GRV.FreeIconSlots)
+	    SlotFree(winIcon);
+
+        /* Map the frame window and any group followers. */
+        if (cli->groupmask == GROUP_LEADER)
 	    deiconifyGroup(cli, winIcon);
-	else
-	    deiconifyOne(cli,winIcon,True);
+        else deiconifyOne(cli, winIcon, True);
 
-	/* Unmap icons */
-	IconHide(cli, winIcon);
-
-	if (cli == CurrentClient && !GRV.FocusFollowsMouse)
-	    ClientSetFocus(cli, True, TimeFresh(cli->framewin));
+        /*
+         * Transfer the focus to the newly mapped frame, but only if we're in
+         * click-to-type mode.
+         */
+        if (cli == CurrentClient && !GRV.FocusFollowsMouse)
+                ClientSetFocus(cli, True, TimeFresh(cli->framewin));
 }
 
 /*
@@ -1154,6 +1239,7 @@ Client *cli;
  * 	on; reparent the pane window
  */
 void
+/* ARGSUSED */
 StateWithdrawn(cli)
 Client *cli;
 {
@@ -1168,23 +1254,22 @@ Client *cli;
 
 	paneInfo = (WinPane*)(frameInfo->fcore.panewin);
 	pane = paneInfo->core.self;
-	iconInfo = cli->iconwin;
 
         /* Return the pointer if necessary */
-	FrameUnwarpPointer(cli);
+        FrameUnwarpPointer(cli);
 
-        /* Unmap the frame and pane. */
-        UnmapWindow(frameInfo);
-        XUnmapWindow(dpy, pane);
+	/* Unmap the frame and pane. */
+	UnmapWindow(frameInfo);
+	XUnmapWindow(dpy, pane);
 
 	/* Unmap the icon */
 	if (iconInfo != NULL)
 	    IconHide(cli, iconInfo);
-
+	
 	/* move the pane and unparent it */
 	FrameUnparentPane(cli, frameInfo, paneInfo);
 
-	DestroyClient(cli);
+        DestroyClient(cli);
 }
 
 /************************************************************************
@@ -1227,7 +1312,6 @@ StateUpdateWMHints(cli,event)
 	Window		pane;
 	XWMHints	wmHints;
 	WinIconPane	*iconPane;
-	Pixmap		iconMask;
 
 	if (cli->framewin == NULL || cli->iconwin == NULL ||
 	    event->state != PropertyNewValue)
@@ -1315,6 +1399,7 @@ StateUpdateWinAttr(cli,event)
  * StateUpdateDecorAdd - read the DecorAdd property and reapply it
  */
 void
+/* ARGSUSED*/
 StateUpdateDecorAdd(cli,event)
 	Client		*cli;
 	XPropertyEvent	*event;
@@ -1326,9 +1411,73 @@ StateUpdateDecorAdd(cli,event)
  * StateUpdateDecorDel - read the DecorDel property and reapply it
  */
 void
+/* ARGSUSED*/
 StateUpdateDecorDel(cli,event)
 	Client		*cli;
 	XPropertyEvent	*event;
 {
 	/* REMIND - this needs to be implemented */
 }
+
+/*
+ * Check to see if a given focus action requires any change to the
+ * key bindings
+ */
+
+typedef struct {
+    List **list;
+    KeySym start_sym;
+    KeySym end_sym;
+    unsigned int modstate;
+    Boolean  state;
+    char *desc;
+} FocusClosure;
+
+/*
+ * Check the binding state for a given key group
+ */
+static void
+checkGroupBinding(dpy, mc, focus, fcl)
+    Display *dpy;
+    minimalclosure *mc;
+    Boolean focus;
+    FocusClosure *fcl;
+{
+    List *list = *(fcl->list);
+    Boolean newstate = fcl->state;
+
+    newstate = focus ? (ListApply(list, matchInstClass, mc) != NULL) : False;
+
+    if (newstate != fcl->state) {
+      fcl->state = newstate;
+      GrabVKeys(dpy, False, True);
+      SetProgKeys(dpy, fcl->start_sym, fcl->end_sym, fcl->modstate, fcl->state);
+      GrabVKeys(dpy, True, True);
+    }
+}
+
+/*
+ * Whenever the focus changes, see if we need to enable/disable certain
+ * function keys
+ */
+CheckBindingState(win, focus)
+      WinGenericFrame *win;
+      Boolean focus;
+{
+      int i;
+      minimalclosure mc;
+
+      static FocusClosure fcl[] = {
+          { &GRV.NoVirtualKey, NoSymbol, NoSymbol, 0L, False, "All" },
+          { &GRV.NoVirtualFKey, XK_F1, XK_F12, 0L, False, "F" },
+          { &GRV.NoVirtualLKey, XK_L1, XK_L10, 0L, False, "L" },
+          { &GRV.NoVirtualRKey, XK_R1, XK_R15, 0L, False, "R" }
+      };
+
+      mc.name = win->fcore.name;
+      mc.instance = win->core.client->wmInstance;
+      mc.class = win->core.client->wmClass;
+
+      for ( i = 0; i < sizeof(fcl) / sizeof(fcl[0]); i++)
+          checkGroupBinding(win->core.client->dpy, &mc, focus, &fcl[i]);
+}
