@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)usermenu.c	1.2 olvwm version 1/27/92"
+#ifdef IDENT
+#ident	"@(#)usermenu.c	1.5 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -107,6 +109,22 @@
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
 
+#ifdef XPM
+#ifndef	NO_PIXEL_FIX
+/* The problem with xpm.h is that it includes <X11/Intrinsic.h> to get
+ * the typedef for Pixel.  Intrinsic.h, however, also typedefs Boolean
+ * (to char).  This causes the compiler to fail on the Boolean typedef
+ * in <olgx/olgx.h> (which is, of course, also char). <olgx/olgx.h> is
+ * included within "win.h".
+ * This kludge typedefs Pixel and defines _XtIntrinsic_h so that the
+ * real Intrinsic.h does not get included.
+ */
+#define _XtIntrinsic_h
+typedef unsigned long	Pixel;	    /* Index into colormap		*/
+#endif	/* NO_PIXEL_FIX */
+#include <xpm.h>
+#endif XPM
+
 #include <string.h>
 #include <pwd.h>
 
@@ -120,7 +138,7 @@
 #include "menu.h"
 
 #ifdef COHERENT
-#define MAXPATHLEN 256
+#define MAXPATHLEN 512
 #endif
 
 static char *menuFileName	= "openwin-menu";
@@ -171,15 +189,16 @@ extern int  OpenCloseSelnFunc();
 extern int  FullRestoreSizeSelnFunc();
 extern int  BackSelnFunc();
 extern int  QuitSelnFunc();
+
 extern int  GenWinMenuFunc();
 extern int  GenDirMenuFunc();
 extern int  StickSelnFunc();
+extern int  MoveDesktopFunc();
 
 /* ---------------------------------------------------------------------
  *	local forward declarations
  * ---------------------------------------------------------------------
  */
-static Bool checkFile();
 static int  menuFromFile();
 static int  parseMenu();
 static void fillMenuStruct();
@@ -226,7 +245,8 @@ typedef struct _buttondata {
     char       *submenu;
 #endif
     FuncPtr	generate;
-    char	*generate_args;
+    char       *generate_args;
+    int		screen;
 }           buttondata;
 
 
@@ -243,8 +263,9 @@ typedef struct {
 
 /* default Root menu should be quite minimal */
 static Button xtermButton = {
-    { { StringLabel, "Xterm", NULL },
-      { NoType, NULL, NULL } },
+    {
+        { StringLabel, "Xterm", NULL},
+    },
     {NULL, NULL}, 
     0, 
     False, 
@@ -261,8 +282,9 @@ static Button xtermButton = {
 };
 
 static Button cmdtoolButton = {
-    { { StringLabel, "Cmdtool", NULL},
-      { NoType, NULL, NULL } },
+    {
+        {StringLabel, "Cmdtool", NULL},
+    },
     {NULL, NULL}, 
     0, 
     False, 
@@ -279,8 +301,9 @@ static Button cmdtoolButton = {
 };
 
 static Button wsrefreshButton = {
-    { { StringLabel, "Refresh", NULL}, 
-      { NoType, NULL, NULL } },
+    {
+        {StringLabel, "Refresh", NULL},
+    },
     {NULL, NULL}, 
     0, 
     False, 
@@ -293,8 +316,9 @@ static Button wsrefreshButton = {
 };
 
 static Button wsrestartButton = {
-    { { StringLabel, "Restart WM", NULL}, 
-      { NoType, NULL, NULL } },
+    {
+        {StringLabel, "Restart WM", NULL},
+    },
     {NULL, NULL}, 
     0, 
     False, 
@@ -307,8 +331,9 @@ static Button wsrestartButton = {
 };
 
 static Button wsrereadButton = {
-    { { StringLabel, "Reread Menu File", NULL}, 
-      { NoType, NULL, NULL } },
+    {
+        {StringLabel, "Reread Menu File", NULL},
+    },
     {NULL, NULL}, 
     0, 
     False, 
@@ -321,8 +346,9 @@ static Button wsrereadButton = {
 };
 
 static Button exitWMButton = {
-    { { StringLabel, "Exit WM", NULL}, 
-      { NoType, NULL, NULL } },
+    {
+        {StringLabel, "Exit WM", NULL},
+    },
     {NULL, NULL}, 
     0, 
     False, 
@@ -335,8 +361,9 @@ static Button exitWMButton = {
 };
 
 static Button exitButton = {
-    { { StringLabel, "Exit", NULL}, 
-      { NoType, NULL, NULL } },
+    {
+        {StringLabel, "Exit", NULL},
+    },
     {NULL, NULL}, 
     0, 
     False, 
@@ -397,7 +424,7 @@ void
 WindowMenuCreate(dpy)
     Display    *dpy;
 {
-    /*SetWindowMenuLabels();*/
+    SetWindowMenuLabels();
     CreateScreenWindowMenuInfo(dpy);
 }
 
@@ -463,11 +490,7 @@ getUserMenu()
 #ifndef COHERENT
 	openwinhomeEnv = "";
 #else
-#ifdef X_MWC
 	openwinhomeEnv = "/usr/X11";
-#else
-	openwinhomeEnv = "/usr/X";
-#endif
 #endif
     
     /* construct "$OPENWINHOME/lib/openwin-menu" */
@@ -625,8 +648,8 @@ RootMenuShow(dpy, winInfo, pEvent)
  * $(OPENWINHOME)/include:${MUBMEL}/include:$FOOBLES/include
  */
 
-static char *
-expandPath(pin, messages)
+char *
+ExpandPath(pin, messages)
     char *pin;
     Bool messages;
 {
@@ -808,7 +831,7 @@ static menudata *
 makeRootMenu(file)
     char       *file;
 {
-    menudata   userroot;
+    menudata  userroot;
     menudata  *proot;
 
     userroot.title = NULL;
@@ -847,16 +870,18 @@ menuFromFile(file, menu, messages)
     char       *new;
     FILE       *stream;
     int         lineno = 1;	/* Needed for recursion */
-    int         rval;
+    int		rval;
 
     /* expand any environment vars in path */
-    if ((new = expandPath(file, messages)) != NULL)
+    if ((new = ExpandPath(file, messages)) != NULL)
 	file = new;
 
     if ((stream = fopen(file, "r")) == NULL) {
 	if (messages)
 	    fprintf(stderr, "olvwm: can't open menu file %s\n", file);
 
+	if (new)
+	    MemFree(new);
 	return MENU_NOTFOUND;
     }
     rval = parseMenu(file, stream, menu, &lineno);
@@ -1074,13 +1099,14 @@ parseMenu(filename, stream, parent, lineno)
 		(*lineno)++;
 		if ((rval = parseMenu(filename, stream,
 				      currentMenu, lineno)) < 0) {
-		    freeMenuData(currentMenu);
+		     /* ?? isn't this free?? freeMenuData(currentMenu); */
 		    return (MENU_FATAL);
 		} else
 		    fillMenuStruct(currentMenu);
 	    } else {
 		rval = menuFromFile(args, currentMenu, True);
 		if (rval <= MENU_NOTFOUND)
+                     /* freeMenuData(currentMenu); */
 		    return (MENU_FATAL);
 	    }
 	    if (rval == MENU_PINNABLE)
@@ -1122,6 +1148,26 @@ parseMenu(filename, stream, parent, lineno)
 	    currentMenu = saveMenu;
 	    continue;
 	}
+	else if (strcmp(prog, "MOVE_DESKTOP") == 0) {
+	    int		n, x, y;
+
+	    n = sscanf(args, "%d%d", &x, &y);
+	    if (!n) {
+		fprintf(stderr,
+		    gettext("olvwm: error in menu file %s, line %d\n"),
+					    filename, *lineno);
+		fprintf(stderr,
+			gettext("Missing parameters after MOVE_DESKTOP\n"));
+		return (MENU_FATAL);
+	    }
+	    currentButton->generate_args = MemNewString(args);
+	    currentButton->name = MemNewString(label);
+	    currentButton->func = MoveDesktopFunc;
+	    currentButton->exec = NULL;
+	    initButton((buttondata **) &(currentButton->next));
+	    currentButton = currentButton->next;
+	    continue;
+	}
 	else if (strcmp(prog, "COLUMNS") == 0) {
 	    char	*t;
 
@@ -1306,6 +1352,9 @@ struct _svctoken {
     {
 	"STICK_UNSTICK_SELN", StickSelnFunc, ServiceToken
     },
+    {
+	"MOVE_DESKTOP", MoveDesktopFunc, ServiceToken
+    }
 };
 
 #define NSERVICES COUNT(svctokenlookup)
@@ -1404,7 +1453,7 @@ buildFromSpec(dpy, scrInfo, pmenu, deftitle)
 	    bdata->name[strlen(bdata->name) - 1] = '\0';
 	    b->label[0].string = MemNewString(bdata->name + 1);
 	    b->label[0].pixlabel = MemNew(Pixlabel);
-	    if (!createPixmapFile(dpy, scrInfo, b->label[0].string,
+	    if (!CreatePixmapFile(dpy, scrInfo, b->label[0].string,
 					b->label[0].pixlabel))  {
 		b->label[0].kind = StringLabel;
 		MemFree(b->label[0].pixlabel);
@@ -1604,7 +1653,7 @@ menuFileModified()
     lp = menuFileInfo.fileinfoList;
     for (fi = ListEnum(&lp); fi != NULL; fi = ListEnum(&lp)) {
 	if (stat(fi->filename, &statbuf) < 0) {
-	    return True;
+	    return False;
 	}
 	if (statbuf.st_mtime != fi->mtime ||
 		statbuf.st_dev != fi->device ||
@@ -1677,8 +1726,7 @@ Menu       *MenuTable[NUM_MENUS];
  *	Title and help strings
  */
 static char *windowTitle = "Window";
-static char *frameHelpString = "window:FrameMenu";
-static char *iconHelpString = "window:IconMenu";
+static char *frameHelpString = "window:WindowMenu";
 
 extern Button *MakeOpenButton(), *MakeOwnerButton(), *MakeFullSizeButton(),
 	      *MakePropertiesButton(), *MakeBackButton(),
@@ -1686,55 +1734,80 @@ extern Button *MakeOpenButton(), *MakeOwnerButton(), *MakeFullSizeButton(),
 	      *MakeDismissButton(), *MakeResizeButton(), *MakeQuitButton(),
 	      *MakeMoveButton(), *MakeStickyButton(), *MakeDismissAllButton();
 
+extern Button	openButton, fullSizeButton, moveButton, resizeButton,
+		propertiesButton, backButton, refreshButton, stickyButton,
+		quitButton, dismissButton, dismissAllButton,
+		dismissThisButton, ownerButton,
+		moveRightButton, moveLeftButton, moveUpButton, moveDownButton,
+		moveUpRightButton, moveDownRightButton, moveUpLeftButton,
+		moveDownLeftButton, moveHomeButton;
+
 /*
  * ===========================================================================
+ */
 
 void
 SetWindowMenuLabels()
 {
 #ifdef OW_I18N_L3
-    windowTitle = gettext(windowTitle);
+        windowTitle = gettext(windowTitle);
 
-    backButton.label[0].string = gettext(backButton.label[0].string);
+        openButton.label[0].string = gettext("Open");
+        openButton.label[1].string = gettext("Close");
 
-    dismissAllButton.label[0].string = gettext(dismissAllButton.label[0].string);
+        fullSizeButton.label[0].string = gettext("Full Size");
+        fullSizeButton.label[1].string = gettext("Restore Size");
+ 
+        stickyButton.label[0].string = gettext("Stick");
+        stickyButton.label[1].string = gettext("Unstick");
+ 
+        moveButton.label[0].string = gettext("Move");
 
-    dismissButton.label[0].string = gettext(dismissButton.label[0].string);
+        resizeButton.label[0].string = gettext("Resize");
 
-    dismissThisButton.label[0].string = gettext(dismissThisButton.label[0].string);
+        propertiesButton.label[0].string = gettext("Properties");
 
-    propertiesButton.label[0].string = gettext(propertiesButton.label[0].string);
+        backButton.label[0].string = gettext("Back");
 
-    quitButton.label[0].string = gettext(quitButton.label[0].string);
+        refreshButton.label[0].string = gettext("Refresh");
 
-    refreshButton.label[0].string = gettext(refreshButton.label[0].string);
+        quitButton.label[0].string = gettext("Quit");
 
-    resizeButton.label[0].string = gettext(resizeButton.label[0].string);
+        dismissButton.label[0].string = gettext("Dismiss");
 
-    openButton.label[0].string = gettext(openButton.label[0].string);
-    openButton.label[1].string = gettext(openButton.label[1].string);
+        dismissAllButton.label[0].string = gettext("All Pop-ups");
 
-    fullSizeButton.label[0].string = gettext(fullSizeButton.label[0].string);
-    fullSizeButton.label[1].string = gettext(fullSizeButton.label[1].string);
+        dismissThisButton.label[0].string = gettext("This Window");
 
-    moveButton.label[0].string = gettext(moveButton.label[0].string);
-    ownerButton.label[0].string = gettext(ownerButton.label[0].string);
+        ownerButton.label[0].string = gettext("Owner?");
 
-    stickyButton.label[0].string = gettext(stickyButton.label[0].string);
-    stickyButton.label[1].string = gettext(stickyButton.label[1].string);
-#endif OW_I18N_L3
+        moveRightButton.label[0].string = gettext("Move East");
+
+        moveLeftButton.label[0].string = gettext("Move West");
+
+        moveUpButton.label[0].string = gettext("Move North");
+
+        moveDownButton.label[0].string = gettext("Move South");
+
+        moveUpRightButton.label[0].string = gettext("Move NorthEast");
+
+        moveDownRightButton.label[0].string = gettext("Move SouthEast");
+
+        moveUpLeftButton.label[0].string = gettext("Move NorthWest");
+
+        moveDownLeftButton.label[0].string = gettext("Move SouthWest");
+
+        moveHomeButton.label[0].string = gettext("Move Home");
+#endif
 }
 
-*/
-
 initMenuButtons(dpy, scrInfo)
     Display	*dpy;
     ScreenInfo	*scrInfo;
 {
-int	i;
-
     scrInfo->menuButtons.frameFullButtons =
 				(Button **) MemAlloc(9 * sizeof(Button *));
+    scrInfo->menuButtons.frameFullButtonsCount = 9;
     scrInfo->menuButtons.frameFullButtons[0] = MakeOpenButton(dpy, scrInfo);
     scrInfo->menuButtons.frameFullButtons[1] = MakeFullSizeButton(dpy, scrInfo);
     scrInfo->menuButtons.frameFullButtons[2] = MakeMoveButton(dpy, scrInfo);
@@ -1747,11 +1820,13 @@ int	i;
 
     scrInfo->menuButtons.frameDismissButtons =
 				(Button **) MemAlloc(2 * sizeof(Button *));
+    scrInfo->menuButtons.frameDismissButtonsCount = 2;
     scrInfo->menuButtons.frameDismissButtons[0] = MakeDismissThisButton(dpy, scrInfo);
     scrInfo->menuButtons.frameDismissButtons[1] = MakeDismissAllButton(dpy, scrInfo);
 
     scrInfo->menuButtons.frameLimitedButtons =
 				(Button **) MemAlloc(6 * sizeof(Button *));
+    scrInfo->menuButtons.frameLimitedButtonsCount = 6;
     scrInfo->menuButtons.frameLimitedButtons[0] = MakeDismissButton(dpy, scrInfo);
     scrInfo->menuButtons.frameLimitedButtons[1] = MakeMoveButton(dpy, scrInfo);
     scrInfo->menuButtons.frameLimitedButtons[2] = MakeResizeButton(dpy, scrInfo);
@@ -1770,19 +1845,23 @@ InitMenus(dpy, scrInfo)
     Display    *dpy;
     ScreenInfo	*scrInfo;
 {
-    /* SetWindowMenuLabels();	/*usually, a NOOP*/
+    SetWindowMenuLabels();
 
     initMenuButtons(dpy, scrInfo);
     scrInfo->menuTable[MENU_FULL] = CreateMenu(windowTitle,
-			scrInfo->menuButtons.frameFullButtons, 
-			basewin_ctbuttons, False, frameHelpString);
+			scrInfo->menuButtons.frameFullButtons,
+			scrInfo->menuButtons.frameFullButtonsCount,
+			False, frameHelpString);
     scrInfo->menuTable[MENU_LIMITED] = CreateMenu(windowTitle,
-			scrInfo->menuButtons.frameLimitedButtons, 
-			popup_ctbuttons, False, frameHelpString);
+			scrInfo->menuButtons.frameLimitedButtons,
+			scrInfo->menuButtons.frameLimitedButtonsCount,
+			False, frameHelpString);
     SetMenuHier(scrInfo->menuTable[MENU_LIMITED], popup_dismissitem,
 		CreateMenu(windowTitle,
-			   scrInfo->menuButtons.frameDismissButtons, 
-			   limit_ctbuttons, False, frameHelpString));
+			   scrInfo->menuButtons.frameDismissButtons,
+			   scrInfo->menuButtons.frameDismissButtonsCount,
+			   False, frameHelpString));
+    InitVDMMenu(dpy, scrInfo);
 
     /* this sets ROOT_MENU */
     InitUserMenu(dpy, scrInfo);
@@ -1795,20 +1874,19 @@ InitMenus(dpy, scrInfo)
  *	Assumes that the window menus will take up the first 6 slots
  */
 int
+/* ARGSUSED */
 CreateWindowMenuInfo(dpy, scrInfo)
     Display    *dpy;
     ScreenInfo *scrInfo;
 {
     int         origNextSlot = scrInfo->menuCache->nextSlot;
 
-    int j, x;
-
     scrInfo->menuCache->nextSlot = 0;
 
     (void) MenuInfoCreate(scrInfo->menuCache, scrInfo->rootwin,
-			  scrInfo->menuTable[MENU_FULL], 1);
+			  scrInfo->menuTable[MENU_FULL], 1, MENU_NEWSLOT);
     (void) MenuInfoCreate(scrInfo->menuCache, scrInfo->rootwin,
-			  scrInfo->menuTable[MENU_LIMITED], 1);
+			  scrInfo->menuTable[MENU_LIMITED], 1, MENU_NEWSLOT);
 
     scrInfo->menuCache->nextSlot = origNextSlot;
 }
@@ -1887,11 +1965,10 @@ GetEnabledMenu(cli, flfull, flnotitle, flsticky)
 struct _setdefinfo {
     WinGenericFrame *win;
     Menu *menu;
-#ifndef COHERENT
     void (*proc)();
+#ifndef COHERENT
     void *data;
 #else
-    char (*proc)();
     char *data;
 #endif
 #ifdef DEBUG
@@ -1930,11 +2007,10 @@ ShowStandardMenuSync(win, eve, flbutton, proc, data)
     WinGenericFrame *win;
     XEvent *eve;
     Bool flbutton;
-#ifndef COHERENT
     void (*proc)();
+#ifndef COHERENT
     void *data;
 #else
-    char (*proc)();
     char *data;
 #endif
 {
@@ -1969,7 +2045,7 @@ ShowStandardMenu(win, eve, flbutton)
 }
 
 /*
- * createPixmapFile
+ * CreatePixmapFile
  *
  *  Given a filename, return a pixmap.  Currently only supports X11 bitmap
  *  files, but will someday support Sun Icon files too
@@ -1993,6 +2069,12 @@ int	dummy;
 	return BadFormat;
     fgets(s, 255, fp);
     fclose(fp);
+#ifdef XPM
+    if (strncmp(s, "/* XPM */", 9) == 0) /* XPM 3.x format */
+	return XPixmapFormat;
+    if (strncmp(s, "! XPM", 5) == 0)	/* XPM 2.x format */
+	return XPixmapFormat;
+#endif
     if (s[0] == '#')
 	return XBitmapFormat;
     if (sscanf(s, "/* Format_version=%d", &dummy) < 1)
@@ -2001,7 +2083,7 @@ int	dummy;
 }
 
 Bool
-createPixmapFile(dpy, scrInfo, filename, pixlabel)
+CreatePixmapFile(dpy, scrInfo, filename, pixlabel)
 Display		*dpy;
 ScreenInfo	*scrInfo;
 char		*filename;
@@ -2013,34 +2095,40 @@ Pixmap	  bitmap;
 int	  xhot, yhot;
 GC	gc;
 XGCValues	gcv;
+int	  rval;
+char	 *newname;
+#ifdef XPM
+XpmAttributes	xpmAttr;
+#endif
 
-#ifdef NOTDEF
+	if ((newname = ExpandPath(filename, False)) != NULL)
+	    filename = newname;
 	switch ( ImageFileFormat(filename) ) {
 	    case XBitmapFormat:
-#endif
 		if (XReadBitmapFile(dpy, drawable,
-			    filename, &(pixlabel->width), &(pixlabel->height),
+			    filename, (unsigned int *) &(pixlabel->width),
+			    (unsigned int *) &(pixlabel->height),
 			    &bitmap, &xhot, &yhot) != BitmapSuccess) {
-			return False;
+			goto FAILURE;
 		}
 		pixlabel->pixmap = XCreatePixmap(dpy, drawable,
 			pixlabel->width, pixlabel->height, depth);
-		gcv.foreground = scrInfo->colorInfo.bg1Color;
+		gcv.foreground = scrInfo->colorInfo.fgColor;
 		gcv.background = scrInfo->colorInfo.workspaceColor;
 		if (gcv.foreground == gcv.background)
-		    gcv.foreground = scrInfo->colorInfo.fgColor;
+		    gcv.foreground = scrInfo->colorInfo.bg1Color;
 		gc = XCreateGC(dpy, drawable, GCForeground|GCBackground, &gcv);
 		XCopyPlane(dpy, bitmap, pixlabel->pixmap,
 			gc,
 			0, 0, pixlabel->width, pixlabel->height, 0, 0, 1);
 		XFreePixmap(dpy, bitmap);
 		XFreeGC(dpy, gc);
-#ifdef FUTURE
 		break;
+#ifdef SUNICON
 	    case SunIconFormat:
 		if (!SunReadIconFile(dpy, drawable, filename,
 			&pixlabel->width, &pixlabel->height, &bitmap))
-		    return False;
+		     goto FAILURE;
 		pixlabel->pixmap = XCreatePixmap(dpy, drawable,
 			pixlabel->width, pixlabel->height, depth);
 		XCopyPlane(dpy, bitmap, pixlabel->pixmap,
@@ -2048,25 +2136,36 @@ XGCValues	gcv;
 			pixlabel->width, pixlabel->height, 0, 0, 1);
 		XFreePixmap(dpy, bitmap);
 		break;
-	    case XPixmapFormat:
-		if (XReadPixmapFile(dpy, ?Visual?, drawable, ?Colormap?,
-			    filename, depth, &(pixlabel->pixmap),
-			    &(pixlabel->width), &(pixlabel->height),
-			    (unsigned long **)0, 0, /*don't save pixel info*/
-			    (ColorSymbol *)0, 0, /*don't override colors*/
-			    (XpmInfo *)0)	 /*don't save xpm info*/
-			    != PixmapSuccess) {
-			return False;
-		}
-		break;
-	    default:
-		return False;
-	}
 #endif
-	return True;
+#ifdef XPM
+	    case XPixmapFormat:
+		xpmAttr.valuemask = XpmVisual | XpmColormap | XpmDepth;
+		xpmAttr.visual = scrInfo->visual;
+		xpmAttr.colormap = scrInfo->colormap;
+		xpmAttr.depth = depth;
+		if ((rval = XpmReadFileToPixmap(dpy, drawable, filename,
+			    &(pixlabel->pixmap),
+			    (Pixmap *)0, /* ignore shape mask for now */
+			    &xpmAttr)) != PixmapSuccess) {
+			goto FAILURE;
+		}
+		pixlabel->width = xpmAttr.width;
+		pixlabel->height = xpmAttr.height;
+		break;
+#endif
+	    default:
+		goto FAILURE;
+	}
+	if (newname != NULL)
+	    MemFree(newname);
+	rval = True;
+FAILURE:
+	if (newname != NULL)
+	    MemFree(newname);
+	return rval;
 }
 
-#ifdef NOTDEF
+#ifdef SUNICON
 SunReadIconFile(dpy, drawable, filename, width, height, bitmap)
     Display	*dpy;
     Window	drawable;
@@ -2077,17 +2176,19 @@ SunReadIconFile(dpy, drawable, filename, width, height, bitmap)
 {
 FILE	*fp;
 char	s[256];
-int	version = 0, depth = 0, bits = 0;
+int	version = 0, depth = 0, iconbitsz = 0;
 char	*data, *pd;
-int	i, temp;
+int	icon_word, xbm_bits, bit_loop, xbm_loop, xbm_bytes_per_icon_word;
+int	xbm_byte_count, width_loop, height_loop, icon_words_per_line, c;
+Bool	half_of_last;
 
     fp = fopen(filename, "r");
     if (!fp)
 	return False;
     fgets(s, 255, fp);
     sscanf(s, "/* Format_version=%d, Width=%d, Height=%d, Depth=%d, Valid_bits_per_item=%d",
-	   &version, width, height, &depth, &bits);
-    if (version != 1 || depth != 1 || (bits != 16 && bits != 32)) {
+	   &version, width, height, &depth, &iconbitsz);
+    if (version != 1 || depth != 1 || (iconbitsz != 16 && iconbitsz != 32)) {
 	ErrorWarning(gettext("An invalid SunIcon file was named as a bitmap"));
 	fclose(fp);
 	return False;
@@ -2099,26 +2200,58 @@ int	i, temp;
     }
     data = MemAlloc((*width / 8) * *height);
     pd = data;
-    fgets(s, 255, fp);		/* get end of comment */
-    for (i = 0; i < *height; i++) {
-	fscanf(fp, "0x%lx", &temp);
-	switch(bits) {
-	    case 16:
-		*pd++ = (temp >> 8);
-		*pd++ = (temp & 0xff);
-		break;
-	    case 32:
-		*pd++ = (temp >> 24);
-		*pd++ = ((temp>>16) & 0xff);
-		*pd++ = ((temp>>8) & 0xff);
-		*pd++ = (temp & 0xff);
+
+    while ((c = getc(fp)) != EOF) {
+	if (c == '*') {
+	    do {
+		if (((c = getc(fp)) != EOF) ** (c == '/'))
+		    break;
+	    } while (c == '*');
+	    if (c == '/')
 		break;
 	}
     }
+    if (c == EOF) {
+	ErrorWarning(gettext("An invalid SunIcon file was named as a bitmap"));
+	fclose(fp);
+	return False;
+    }
+
+    xbm_bytes_per_icon_word = iconbitsz / 8;
+    icon_words_per_line = *width / iconbitsz;
+    if ( (*width % iconbitsz) != 0 ) {
+	/* a 32-bit icon image that only uses half of the last icon_word */
+	icon_words_per_line += 1;
+	half_of_last = True;
+    }
+    else half_of_last = False;
+    for (height_loop = *height; --height_loop >= 0; ) {
+	for ( width_loop = icon_words_per_line ; --width_loop >= 0 ; ) {
+	    /* position on 0 of 0xFFFF */
+	    while ( ((c = getc(fp)) != EOF) && (c != '0') ) {
+		;	/* nothing else to do */
+	    }   /* endwhile */
+	    c = fscanf(fp, "x%X", &icon_word);
+	    if ( (width_loop == 0) && half_of_last )
+		xbm_byte_count = xbm_bytes_per_icon_word / 2;
+	    else xbm_byte_count = xbm_bytes_per_icon_word;
+	    for (xbm_loop = xbm_byte_count ; --xbm_loop >= 0 ; ) {
+		xbm_bits = 0;
+		for (bit_loop = 1 ; bit_loop <= 8 ; ++bit_loop) {
+		    xbm_bits <<= 1;
+		    xbm_bits |= (icon_word & 0x0001);
+		    icon_word >>= 1;
+		}
+		*(pd + xbm_loop) = xbm_bits;
+	    }
+	    pd += xbm_bytes_per_icon_word;
+	}
+    }
+
     *bitmap = XCreateBitmapFromData(dpy, drawable, data, *width, *height);
     fclose(fp);
     if (!*bitmap)
 	return False;
     return True;
 }
-#endif
+#endif SUNICON
