@@ -5,10 +5,8 @@
 
 #include <stdio.h>
 #include <string.h>
-#ifdef COHERENT
-#include <sys/types.h>
-#endif
 #include <dirent.h>
+#include <sys/param.h>
 #include <X11/Xos.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -31,7 +29,25 @@
 #include "vdm.icon"
 #include "vdm.mask"
 
-#ident "@(#)virtual.c	1.2 olvwm version 1/27/92"
+#define INIT   register char *sp = instring;
+#define GETC() (*sp++)
+#define PEEKC()     (*sp)
+#define UNGETC(c)   (--sp)
+#define RETURN(c)   return;
+#define ERROR(val)  regerr(val)
+#define TRUE 1
+#define FALSE 0
+#ifndef COHERENT
+#include <regexp.h>
+#endif
+
+#ifdef COHERENT
+#define MAXPATHLEN 512
+#endif
+
+#ifdef IDENT
+#ident "@(#)virtual.c	1.5 olvwm version 12/7/92"
+#endif
 
 /* Class Function Vector; a virtual pane is the VDM window in which all
  * the little virtual windows appear (and to which said windows are
@@ -54,6 +70,8 @@ extern Button	*MakeUpLeftButton(),*MakeLeftButton(),*MakeDownLeftButton(),
 		*MakeUpButton(),*MakeHomeButton(),*MakeDownButton(),
 		*MakeUpRightButton(),*MakeRightButton(),*MakeDownRightButton();
 
+extern char	*ExpandPath();
+
 /*
  * Semantic action associated with each of the buttons above.  These must
  * be in the same order as the button array; it would be better if the Button
@@ -72,7 +90,7 @@ static SemanticAction	vdmButtonActions[] = {
     ACTION_DOWNRIGHT,
 };
 
-static char pixdata[] = { 0xaa, 0x55 };
+static unsigned char pixdata[] = { 0xaa, 0x55 };
 
 #define VDMSelectMask (ButtonPressMask | ButtonReleaseMask | \
 		       ButtonMotionMask | ExposureMask )
@@ -160,6 +178,10 @@ WinGenericFrame	*win;
 
     if (cli->screen != c->screen)
 	return NULL;
+    if (cli->wmInstance && !strcmp(cli->wmInstance, "OI_TRANSIENT"))
+	return NULL;
+    if (cli->wmClass && !strcmp(cli->wmClass, "OI_TRANSIENT"))
+	return NULL;
     if (cli && !cli->sticky) {
 	win = (WinGenericFrame *) cli->framewin;
 	if (win)
@@ -179,15 +201,15 @@ WinGenericFrame	*win;
 	 */
 	if (cli->framewin)
 	    XMoveWindow(cli->dpy, cli->framewin->core.virtual,
-	        (cli->framewin->core.x) / cli->scrInfo->vdm->resources->scale +
+		(cli->framewin->core.x) / cli->scrInfo->vdm->resources->scale +
 				cli->scrInfo->vdm->screenX,
-	        (cli->framewin->core.y) / cli->scrInfo->vdm->resources->scale +
+		(cli->framewin->core.y) / cli->scrInfo->vdm->resources->scale +
 				cli->scrInfo->vdm->screenY);
 	if (cli->iconwin)
 	    XMoveWindow(cli->dpy, cli->iconwin->core.virtual,
-	        (cli->iconwin->core.x) / cli->scrInfo->vdm->resources->scale +
+		(cli->iconwin->core.x) / cli->scrInfo->vdm->resources->scale +
 				cli->scrInfo->vdm->screenX,
-	        (cli->iconwin->core.y) / cli->scrInfo->vdm->resources->scale +
+		(cli->iconwin->core.y) / cli->scrInfo->vdm->resources->scale +
 				cli->scrInfo->vdm->screenY);
     }
     return NULL;
@@ -285,12 +307,10 @@ int	dw = DisplayWidth(dpy, vdm->client->screen);
 	    deltas.delta_x = dw * .5;
 	    break;
 	case ACTION_UPLEFT:
-	case ACTION_ROW_START:
 	    deltas.delta_x = -dw;
 	    deltas.delta_y = -dh;
 	    break;
 	case ACTION_JUMP_UPLEFT:
-	case ACTION_DATA_START:
 	    deltas.delta_x = -dw * 20;
 	    deltas.delta_y = -dh * 20;
 	    break;
@@ -315,12 +335,10 @@ int	dw = DisplayWidth(dpy, vdm->client->screen);
 	    deltas.delta_y = vdm->offsetY;
 	    break;
 	case ACTION_DOWNLEFT:
-	case ACTION_ROW_END:
 	    deltas.delta_x = -dw;
 	    deltas.delta_y = dh;
 	    break;
 	case ACTION_JUMP_DOWNLEFT:
-	case ACTION_DATA_END:
 	    deltas.delta_x = -dw * 20;
 	    deltas.delta_y = dh * 20;
 	    break;
@@ -351,9 +369,9 @@ int	dw = DisplayWidth(dpy, vdm->client->screen);
 	case ACTION_GOTO_9:
 	case ACTION_GOTO_10:
 	    deltas.delta_x = vdm->offsetX +
-				((a - ACTION_GOTO_1) % vdm->columns) * dw;
+				((int) (a - ACTION_GOTO_1) % vdm->columns) * dw;
 	    deltas.delta_y = vdm->offsetY +
-				((a - ACTION_GOTO_1) / vdm->columns) * dh;
+				((int) (a - ACTION_GOTO_1) / vdm->columns) * dh;
 	    break;
 	default:
 	    return False;
@@ -376,8 +394,9 @@ translateVirtualCoords(vdm, root_x, root_y, x, y)
     int			*root_x, *root_y, *x, *y;
 
 {
-int     tx, ty, tw, th, bw, d;
-Window  root;
+int     	tx, ty;
+unsigned int	tw, th, bw, d;
+Window  	root;
 
     if (x)
 	*x *= vdm->resources->scale;
@@ -413,7 +432,7 @@ calculateVirtualDesktopSize(dpy, screen, v)
 
     sscanf(v->resources->size, "%dx%d", &width, &height);
     if (width < dw)
-        v->columns = width;
+	v->columns = width;
     else v->columns = CEIL(width, dw);
     if (height < dh)
 	v->rows = height;
@@ -425,8 +444,8 @@ calculateVirtualDesktopSize(dpy, screen, v)
     v->screenWidth = dw / v->resources->scale;
     v->screenHeight = dh / v->resources->scale;
     if (v->resources->grid) {
-        v->width = v->columns * v->screenWidth;
-        v->height = v->rows * v->screenHeight;
+	v->width = v->columns * v->screenWidth;
+	v->height = v->rows * v->screenHeight;
     }
     else {
 	v->width = v->absoluteWidth / v->resources->scale;
@@ -570,6 +589,7 @@ int		dh = DisplayHeight(stuff->vdm->client->dpy,
 }
 
 static Bool
+/* ARGSUSED */
 vdmInterposer(dpy, event, w, stuff)
     Display	*dpy;
     XEvent	*event;
@@ -588,8 +608,8 @@ SemanticAction	action;
 	case MotionNotify:
 	    if (!event->xmotion.same_screen)
 		break;
-	    if (XEventsQueued(dpy, QueuedAfterReading) > 0 &&
-		XPeekEvent(dpy, &nextevent), nextevent.type == MotionNotify)
+	    if ((XEventsQueued(dpy, QueuedAfterReading) > 0) &&
+		(XPeekEvent(dpy, &nextevent), nextevent.type == MotionNotify))
 		/* Ignore this event, there's another one coming */
 		break;
 	    vdmMoveUpdate(event, stuff);
@@ -766,6 +786,7 @@ ScreenInfo	*scrInfo = winInfo->core.client->scrInfo;
 }
 
 static
+/* ARGSUSED */
 vdmRedraw(dpy, win)
     Display	*dpy;
     WinGeneric	*win;
@@ -848,13 +869,6 @@ static vdmSelect()
 {
 }
 
-static
-winIntNullFunc()
-{
-    fprintf(stderr, "WinIntNULL!\n");
-}
-
- 
 /*
  * setsizePane - set the pane to a particular size, and initiate a reconfigure
  */
@@ -892,14 +906,15 @@ vdmSetupFrame(win, cli, frame)
     XReparentWindow(cli->dpy, win->core.self, frame->core.self,
 		    win->core.x, win->core.y);
     cli->wmHints->icon_pixmap = XCreateBitmapFromData(cli->dpy,
-				RootWindow(cli->dpy, cli->screen), vdm_bits,
+				RootWindow(cli->dpy, cli->screen), (char *) vdm_bits,
 				vdm_width, vdm_height);
     cli->wmHints->icon_mask = XCreateBitmapFromData(cli->dpy,
-				RootWindow(cli->dpy, cli->screen), vdmmask_bits,
+				RootWindow(cli->dpy, cli->screen), (char *) vdmmask_bits,
 				vdmmask_width, vdmmask_height);
 }
 
 static
+/* ARGSUSED */
 vdmComputeWidth(dpy, event, winInfo)
     Display	*dpy;
     XEvent	*event;
@@ -908,6 +923,7 @@ vdmComputeWidth(dpy, event, winInfo)
 }
 
 static
+/* ARGSUSED */
 vdmComputeHeight(dpy, event, winInfo)
     Display	*dpy;
     XEvent	*event;
@@ -926,6 +942,7 @@ RedrawVDM(vdm)
     drawVDMGrid(vdm->client->dpy, vdm);
 }
 
+/* ARGSUSED */
 VirtualInit(dpy)
     Display	*dpy;
 
@@ -971,11 +988,8 @@ static XTextProperty	iName = {(unsigned char *) "Desktop",
     XWMHints *wmHints;
     XClassHint *classHints;
     unsigned attrMask;
-    int	win;
     WinVirtual		*w;
     VirtualDesktop	*v;
-    char	title[20];
-    Button	*vdmButtons[9];
 
     v = allocVirtualDesktop(dpy, scrInfo->screen, rsc);
     w = MemNew(WinVirtual);
@@ -988,8 +1002,8 @@ static XTextProperty	iName = {(unsigned char *) "Desktop",
     sizeHints->min_height = v->screenHeight;
     if (rsc->grid) {
 	sizeHints->flags = PMinSize | PResizeInc;
-        sizeHints->width_inc = v->screenWidth;
-        sizeHints->height_inc = v->screenHeight;
+	sizeHints->width_inc = v->screenWidth;
+	sizeHints->height_inc = v->screenHeight;
     }
     else sizeHints->flags = PMinSize;
 
@@ -1012,21 +1026,27 @@ static XTextProperty	iName = {(unsigned char *) "Desktop",
  
     attrMask = CWEventMask;
 
-    if (DefaultDepth(dpy, scrInfo->screen) == 1) {
-        attrMask |= CWBackPixmap;
-        attr.background_pixmap = XCreatePixmapFromBitmapData(dpy,
+    if ((DefaultDepth(dpy, scrInfo->screen) == 1) && !rsc->background) {
+	attrMask |= CWBackPixmap;
+	attr.background_pixmap = XCreatePixmapFromBitmapData(dpy,
 			RootWindow(dpy, scrInfo->screen),
-			pixdata, 8, 2,
+			(char *) pixdata, 8, 2,
 			scrInfo->colorInfo.fgColor, scrInfo->colorInfo.bgColor,
 			1);
     }
     else if (!rsc->background) {
-        attrMask |= CWBackPixel;
-        attr.background_pixel = scrInfo->colorInfo.virtualBgColor;
+	attrMask |= CWBackPixel;
+	attr.background_pixel = scrInfo->colorInfo.virtualBgColor;
     }
     else {
 	attrMask |= CWBackPixmap;
 	attr.background_pixmap = VirtualGetPixmap(dpy, scrInfo, rsc->background);
+	if (attr.background_pixmap == None)
+	    attr.background_pixmap = XCreatePixmapFromBitmapData(dpy,
+			RootWindow(dpy, scrInfo->screen),
+			(char *) pixdata, 8, 2,
+			scrInfo->colorInfo.fgColor, scrInfo->colorInfo.bgColor,
+			DefaultDepth(dpy, scrInfo->screen));
     }
     attr.event_mask = ExposureMask | ButtonPressMask | ButtonReleaseMask |
 		      ButtonMotionMask | KeyPressMask;
@@ -1046,16 +1066,17 @@ static XTextProperty	iName = {(unsigned char *) "Desktop",
 
     w->core.self = XCreateWindow(dpy, RootWindow(dpy, scrInfo->screen),
 	    			sizeHints->x, sizeHints->y,
-            			sizeHints->base_width, sizeHints->base_height,
+	    			sizeHints->base_width, sizeHints->base_height,
 				0,
 			/* REMIND olwm visual affects this? */
-            			DefaultDepth(dpy, scrInfo->screen), InputOutput,
-            			CopyFromParent, attrMask, &attr);
+	    			DefaultDepth(dpy, scrInfo->screen), InputOutput,
+	    			CopyFromParent, attrMask, &attr);
     XSetWMProperties(dpy, w->core.self, &wName, &iName, NULL, 0,
-        	     sizeHints, wmHints, classHints);
+		     sizeHints, wmHints, classHints);
 
     WIInstallInfo((WinGeneric *)w);
     scrInfo->vdm = v;
+
     v->client = StateNew(dpy, RootWindow(dpy, scrInfo->screen), w->core.self, False, w);
     /*
      * Sigh -- the call back was called before the icon frame was created
@@ -1071,6 +1092,18 @@ static XTextProperty	iName = {(unsigned char *) "Desktop",
     VirtualSetGeometry(v->client->iconwin,
 		       v->client->scrInfo->vdm->resources->iconGeometry);
 
+    XFree((char *) sizeHints);
+    XFree((char *) wmHints);
+    XFree((char *) classHints);
+}
+
+
+InitVDMMenu(dpy, scrInfo)
+    Display	*dpy;
+    ScreenInfo	*scrInfo;
+{
+    char	title[20];
+    Button	*vdmButtons[9];
     /*
      * Make the VDMs menu
      */
@@ -1089,12 +1122,6 @@ static XTextProperty	iName = {(unsigned char *) "Desktop",
 				True, "olvwm:MotionMenu");
     scrInfo->menuTable[MENU_VDM]->prefColSize = 3;
     scrInfo->menuTable[MENU_VDM]->buttonDefault = 4;
-    (void) MenuInfoCreate(scrInfo->menuCache, scrInfo->rootwin,
-			      scrInfo->menuTable[MENU_VDM], 1);
-
-    XFree(sizeHints);
-    XFree(wmHints);
-    XFree(classHints);
 }
 
 /*
@@ -1128,7 +1155,7 @@ Window	virtual;
 		x, y, width, height, 1, cli->scrInfo->colorInfo.borderColor,
 		cli->scrInfo->colorInfo.virtualFgColor);
     if (PANEWINOFCLIENT(cli) != PANEWINOFCLIENT(cli->scrInfo->vdm->client))
-        XSelectInput(cli->dpy, virtual, VDMSelectMask);
+	XSelectInput(cli->dpy, virtual, VDMSelectMask);
     else XSelectInput(cli->dpy, virtual, ExposureMask);
     cli->framewin->core.virtual = virtual;
     VInstallInfo(cli->framewin);
@@ -1193,6 +1220,7 @@ int	length;
 			       win->core.client->scrInfo->gc[VDM_GC],
 		     1, win->core.client->scrInfo->vdm->max_ascent + 1,
 		     win->fcore.name, length);
+    CheckBindingState(win, focus);
 }
 
 /*
@@ -1268,7 +1296,7 @@ unsigned int    ignoremask;
 		 * So for this one we pretend it's a double click in the
 		 * VDM itself
 		 */
-	        translateVirtualCoords(win->core.client->scrInfo->vdm,
+		translateVirtualCoords(win->core.client->scrInfo->vdm,
 				&event->xmotion.x_root, &event->xmotion.y_root,
 				&event->xmotion.x, &event->xmotion.y);
 		VDMMoveTo(win->core.client->dpy, win->core.client,
@@ -1276,7 +1304,7 @@ unsigned int    ignoremask;
 		return True;
 	    }
 	    if (currentVDMAction == ACTION_MENU)
-	        translateVirtualCoords(win->core.client->scrInfo->vdm,
+		translateVirtualCoords(win->core.client->scrInfo->vdm,
 				       NULL, NULL,
 				       &event->xmotion.x, &event->xmotion.y);
 	    else translateVirtualCoords(win->core.client->scrInfo->vdm,
@@ -1296,7 +1324,7 @@ unsigned int    ignoremask;
 	    if (currentVDMAction == ACTION_NONE)
 		return True;
 	    if (currentVDMAction == ACTION_MENU)
-	        translateVirtualCoords(win->core.client->scrInfo->vdm,
+		translateVirtualCoords(win->core.client->scrInfo->vdm,
 				       NULL, NULL,
 				       &event->xmotion.x, &event->xmotion.y);
 	    else translateVirtualCoords(win->core.client->scrInfo->vdm,
@@ -1320,15 +1348,24 @@ MakeSticky(cli, sticky)
     Bool	sticky;
 
 {
-int	dw, dh, x, y;
+int	x, y;
+
     /*
      * Can't unstick the VDM
      */
-    if (cli->groupid == PANEWINOFCLIENT(cli->scrInfo->vdm->client) && !sticky)
+    if (cli->groupid == PANEWINOFCLIENT(cli->scrInfo->vdm->client) && !sticky) {
+	if (GRV.Beep == BeepAlways)
+	    XBell(cli->dpy, 100);
 	return !NULL;
+    }
     cli->sticky = sticky;
-    dw = DisplayWidth(cli->dpy, cli->screen);
-    dh = DisplayHeight(cli->dpy, cli->screen);
+    if (sticky && !GRV.VirtualDrawSticky)
+	XUnmapWindow(cli->dpy, (cli->wmState == IconicState) ?
+				cli->iconwin->core.virtual :
+				cli->framewin->core.virtual);
+    else XMapWindow(cli->dpy, (cli->wmState == IconicState) ?
+				cli->iconwin->core.virtual :
+				cli->framewin->core.virtual);
     if (cli->sticky) {
 	x = cli->framewin->core.x;
 	y = cli->framewin->core.y;
@@ -1362,15 +1399,13 @@ SemanticAction	a;
 
     root = WIGetInfo(ev->xkey.root);
     if (!root) {
-	fprintf(stderr, "NO ROOT\n");
+	/* root is not managed by this wm, running in -single mode */
 	return False;
     }
     if (!root->core.client) {
-	fprintf(stderr, "NO CLIENT\n");
 	return False;
     }
     if (!root->core.client->scrInfo) {
-	fprintf(stderr, "NO SCRINFO\n");
 	return False;
     }
     vdm = root->core.client->scrInfo->vdm;
@@ -1411,11 +1446,11 @@ ScreenInfo	*si;
 List		*l = ScreenInfoList;
 
     for (si = ListEnum(&l); si; si = ListEnum(&l)) {
-        si->vdm->saveX = si->vdm->offsetX;
-        si->vdm->saveY = si->vdm->offsetY;
-        deltas.delta_x = si->vdm->offsetX - x;
-        deltas.delta_y = si->vdm->offsetY - y;
-        moveDesktop(dpy, &deltas, si->vdm);
+	si->vdm->saveX = si->vdm->offsetX;
+	si->vdm->saveY = si->vdm->offsetY;
+	deltas.delta_x = si->vdm->offsetX - x;
+	deltas.delta_y = si->vdm->offsetY - y;
+	moveDesktop(dpy, &deltas, si->vdm);
     }
 }
 
@@ -1427,9 +1462,9 @@ ScreenInfo	*si;
 List		*l = ScreenInfoList;
 
     for (si = ListEnum(&l); si; si = ListEnum(&l)) {
-        deltas.delta_x = -si->vdm->saveX;
-        deltas.delta_y = -si->vdm->saveY;
-        moveDesktop(dpy, &deltas, si->vdm);
+	deltas.delta_x = -si->vdm->saveX;
+	deltas.delta_y = -si->vdm->saveY;
+	moveDesktop(dpy, &deltas, si->vdm);
     }
 }
 
@@ -1480,7 +1515,8 @@ Display	*dpy = cli->dpy;
 	XDestroyWindow(dpy, cli->framewin->core.virtual);
 	XDestroyWindow(dpy, cli->iconwin->core.virtual);
 	MakeVirtual(cli);
-	XMapWindow(dpy, (cli->wmState == IconicState) ?
+	if (!cli->sticky || GRV.VirtualDrawSticky)
+	    XMapWindow(dpy, (cli->wmState == IconicState) ?
 				cli->iconwin->core.virtual :
 				cli->framewin->core.virtual);
     }
@@ -1492,6 +1528,22 @@ static void *
 #else
 static char *
 #endif
+restickVirtual(cli)
+    Client	*cli;
+{
+    if (!cli->iconwin || !cli->framewin)
+	return NULL;
+    if (cli->sticky && !GRV.VirtualDrawSticky)
+	XUnmapWindow(cli->dpy, (cli->wmState == IconicState) ?
+				cli->iconwin->core.virtual :
+				cli->framewin->core.virtual);
+    else XMapWindow(cli->dpy, (cli->wmState == IconicState) ?
+				cli->iconwin->core.virtual :
+				cli->framewin->core.virtual);
+    return NULL;
+}
+
+static void
 updateVirtualWindow(cli)
     Client	*cli;
 
@@ -1527,9 +1579,9 @@ WinGenericFrame	*win;
     win = (WinGenericFrame *) vdm->client->framewin;
     GFrameSetConfig(win, win->core.x, win->core.y,
 		vdm->width + (WinFunc(win,fcore.widthleft))(win) +
-		             (WinFunc(win,fcore.widthright))(win),
+			     (WinFunc(win,fcore.widthright))(win),
 		vdm->height + (WinFunc(win,fcore.heighttop))(win) +
-		              (WinFunc(win,fcore.heightbottom))(win));
+			      (WinFunc(win,fcore.heightbottom))(win));
     ListApply(ActiveClientList, remakeVirtual, 0);
 }
 
@@ -1540,6 +1592,13 @@ VirtualUpdateVirtualWindows(cli)
     ClientRefresh(cli);
 }
 
+VirtualUpdateDrawSticky(cli)
+    Client	*cli;
+{
+    ListApply(ActiveClientList, restickVirtual, 0);
+    ClientRefresh(cli);
+}
+
 /*
  * Size the VDM with the new geometry
  */
@@ -1548,30 +1607,31 @@ VirtualSetGeometry(win, geom)
     char	*geom;
 {
 int	changed;
-int	newx, newy, x, y, w, h;
+int	newx, newy, x, y;
+unsigned int w, h;
 Display	*dpy = win->core.client->dpy;
 ScreenInfo	*scrInfo = win->core.client->scrInfo;
 
-        changed = XParseGeometry(geom, &x, &y, &w, &h);
-        if (changed & (XValue | YValue)) {
-            if (changed & XValue)
-                if (changed & XNegative)
-                    newx = DisplayWidth(dpy, scrInfo->screen) + x;
-                else newx = x;
-            else newx = win->core.x;
+	changed = XParseGeometry(geom, &x, &y, &w, &h);
+	if (changed & (XValue | YValue)) {
+	    if (changed & XValue)
+		if (changed & XNegative)
+		    newx = DisplayWidth(dpy, scrInfo->screen) + x - win->core.width;
+		else newx = x;
+	    else newx = win->core.x;
 	    w = win->core.width;
-            if (newx > DisplayWidth(dpy, scrInfo->screen) - w)
-                newx = DisplayWidth(dpy, scrInfo->screen) - w;
-            if (changed & YValue)
-                if (changed & YNegative)
-                    newy = DisplayHeight(dpy, scrInfo->screen) + y;
-                else newy = y;
-            else newy = win->core.y;
+	    if (newx > DisplayWidth(dpy, scrInfo->screen) - w)
+		newx = DisplayWidth(dpy, scrInfo->screen) - w;
+	    if (changed & YValue)
+		if (changed & YNegative)
+		    newy = DisplayHeight(dpy, scrInfo->screen) + y - win->core.height;
+		else newy = y;
+	    else newy = win->core.y;
 	    h = win->core.height;
-            if (newy > DisplayHeight(dpy, scrInfo->screen) - h)
-                newy = DisplayHeight(dpy, scrInfo->screen) - h;
-            GFrameSetConfig(win, newx, newy, win->core.width, win->core.height);           
-        }
+	    if (newy > DisplayHeight(dpy, scrInfo->screen) - h)
+		newy = DisplayHeight(dpy, scrInfo->screen) - h;
+	    GFrameSetConfig(win, newx, newy, win->core.width, win->core.height);	   
+	}
 }
 
 /*
@@ -1585,9 +1645,14 @@ VirtualGetPixmap(dpy, scrInfo, name)
 
 {
 Pixmap	read, write;
-int	w, h, dummy;
+unsigned int	w, h;
+int	dummy;
 XGCValues	gcv;
 GC	gc;
+char	*new = NULL;
+
+    if ((new = ExpandPath(name, True)) != NULL)
+	name = new;
 
     if (XReadBitmapFile(dpy, scrInfo->rootid, name,
 			&w, &h, &read, &dummy, &dummy) == BitmapSuccess) {
@@ -1599,10 +1664,14 @@ GC	gc;
 	XCopyPlane(dpy, read, write, gc, 0, 0, w, h, 0, 0, 1);
 	XFreePixmap(dpy, read);
 	XFreeGC(dpy, gc);
+	if (new)
+	    MemFree(new);
 	return write;
     }
     else {
 	ErrorWarning(gettext("An invalid bitmap file was named as the virtual background"));
+	if (new)
+	    MemFree(new);
 	return None;
     }
 }
@@ -1611,6 +1680,7 @@ GC	gc;
  * Perform an action from the VDM menu
  */
 int
+/* ARGSUSED */
 VDMMenuAction(dpy, winInfo, menuInfo, btn)
     Display	*dpy;
     WinPinMenu	*winInfo;
@@ -1668,6 +1738,28 @@ int	dw, dh;
 					client->scrInfo->vdm->offsetY);
 }
 
+MoveDesktopFunc(dpy, wininfo, menuinfo, btn)
+    Display	*dpy;
+    WinGeneric	*wininfo;
+    MenuInfo	*menuinfo;
+    int		btn;
+{
+int	n, x, y;
+
+    n = sscanf(menuinfo->menu->buttons[btn]->generate_args, "%d%d", &x, &y);
+    switch(n) {
+	default:
+	    VDMMoveTo(dpy, wininfo->core.client, x, y);
+	    break;
+	case 1:
+	    VDMGoto(dpy, wininfo->core.client, x);
+	    break;
+	case 0:
+	    fprintf(stderr, gettext("olvwm:  Bad movedesktop switch\n"));
+	    break;
+    }
+}
+	    
 /*
  *==========================================================================
  *
@@ -1682,7 +1774,8 @@ MapWindow(win)
     XSetWindowBorderWidth(win->core.client->dpy,
 		win->core.virtual, (win->core.client->isSelected) ? 2 : 1);
     XMapWindow(win->core.client->dpy, win->core.self);
-    XMapWindow(win->core.client->dpy, win->core.virtual);
+    if (GRV.VirtualDrawSticky || !win->core.client->sticky)
+        XMapWindow(win->core.client->dpy, win->core.virtual);
     if (GRV.VirtualRaiseVDM && win->core.client->scrInfo->vdm->client)
 	RaiseWindow(win->core.client->scrInfo->vdm->client->framewin);
 }
@@ -1691,7 +1784,8 @@ UnmapWindow(win)
     WinGeneric	*win;
 {
     XUnmapWindow(win->core.client->dpy, win->core.self);
-    XUnmapWindow(win->core.client->dpy, win->core.virtual);
+    if (GRV.VirtualDrawSticky || !win->core.client->sticky)
+        XUnmapWindow(win->core.client->dpy, win->core.virtual);
 }
 
 MapRaised(win)
@@ -1700,7 +1794,8 @@ MapRaised(win)
     XSetWindowBorderWidth(win->core.client->dpy,
 		win->core.virtual, (win->core.client->isSelected) ? 2 : 1);
     XMapRaised(win->core.client->dpy, win->core.self);
-    XMapRaised(win->core.client->dpy, win->core.virtual);
+    if (GRV.VirtualDrawSticky || !win->core.client->sticky)
+        XMapRaised(win->core.client->dpy, win->core.virtual);
     if (GRV.VirtualRaiseVDM && win->core.client->scrInfo->vdm->client)
 	RaiseWindow(win->core.client->scrInfo->vdm->client->framewin);
 }
@@ -1732,7 +1827,7 @@ DestroyWindow(win)
     XDestroyWindow(win->core.client->dpy, win->core.self);
     WIUninstallInfo(win->core.self);
     if (win->core.virtual)
-        XDestroyWindow(win->core.client->dpy, win->core.virtual);
+	XDestroyWindow(win->core.client->dpy, win->core.virtual);
 }
 
 DeleteProperty(dpy, win, atom)
@@ -1743,7 +1838,7 @@ DeleteProperty(dpy, win, atom)
 {
     XDeleteProperty(dpy, win->core.self, atom);
     if (win->core.virtual)
-        XDeleteProperty(dpy, win->core.virtual, atom);
+	XDeleteProperty(dpy, win->core.virtual, atom);
 }
 
 ChangeProperty(dpy, win, property, type, format, mode, data, nelements)
@@ -1758,7 +1853,7 @@ ChangeProperty(dpy, win, property, type, format, mode, data, nelements)
     XChangeProperty(dpy, win->core.self, property, type, format,
 		    mode, data, nelements);
     if (win->core.virtual)
-        XChangeProperty(dpy, win->core.virtual, property, type, format,
+	XChangeProperty(dpy, win->core.virtual, property, type, format,
 		    mode, data, nelements);
 }
 
@@ -1769,36 +1864,74 @@ ConfigureWindow(dpy, win, mask, values)
     XWindowChanges	*values;
 
 {
-int	scale;
+int		scale;
 WinGeneric	*tmp;
+VirtualDesktop	*vdm;
 
+    vdm = win->core.client->scrInfo->vdm;
+    /*
+     * Make sure the window is somewhere on the visible desktop
+     */
+    if (win->core.x + (int) win->core.width < vdm->offsetX) {
+        win->core.x = vdm->offsetX;
+        win->core.dirtyconfig |= CWX;
+    }
+    else if (win->core.x > vdm->absoluteWidth + vdm->offsetX) {
+        win->core.x = vdm->absoluteWidth + vdm->offsetX - win->core.width;
+        win->core.dirtyconfig |= CWX;
+    }
+    if (win->core.y + (int) win->core.height < vdm->offsetY) {
+        win->core.y = vdm->offsetY;
+        win->core.dirtyconfig |= CWY;
+    }
+    else if (win->core.y > vdm->absoluteHeight + vdm->offsetY) {
+        win->core.y = vdm->absoluteHeight + vdm->offsetY - win->core.height;
+        win->core.dirtyconfig |= CWY;
+    }      
+
+    scale = vdm->resources->scale;
     XConfigureWindow(dpy, win->core.self, mask, values);
-    scale = win->core.client->scrInfo->vdm->resources->scale;
     if (mask & CWX)
-	values->x = (win->core.x - win->core.client->scrInfo->vdm->offsetX) /
-			scale;
+	values->x = (win->core.x - vdm->offsetX) / scale;
     if (mask & CWY)
-	values->y = (win->core.y - win->core.client->scrInfo->vdm->offsetY) /
-			scale;
+	values->y = (win->core.y - vdm->offsetY) / scale;
     if (mask & CWWidth)
 	values->width = win->core.width / scale;
     if (mask & CWHeight)
 	values->height = win->core.height / scale;
     if (mask & CWSibling) {
 	tmp = WIGetInfo(values->sibling);
-	if (tmp)
+	if (tmp) {
 	    values->sibling = tmp->core.virtual;
-	else mask |= ~(CWSibling|CWStackMode);
+	}
+	else {
+	    mask |= ~(CWSibling|CWStackMode);
+	}
     }
     XConfigureWindow(dpy, win->core.virtual, mask, values);
     if (GRV.VirtualRaiseVDM)
-	RaiseWindow(win->core.client->scrInfo->vdm->client->framewin);
+	RaiseWindow(vdm->client->framewin);
+}
+
+/*
+ * There's another cmpButton in olvwmrc.y, but that comparison checks for
+ * the icon flag and is case insensitive.  We need a simple case sensitive
+ * check here
+ */
+static int
+cmpButton(b1, b2)
+    Button	**b1, **b2;
+
+{
+    return strcmp(gettext((*b1)->label[0].string),
+		  gettext((*b2)->label[0].string));
 }
 
 /*
  * Menu generation function for DIRMENU
  *
  */
+/* ARGSUSED */
 GenDirMenuFunc(dpy, menuInfo, bindex, cache, winInfo, depth)
     Display	*dpy;
     MenuInfo	*menuInfo;
@@ -1808,12 +1941,22 @@ GenDirMenuFunc(dpy, menuInfo, bindex, cache, winInfo, depth)
     int		depth;
 
 {
-Menu	*menu;
+struct _menu	*menu;
 DIR	*dir;
 struct dirent	*ent;
 Button	*b;
-char	s[256], *dirname;
+char	s[MAXNAMLEN], dirname[MAXPATHLEN - MAXNAMLEN], *newname, *ExpandPath();
+char	pattern[MAXNAMLEN];
 extern int AppMenuFunc();
+MenuCache	*menuCache;
+int		slot;
+
+    menuCache = winInfo->core.client->scrInfo->menuCache;
+    for (slot = 0; slot < menuCache->nextSlot; slot++)
+	if (menuInfo->buttons[bindex].subMenu == menuCache->menuInfoList[slot])
+	    break;
+    if (slot == menuCache->nextSlot)
+	slot = MENU_NEWSLOT;
 
     MenuInfoDestroy(menuInfo->buttons[bindex].subMenu);
     menu = (Menu *) MemAlloc(sizeof(Menu));
@@ -1826,15 +1969,33 @@ extern int AppMenuFunc();
     menu->maxLabWidth = 0;
     menu->prefColSize = 0;
 
-    dirname = (char *) menuInfo->menu->buttons[bindex]->generate_args;
-    if (!(dir = opendir(dirname))) {
-	menuInfo->buttons[bindex].subMenu =
-				MenuInfoCreate(cache, winInfo, menu, depth);
-	return;
+    pattern[0] = '\0';
+    if ((newname = ExpandPath(menuInfo->menu->buttons[bindex]->generate_args,
+				True)) == NULL)
+	strcpy(dirname, (char *) menuInfo->menu->buttons[bindex]->generate_args);
+    else {
+	strcpy(dirname, newname);
+	MemFree(newname);
+    }
+    if ((dir = opendir(dirname)) == NULL) {
+	if (newname = strrchr(dirname, '/')) {
+	    strcpy(pattern, newname + 1);
+	    dirname[strlen(dirname) - strlen(pattern) - 1] = '\0';
+	    rexInit(pattern);
+	}
+	if ((newname == NULL) || ((dir = opendir(dirname)) == NULL)) {
+	    ErrorWarning(gettext("An invalid directory was named for DIRMENU"));
+	    menuInfo->buttons[bindex].subMenu =
+			MenuInfoCreate(cache, winInfo, menu, depth, slot);
+	    return;
+	}
     }
     while (ent = readdir(dir)) {
 	if (ent->d_name[0] == '.')
 	    continue;
+	if (pattern[0] && !rexMatch(ent->d_name))
+	    continue;
+
 	b = (Button *) MemAlloc(sizeof(Button));
 	if (!menu->buttonCount++)
 	    menu->buttons = (Button **) MemAlloc(sizeof(Button *));
@@ -1860,6 +2021,115 @@ extern int AppMenuFunc();
 	b->generate_func = NULL;
     }
     closedir(dir);
+    if (GRV.VirtualDirSort == SortAlpha || GRV.VirtualDirSort == SortAlphaAll)
+	qsort(menu->buttons, menu->buttonCount, sizeof(Button *), cmpButton);
     menuInfo->buttons[bindex].subMenu =
-				MenuInfoCreate(cache, winInfo, menu, depth);
+				MenuInfoCreate(cache, winInfo, menu, depth, slot);
 }
+
+static
+regerr(val)
+int val;
+{
+    switch(val) {
+	case 11:
+	    ErrorWarning(gettext("DIRMENU: Range endpoint too large.\n"));
+	    break;
+	case 16:
+	    ErrorWarning(gettext("DIRMENU: Bad number.\n"));
+	    break;
+	case 25:
+	    ErrorWarning(gettext("DIRMENU: ``\\ digit'' out of range.\n"));
+	    break;
+	case 36:
+	    ErrorWarning(gettext("DIRMENU: Illegal or missing delimiter.\n"));
+	    break;
+	case 41:
+	    ErrorWarning(gettext("DIRMENU: No remembered search string.\n"));
+	    break;
+	case 42:
+	    ErrorWarning(gettext("DIRMENU: \\( \\) imbalance.\n"));
+	    break;
+	case 43:
+	    ErrorWarning(gettext("DIRMENU: Too many \\(.\n"));
+	    break;
+	case 44:
+	    ErrorWarning(gettext("DIRMENU: More than 2 numbers given in \\{ \\}.\n"));
+	    break;
+	case 45:
+	    /* { gratutitous brace to match next line for vi */
+	    ErrorWarning(gettext("DIRMENU: } expected after \\.\n"));
+	    break;
+	case 46:
+	    ErrorWarning(gettext("DIRMENU: First number exceeds second in \\{ \\}.\n"));
+	    break;
+	case 49:
+	    ErrorWarning(gettext("DIRMENU: [] imbalance.\n"));
+	    break;
+	case 50:
+	    ErrorWarning(gettext("DIRMENU: Regular expression too long.\n"));
+	    break;
+	default:
+	    ErrorWarning(gettext("DIRMENU: Unexpected Error Code\n"));
+	    break;
+    }
+}
+
+static char expbuf[256];
+
+static
+rexMatch(string)
+    char *string;
+{
+    return step(string,expbuf);
+}
+
+static
+rexInit(pattern)
+    char *pattern;
+{
+int i, j, n;
+char newPattern[256];
+
+    strcpy(newPattern,"");
+    n = strlen(pattern);
+    newPattern[0] = '^';
+    for(i = 0, j = 1; i < n; i++) {
+	switch(pattern[i]) {
+	    case '?':
+		newPattern[j++] = '.';
+		break;
+	    case '*':
+		if (i == 0)
+		    newPattern[j++] = '.';
+		newPattern[j++] = '*';
+		break;
+	    case '.':
+		newPattern[j++] = '\\';
+		newPattern[j++] = '.';
+		break;
+	    default:
+		newPattern[j++] = pattern[i];
+	}
+    }
+    newPattern[j++] = '$';
+    newPattern[j++] = '\0';
+    compile(newPattern, expbuf, &expbuf[256], '\0');
+}
+
+#ifdef COHERENT
+/*
+ * I've no idea yet, how the compile and step regular expression
+ * routines should work. So the following functions are dummys
+ * and they don't work right.
+ */
+step()
+{
+	return(0);
+}
+
+compile()
+{
+	return(0);
+}
+#endif
