@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)winframe.c	1.2 olvwm version 1/27/92"
+#ifdef IDENT
+#ident	"@(#)winframe.c	1.5 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -19,9 +21,10 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
-#include <olgx/olgx.h>
 
 #include "i18n.h"
+#include <olgx/olgx.h>
+
 #include "ollocale.h"
 #include "mem.h"
 #include "olwm.h"
@@ -47,11 +50,11 @@ extern int Resize_height, Resize_width;
 ***************************************************************************/
 
 #define FRAME_EVENT_MASK        (ButtonPressMask | ButtonReleaseMask | \
-                                 ExposureMask | ButtonMotionMask | \
-                                 EnterWindowMask | LeaveWindowMask | \
-                                 SubstructureRedirectMask | \
-                                 FocusChangeMask | PropertyChangeMask)
-#define FRAME_EVENT_ND_MASK	( ExposureMask | EnterWindowMask | \
+				 ExposureMask | ButtonMotionMask | \
+				 EnterWindowMask | LeaveWindowMask | \
+				 SubstructureRedirectMask | \
+				 FocusChangeMask | PropertyChangeMask)
+#define FRAME_EVENT_ND_MASK     ( ExposureMask | EnterWindowMask | \
 				  LeaveWindowMask | SubstructureRedirectMask | \
 				  FocusChangeMask | PropertyChangeMask )
 
@@ -150,17 +153,19 @@ Graphics_info *gis;
  * font size 
  */
 static int
+/* ARGSUSED */
 headerHeight(cli,gis)
 Client *cli;
 Graphics_info *gis;
 {
-	int fontht = GRV.TitleFontInfo->ascent 
+	int fontht = GRV.TitleFontInfo->ascent
 		     + GRV.TitleFontInfo->descent;
 	return MAX(Abbrev_MenuButton_Height(gis),fontht+3);
 }
 
 /* REMIND this function should also be changed to use olgx macros */
 static int
+/* ARGSUSED */
 footerHeight(cli,gis)
 Client *cli;
 Graphics_info *gis;
@@ -169,7 +174,6 @@ Graphics_info *gis;
 	    + ResizeArm_Height(gis);
 }
 
-
 /* height/width functions */
 static int
 heightTopFrame(win)
@@ -292,6 +296,7 @@ WinPaneFrame *win;
  * eventMapRequest -- the pane is go from iconic to normal states
  */
 static int
+/* ARGSUSED */
 eventMapRequest(dpy, event, frameInfo)
 Display	*dpy;
 XEvent	*event;
@@ -314,6 +319,7 @@ WinPaneFrame *frameInfo;
  * eventConfigureRequest -- the pane is trying to change configuration
  */
 static int
+/* ARGSUSED */
 eventConfigureRequest(dpy, event, frameInfo)
 Display	*dpy;
 XEvent	*event;
@@ -329,6 +335,7 @@ WinPaneFrame *frameInfo;
  * selectClickFrame -- the select button has been clicked
  */
 static int
+/* ARGSUSED */
 selectClickFrame(dpy, event, frameInfo)
 Display	*dpy;
 XEvent	*event;
@@ -346,6 +353,7 @@ WinPaneFrame *frameInfo;
  * selectDoubleClickFrame -- the select button has been double-clicked
  */
 static int
+/* ARGSUSED */
 selectDoubleClickFrame(dpy, event, frameInfo)
 Display	*dpy;
 XEvent	*event;
@@ -362,6 +370,7 @@ WinPaneFrame *frameInfo;
  * 	to trigger a drag.
  */
 static int
+/* ARGSUSED */
 selectDragFrame(dpy, event, frameInfo, lastpress)
 Display *dpy;
 XEvent *event;
@@ -375,6 +384,7 @@ XButtonEvent *lastpress;
  * menuPressFrame -- the menu button has been pressed
  */
 static int
+/* ARGSUSED */
 menuPressFrame(dpy,event,frameInfo)
 Display *dpy;
 XEvent *event;
@@ -388,6 +398,7 @@ WinPaneFrame *frameInfo;
  * selectPressFrame -- the select or adjust button has been pressed
  */
 static int
+/* ARGSUSED */
 selectAdjustPressFrame(dpy, event, frameInfo)
 Display	*dpy;
 XEvent	*event;
@@ -406,6 +417,7 @@ WinPaneFrame *frameInfo;
  * adjustClickFrame -- the adjust button has been pressed
  */
 static int
+/* ARGSUSED */
 adjustClickFrame(dpy, event, frameInfo)
 Display	*dpy;
 XEvent	*event;
@@ -447,6 +459,7 @@ WinPaneFrame *frameInfo;
  * the frame.
  */
 static int
+/* ARGSUSED */
 eventLeaveNotify(dpy, event, frameInfo)
 Display	*dpy;
 XEvent	*event;
@@ -465,6 +478,7 @@ WinPaneFrame *frameInfo;
  * drawHeaderBusy3D - draw header in busy state (3D mode)
  */
 static void
+/* ARGSUSED */
 drawHeaderBusy3D(dpy, win, cli, sel)
     Display *dpy;
     WinPaneFrame *win;
@@ -503,6 +517,7 @@ drawHeaderBusy3D(dpy, win, cli, sel)
  * drawHeaderBusy2D - draw header in busy state (2D mode)
  */
 static void
+/* ARGSUSED */
 drawHeaderBusy2D(dpy, win, cli, sel)
     Display *dpy;
     WinPaneFrame *win;
@@ -545,6 +560,7 @@ drawHeaderBusy2D(dpy, win, cli, sel)
  * drawHeaderBar3D - draw the header, with indented focus bar (3D mode)
  */
 static void
+/* ARGSUSED */
 drawHeaderBar3D(dpy, win, cli, sel)
 Display *dpy;
 WinPaneFrame *win;
@@ -617,7 +633,6 @@ static	Bool chiseledFocusLines = False;
 
 	olgx_draw_text(gis, self, win->fcore.name, win->titlex, 
 		win->titley, 0, OLGX_NORMAL);
-
 	if (cli->wmDecors->flags & WMDecorationResizeable) {
 	    lineleft = Resize_width + 1;
 	    linelen = w - (2*Resize_width) - 2;
@@ -649,6 +664,7 @@ static	Bool chiseledFocusLines = False;
  * drawHeaderNoFocus3D - draw the header, without focus (3D mode)
  */
 static void
+/* ARGSUSED */
 drawHeaderNoFocus3D(dpy, win, cli, sel)
 Display *dpy;
 WinPaneFrame *win;
@@ -673,6 +689,7 @@ Bool sel;
  * drawHeaderBar2D - draw the header, with inverted focus bar (2D mode)
  */
 static void
+/* ARGSUSED */
 drawHeaderBar2D(dpy, win, cli, sel)
 Display *dpy;
 WinPaneFrame *win;
@@ -712,6 +729,7 @@ Bool sel;
 	XDrawString(dpy, self, gc,
 		win->titlex, win->titley,
 		win->fcore.name, win->nameLength);
+	
 }
 
 
@@ -776,6 +794,7 @@ Bool sel;
  * drawHeaderNoFocus2D - draw the header, without focus (2D mode)
  */
 static void
+/* ARGSUSED */
 drawHeaderNoFocus2D(dpy, win, cli, sel)
 Display *dpy;
 WinPaneFrame *win;
@@ -812,13 +831,12 @@ Client *cli;
 	int fy = h-heightBottomFrame(win);
 	int baseline;
 	int margin;
-	int footwidth = w - 2*margin;
-	int qfootwidth = footwidth / 4;
+	int footwidth;
+	int qfootwidth;
 	int gutter;
 	int rstart, lmaxwidth, rmaxwidth;
 	Graphics_info	*gis;
 	GC	gc;
-	int armh;
 
 	if (cli->isFocus) {
 	    gc = WinGC(win, INPUTFOCUS_GC);
@@ -831,9 +849,10 @@ Client *cli;
 
 	/* fill in frame-colored area above footer */
 	baseline = fy + GRV.TitleFontInfo->ascent + ResizeArm_Height(gis);
-	armh = ResizeArm_Height(gis);
 	gutter = ptSize(gis);
 	margin = FRAME_OUTLINE_WIDTH + ptSize(gis);
+	footwidth = w - 2*margin;
+	qfootwidth = footwidth / 4;
 
 	XFillRectangle(dpy, self, gc,
 		widthLeftFrame(win), fy,
@@ -886,8 +905,6 @@ Bool sel;
 	int lwidth = sel ? FRAME_SELECTED_WIDTH : FRAME_OUTLINE_WIDTH;
 	int w = win->core.width;
 	int h = win->core.height;
-	int armh = ResizeArm_Height(WinGI(win,NORMAL_GINFO));
-	int armw = ResizeArm_Width(WinGI(win,NORMAL_GINFO));
 	GC      borderGC = WinGC(win,BORDER_GC);
 	GC	gc;
 
@@ -911,6 +928,7 @@ Bool sel;
 /* drawBase3D - draw the outer border of the window (3D mode)
  */
 static void
+/* ARGSUSED */
 drawBase3D(dpy, win, cli, sel)
 Display *dpy;
 WinPaneFrame *win;
@@ -1038,6 +1056,7 @@ WinPaneFrame *winInfo;
  * newconfigFrame -- compute a new configuration of frame window
  */
 static int
+/* ARGSUSED */
 newconfigFrame(winInfo, pxcre)
 WinPaneFrame *winInfo;
 XConfigureRequestEvent *pxcre;
@@ -1109,7 +1128,6 @@ setconfigFrame(dpy, winInfo)
     GFrameSetConfigFunc(dpy, winInfo);
 }
 
-
 static int
 selectFrame(dpy, winInfo, selected)
     Display	    *dpy;
@@ -1227,10 +1245,6 @@ Window panewin;
 	w->nameLength = strlen(w->fcore.name);
 	w->nameWidth = XTextWidth(GRV.TitleFontInfo, w->fcore.name, w->nameLength);
 
-#ifdef NOTDEF
-	availwidth = w->core.width - widthLeftFrame(w) - widthRightFrame(w) - 
-		w->titleOff;
-#endif
 	availwidth = w->core.width - widthRightFrame(w) - w->titleOff;
 	availwidth = MAX(0,availwidth);
 
@@ -1248,7 +1262,7 @@ Window panewin;
                         w->fcore.name = MemNewString(ptr);
 			MemFree(tmp);
                         w->nameWidth = XTextWidth( GRV.TitleFontInfo, w->fcore.name, 
-				w->nameLength);
+						 w->nameLength);
                 }
         }
 
@@ -1264,7 +1278,7 @@ Window panewin;
 
         /* Center that title. */
         w->titlex = w->titleOff + (availwidth - w->nameWidth)/2;
-        w->titley = GRV.TitleFontInfo->max_bounds.ascent + 2 + 
+        w->titley = GRV.TitleFontInfo->ascent +
 		ResizeArm_Height(WinGI(w,NORMAL_GINFO));
 }
 
@@ -1337,6 +1351,7 @@ setFooterText(dpy,w,panewin)
  * fullrestoreFrame
  */
 static int
+/* ARGSUSED */
 fullrestoreFrame(client)
 Client	*client;
 {
@@ -1532,7 +1547,8 @@ XWindowAttributes *paneattrs;
 	attributes.cursor = GRV.TargetPointer;
 	attributes.border_pixel = 0;
 	attributes.colormap = cli->scrInfo->colormap;
-	if (GRV.PointerWorkspace)
+
+	if (!GRV.PointerWorkspace)
 	    valuemask = CWEventMask | CWSaveUnder | CWBackPixmap |
 			CWBorderPixel | CWColormap;
 	else valuemask = CWEventMask | CWSaveUnder | CWBackPixmap | CWCursor |
@@ -1600,6 +1616,7 @@ XWindowAttributes *paneattrs;
 }
 
 void
+/* ARGSUSED */
 FrameInit(dpy)
 Display *dpy;
 {
@@ -1702,65 +1719,64 @@ FrameSetPosAbsolute(win, x, y)
         (WinFunc(win,core.newposfunc))(win, fx, fy);
 }
 
-
 /* FrameSetPosFromPane -- the client has specified a position for the pane.  
  * 	Using the window gravity, the frame's position should be adjusted
  * 	so that the point on the frame named by the window gravity is at the
  *	corresponding point in the requested pane.
- *	REMIND we aren't accounting for the window's border width here 
+ *	REMIND we aren't accounting for the window's border width here
  */
 void
 FrameSetPosFromPane(win,x,y)
-WinPaneFrame *win;
-int x,y;
+    WinPaneFrame *win;
+    int x,y;
 {
-	int bw = widthLeftFrame(win)+widthRightFrame(win);
-	int bh = heightTopFrame(win)+heightBottomFrame(win);
-	WinGenericPane *pane = win->fcore.panewin;
-	int panebord = (pane == NULL)?(0):(pane->pcore.oldBorderWidth);
+    int bw = widthLeftFrame(win) + widthRightFrame(win);
+    int bh = heightTopFrame(win) + heightBottomFrame(win);
+    WinGenericPane *pane = win->fcore.panewin;
+    int panebord = (pane == NULL)?(0):(pane->pcore.oldBorderWidth);
 
-	switch (win->core.client->normHints->win_gravity)
-	{
+    switch (win->core.client->normHints->win_gravity) {
+	default:
 	case NorthWestGravity:
 		break;
-
+ 
 	case NorthGravity:
 		x -= bw/2-panebord;
 		break;
-
+ 
 	case NorthEastGravity:
 		x -= bw-2*panebord;
 		break;
 
 	case WestGravity:
 		y -= bh/2-panebord;
-		break;
+                break;
 
-	case CenterGravity:
-		y -= bh/2-panebord;
-		x -= bw/2-panebord;
-		break;
+        case CenterGravity:
+                y -= bh/2-panebord;
+                x -= bw/2-panebord;
+                break;
 
-	case EastGravity:
-		y -= bh/2-panebord;
-		x -= bw-2*panebord;
-		break;
-
-	case SouthWestGravity:
-		y -= bh-2*panebord;
-		break;
-
-	case SouthGravity:
-		y -= bh-2*panebord;
-		x -= bw/2-panebord;
-		break;
-
-	case SouthEastGravity:
-		y -= bh-2*panebord;
-		x -= bw-2*panebord;
-		break;
-
-	}
+        case EastGravity:
+                y -= bh/2-panebord;
+                x -= bw-2*panebord;
+                break;
+ 
+        case SouthWestGravity:
+                y -= bh-2*panebord;
+                break;
+ 
+        case SouthGravity:
+                y -= bh-2*panebord;
+                x -= bw/2-panebord;
+                break;
+ 
+        case SouthEastGravity:
+                y -= bh-2*panebord;
+                x -= bw-2*panebord;
+                break;
+ 
+        }
 	(WinFunc(win,core.newposfunc))(win, x, y);
 }
 
@@ -1788,29 +1804,28 @@ WinPane *winPane;
 	{
 	case NorthWestGravity:
 		break;
-
+ 
 	case NorthGravity:
 		x += bw/2-panebord;
 		break;
-
+ 
 	case NorthEastGravity:
 		x += bw-2*panebord;
 		break;
-
+ 
 	case WestGravity:
 		y += bh/2-panebord;
 		break;
-
+ 
 	case CenterGravity:
 		y += bh/2-panebord;
 		x += bw/2-panebord;
 		break;
-
+ 
 	case EastGravity:
 		y += bh/2-panebord;
 		x += bw-2*panebord;
 		break;
-
 	case SouthWestGravity:
 		y += bh-2*panebord;
 		break;
@@ -1827,23 +1842,22 @@ WinPane *winPane;
 	}
 
 	XSetWindowBorderWidth(cli->dpy,winPane->core.self,winPane->pcore.oldBorderWidth);
-        if (winPane->pcore.oldSaveUnder)
-        {
-            XSetWindowAttributes xwa;
-            xwa.save_under = True;
-            XChangeWindowAttributes(cli->dpy,winPane->core.self,CWSaveUnder,&xwa);
-        }
+	if (winPane->pcore.oldSaveUnder)
+	{
+	    XSetWindowAttributes xwa;
+	    xwa.save_under = True;
+	    XChangeWindowAttributes(cli->dpy,winPane->core.self,CWSaveUnder,&xwa);
+	}
 
 	if (winPane->core.kind != WIN_MENU) {
-	    XReparentWindow(cli->dpy, winPane->core.self, 
+	    XReparentWindow(cli->dpy, winPane->core.self,
 		cli->scrInfo->rootid, x, y);
 	    if (!(cli->flags & CLOlwmOwned))
-	        XChangeSaveSet(cli->dpy, winPane->core.self, SetModeDelete);
-	    if (GRV.RestackWhenWithdraw) {
+		XChangeSaveSet(cli->dpy, winPane->core.self, SetModeDelete);	    if (GRV.RestackWhenWithdraw) {
 		xwc.sibling = winFrame->core.self;
 		xwc.stack_mode = Above;
 		ConfigureWindow(cli->dpy, winPane,
-			     	CWSibling|CWStackMode, &xwc);
+				CWSibling|CWStackMode, &xwc);
 	    }
 	}
 }
