@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)winicon.c	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident	"@(#)winicon.c	1.4 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -19,9 +21,10 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
-#include <olgx/olgx.h>
 
 #include "i18n.h"
+#include <olgx/olgx.h>
+
 #include "ollocale.h"
 #include "mem.h"
 #include "olwm.h"
@@ -37,7 +40,6 @@ extern 	Bool	PropGetWMIconName();
 /***************************************************************************
 * private data
 ***************************************************************************/
-
 /* events in the icon window that are interesting */
 #define ICON_EVENT_MASK        (ButtonPressMask | ButtonReleaseMask | \
 				ExposureMask | ButtonMotionMask | \
@@ -55,6 +57,7 @@ static ClassIconFrame classIconFrame;
 ***************************************************************************/
 
 static int
+/* ARGSUSED */
 menuPressIcon(dpy,event,iconInfo)
 Display *dpy;
 XEvent *event;
@@ -65,6 +68,7 @@ WinIconFrame *iconInfo;
 }
 
 static int
+/* ARGSUSED */
 selectDoubleClickIcon(dpy,event,iconInfo)
 Display *dpy;
 XEvent *event;
@@ -74,6 +78,7 @@ WinIconFrame *iconInfo;
 }
 
 static int
+/* ARGSUSED */
 adjustClickIcon(dpy,event,iconInfo)
 Display *dpy;
 XEvent *event;
@@ -90,15 +95,14 @@ WinIconFrame *iconInfo;
  * iconCalcName - calc position/size of icon name
  */
 static void
+/* ARGSUSED */
 iconCalcName(winIcon,pane)
 	WinIconFrame *winIcon;
 	Window 	pane;
 {
-	Display *dpy = winIcon->core.client->dpy;
-
 	winIcon->nameLength = strlen(winIcon->fcore.name);
 	winIcon->nameWidth = XTextWidth(GRV.IconFontInfo, winIcon->fcore.name, 
-		winIcon->nameLength);
+				       winIcon->nameLength);
 	winIcon->nameX = (winIcon->core.width - winIcon->nameWidth)/2;
 
 	/* 
@@ -137,6 +141,7 @@ iconSetName(winIcon,pane)
  * to initiate a drag.  Unpin the icon slot and start a window-move.
  */
 static int
+/* ARGSUSED */
 selectDragIcon(dpy, ev, iframe, lastpress)
 Display *dpy;
 XEvent *ev;
@@ -153,6 +158,7 @@ XButtonEvent *lastpress;
  * newconfigIcon -- compute a new configuration of icon window
  */
 static int
+/* ARGSUSED */
 newconfigIcon(winInfo, pxcre)
 WinIconFrame *winInfo;
 XConfigureRequestEvent *pxcre;
@@ -204,6 +210,8 @@ int x,y;
 	WinNewPosFunc(winInfo,x,y);
 	if (winInfo->iconslot == NULL &&
 		!ClientIsPinnable(winInfo->core.client) &&
+		(!(GRV.FreeIconSlots) || winInfo->fManuallyPositioned || 
+		   winInfo->core.client->wmState == IconicState) &&
 		winInfo->core.client->transientFor == 0) {
 	    SlotAlloc(winInfo, winInfo->fManuallyPositioned, GRV.FSnapToGrid);
 	}
@@ -410,7 +418,7 @@ WinIconFrame	*win;
 	if (win->core.client->wmDecors->flags & WMDecorationIconName)
 	{
 		return (GRV.IconFontInfo->max_bounds.ascent +
-		       	GRV.IconFontInfo->max_bounds.descent + 
+			GRV.IconFontInfo->max_bounds.descent + 
 			ICON_VERTBORDER);
 	} else {
 		return 0;
@@ -429,7 +437,7 @@ heightTopIcon(win)
 WinIconFrame	*win;
 {
 	WinIconPane *winPane = (WinIconPane *)(win->fcore.panewin);
-	int availHeight,basicbottom;
+	int availHeight;
 
 	availHeight = ICON_WIN_HEIGHT - heightIconName(win);
 
@@ -507,7 +515,6 @@ Client	*client;
 	iconInfo->fcore.fullsize = !iconInfo->fcore.fullsize;
 }
 
-
 /***************************************************************************
 * global functions
 ***************************************************************************/
@@ -518,6 +525,7 @@ Client	*client;
  *	away.
  */
 WinIconFrame *
+/* ARGSUSED */
 MakeIcon(cli,panewin,paneattrs)
 Client *cli;
 Window panewin;		
@@ -589,6 +597,7 @@ XWindowAttributes *paneattrs;
 }
 
 void
+/* ARGSUSED */
 IconInit(dpy)
 Display *dpy;
 {
@@ -638,6 +647,9 @@ WinIconFrame *iconInfo;
 	GC	rootGC = WinGC(winInfo,ROOT_GC);
 	Window	root = WinRootID(winInfo);
 
+	if (GRV.IconFlashCount <= 0)
+	    return;
+
         XGrabServer(dpy);
 
         for(ii=0; ii < GRV.IconFlashCount ; ii++)
@@ -699,6 +711,7 @@ WinIconFrame *iconInfo;
  * IconUpdateName -- the icon name property has been changed
  */
 void
+/* ARGSUSED */
 IconUpdateName(cli,event)
 	Client		*cli;
 	XPropertyEvent	*event;
@@ -731,11 +744,14 @@ IconShow(cli, winIcon)
 {
     WinIconPane *pane = (WinIconPane *)winIcon->fcore.panewin;
 
+#ifdef notdef
+    /* see winipane.c */
     XReparentWindow(cli->dpy, pane->core.self, winIcon->core.self,
-			pane->core.x, pane->core.y);
-    XMapWindow(cli->dpy, pane->core.self);
+			pane->core.x, pane->core.y); see winipane.c
     if (pane->iconClientWindow && !(cli->flags & CLOlwmOwned))
         XChangeSaveSet(cli->dpy, pane->core.self, SetModeInsert);
+#endif
+    XMapWindow(cli->dpy, pane->core.self);
     MapWindow(winIcon);
 }
 
@@ -753,6 +769,24 @@ IconHide(cli, winIcon)
 
     UnmapWindow(winIcon);
     XUnmapWindow(cli->dpy, pane->core.self);
+#ifdef notdef
+    /* see winipane.c */
+    XReparentWindow(cli->dpy, pane->core.self, cli->scrInfo->rootid,
+			winIcon->core.x + pane->core.x,
+			winIcon->core.y + pane->core.y);
+    if (pane->iconClientWindow && !(cli->flags & CLOlwmOwned))
+        XChangeSaveSet(cli->dpy, pane->core.self, SetModeDelete);
+#endif
+}
+
+void
+IconUnparent(cli, winIcon)
+    Client *cli;
+    WinIconFrame *winIcon;
+{
+WinIconPane *pane = (WinIconPane *)winIcon->fcore.panewin;
+
+    XUnmapWindow(cli->dpy, pane->core.self);
     XReparentWindow(cli->dpy, pane->core.self, cli->scrInfo->rootid,
 			winIcon->core.x + pane->core.x,
 			winIcon->core.y + pane->core.y);
