@@ -4,7 +4,9 @@
  *      file for terms of the license.
  */
 
-#ident	"@(#)winroot.c	1.1 olvwm version 1/3/92"
+#ifdef IDENT
+#ident	"@(#)winroot.c	1.3 olvwm version 12/7/92"
+#endif
 
 /*
  * Based on
@@ -18,9 +20,10 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
-#include <olgx/olgx.h>
 
 #include "i18n.h"
+#include <olgx/olgx.h>
+
 #include "ollocale.h"
 #include "mem.h"
 #include "olwm.h"
@@ -188,6 +191,9 @@ eventEnterNotify(dpy, pEvent, winInfo)
 	XEvent		*pEvent;
 	WinRoot		*winInfo;
 {
+        if (pEvent->xcrossing.detail == NotifyNonlinearVirtual)
+            return;
+
 	ColorWindowCrossing(dpy, pEvent, winInfo);
 
 	if (GRV.FocusFollowsMouse)
@@ -199,6 +205,7 @@ eventEnterNotify(dpy, pEvent, winInfo)
  * eventConfigureRequest - a client wants to change configuration
  */
 static int
+/* ARGSUSED */
 eventConfigureRequest(dpy, pEvent, winInfo)
 	Display		*dpy;
 	XEvent		*pEvent;
@@ -280,7 +287,6 @@ eventMotionNotify(dpy, pEvent, winInfo)
 	XEvent		*pEvent;
 	WinRoot		*winInfo;
 {
-	short			boxX, boxY, boxW, boxH;
 	int			(*selectFunc)();
 
 	if (!pEvent->xmotion.same_screen)
@@ -327,7 +333,7 @@ eventMotionNotify(dpy, pEvent, winInfo)
  * eventButtonRelease - handle a click in the root.
  *
  * If the user clicks in the window, the focus is set to the no-focus window, 
- * and the PRIMARY selection is acquired and nulled.
+ * and the PRIMARY selections are acquired and nulled.
  */
 static int
 eventButtonRelease(dpy, pEvent, winInfo)
@@ -413,17 +419,13 @@ eventButtonPress(dpy, pEvent, winInfo)
  * eventKeyPressRelease - a keystroke has happened in the root window
  */
 static int
+/* ARGSUSED */
 eventKeyPressRelease(dpy, pEvent, winInfo)
 	Display		*dpy;
 	XEvent		*pEvent;
 	WinRoot		*winInfo;
 {
 
-	Window		child;
-	WinGeneric	*childInfo;
-	Client		*childClient;
-	Bool		samescreen;
-	int		destX, destY;
 	extern Bool	ExecuteKeyboardFunction();
 	Bool		isbound;
 
@@ -434,84 +436,43 @@ eventKeyPressRelease(dpy, pEvent, winInfo)
 
 	if (!isbound && pEvent->type == KeyPress)
 	    KeyBeep(dpy,pEvent);
-
-#ifdef notdef
-	samescreen = XTranslateCoordinates(dpy,
-				pEvent->xkey.root, pEvent->xkey.root,
-				pEvent->xkey.x_root, pEvent->xkey.y_root, 
-				&destX, &destY, &child );
-
-	if (!samescreen)
-		return;
-
-	if (pEvent->type == KeyPress && child != None &&
-	    matchKeystrokeToSpec(pEvent, &(GRV.FrontKey))) {
-
-		XWindowChanges xwc;
-		xwc.stack_mode = Opposite; NOT DEF
-		XConfigureWindow( dpy, child, CWStackMode, &xwc );
-
-	} else if (matchKeystrokeToSpec(pEvent, &(GRV.HelpKey))) {
-
-		handleHelpKey(dpy,pEvent);
-
-	} else if (pEvent->type == KeyPress && child != None &&
-		   matchKeystrokeToSpec(pEvent, &(GRV.OpenKey))) {
-
-		childInfo = WIGetInfo(child);
-		if ( childInfo ) {
-			childClient = childInfo->core.client;
-			if (childClient != NULL) {
-				ClientOpenCloseToggle(childClient);
-			}
-		}
-	} else if (pEvent->type == KeyPress &&
-		   matchKeystrokeToSpec(pEvent, &(GRV.ColorLockKey))) {
-
-		InstallPointerColormap(dpy, pEvent->xkey.root, 
-			pEvent->xkey.x_root, pEvent->xkey.y_root, True);
-
-	} else if (pEvent->type == KeyPress &&
-		   matchKeystrokeToSpec(pEvent, &(GRV.ColorUnlockKey))) {
-
-		UnlockColormap(dpy,winInfo);
-	}
-#endif /* notdef */
 }
 
 /* 
  * eventPropertyNotify - a root property has changed
  */
 static int
+/* ARGSUSED */
 eventPropertyNotify(dpy, pEvent, winInfo)
 	Display		*dpy;
 	XEvent		*pEvent;
 	WinRoot		*winInfo;
 {
 	unsigned long	nitems, remain;
-	char 		*resourceString;
+	char		*resourceString;
 
 	/* make sure that the property was the one we care about and
 	 * changed (as opposed to deleted)
 	 */
-	if ( (pEvent->xproperty.atom != XA_RESOURCE_MANAGER) 
-	     || (pEvent->xproperty.state != PropertyNewValue) )
+	if ((pEvent->xproperty.atom != XA_RESOURCE_MANAGER) 
+	     || (pEvent->xproperty.state != PropertyNewValue))
 		return;
 
 	resourceString = GetWindowProperty(dpy, WinRootID(winInfo),
-		XA_RESOURCE_MANAGER, 0L, 100000000L, 
+		XA_RESOURCE_MANAGER, 0L, 100000000L,
 		/* REMIND use ENTIRE_CONTENTS */
 		XA_STRING, 0, &nitems, &remain);
 	if (resourceString != NULL) {
 		UpdateGlobals(dpy, resourceString);
 		XFree( resourceString );
-        }
+	}
 }
 
 /* 
  * eventUnmapNotify - an unreparented pane is going away
  */
 static int
+/* ARGSUSED */
 eventUnmapNotify(dpy, pEvent, winInfo)
 	Display		*dpy;
 	XEvent		*pEvent;
@@ -559,7 +520,7 @@ writeProtocols(dpy,rootwin)
 	
 	/* conditionally support the _SUN_WINDOW_STATE protocol */
 	if (DoingWindowState)
-	  data[nitems++] = AtomSunWindowState; 
+		data[nitems++] = AtomSunWindowState;
 
 	/* support 5-word-long _OL_WIN_ATTR property */
 	data[nitems++] = AtomSunOLWinAttr5;
@@ -667,6 +628,7 @@ MakeRoot(dpy, cli)
  * RootInit - init the WinRoot class function vector
  */
 void
+/* ARGSUSED */
 RootInit(dpy)
 Display *dpy;
 {
